@@ -18,30 +18,35 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_BREAK_H__
-#define __CMD_BREAK_H__
+#ifndef CLI_CMD_BREAK_H_
+#define CLI_CMD_BREAK_H_
 
-#include <unistd.h>
 #include <glib.h>
 #include "command.h"
 
-class Value;
+#include "../src/value.h"
+
+class Expression;
+class gpsimObject;
+struct cmd_options;
+
 #define CMDBREAK_BAD_BREAK_NUMBER 0xffff
-class cmd_break : public command
-{
+
+class cmd_break : public command {
 public:
-
   cmd_break();
-  void list(guint64 value=CMDBREAK_BAD_BREAK_NUMBER);
 
-  unsigned int set_break(cmd_options *co, bool bLog=false);
-  unsigned int set_break(cmd_options *co, ExprList_t *pEL, bool bLog=false);
+  void list(guint64 value = CMDBREAK_BAD_BREAK_NUMBER);
+  unsigned int set_break(cmd_options *co, bool bLog = false);
+  unsigned int set_break(cmd_options *co, ExprList_t *pEL, bool bLog = false);
+  unsigned int set_break(gpsimObject *v);
 
 private:
-  unsigned int set_break(cmd_options *co, Expression *pExpr1, Expression *pExpr2=0, bool bLog=false);
+  unsigned int set_break(cmd_options *co, Expression *pExpr1, Expression *pExpr2 = nullptr, bool bLog = false);
   unsigned int set_break(int bit_flag, bool bLog);
 };
 
 extern cmd_break c_break;
+
 #endif
 
