@@ -18,23 +18,22 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_BUS_H__
-#define __CMD_BUS_H__
-#include "misc.h"
+#ifndef CLI_CMD_BUS_H_
+#define CLI_CMD_BUS_H_
+
+#include "command.h"
 
 #include <list>
-using namespace std;
+#include <string>
 
-class cmd_bus : public command
-{
+class cmd_bus : public command {
 public:
+  cmd_bus();
 
-  cmd_bus(void);
-  void list_busses(void);
-
-  void add_busses(list <string> *);
-
+  void list_busses();
+  void add_busses(std::list<std::string> *);
 };
 
 extern cmd_bus c_bus;
+
 #endif
