@@ -39,7 +39,7 @@ static cmd_options cmd_clear_options[] =
 
 cmd_clear::cmd_clear()
   : command("clear", "cl")
-{ 
+{
   brief_doc = string("Remove a break point");
 
   long_doc = string ("clear bp_number\n\
@@ -48,7 +48,7 @@ when it was created. (type \"break\" without any arguments to\n\
 display the currently set break points.\n\
 ");
 
-  op = cmd_clear_options; 
+  op = cmd_clear_options;
 }
 
 
@@ -80,13 +80,9 @@ void cmd_clear::clear(Expression *expr)
       delete v;
      }
     }
-    catch  (Error *err)
+    catch  (Error &err)
     {
-        if (err)
-        {
-            cerr << "***ERROR cmd_clear " << err->toString() << endl;
-            delete err;
-        }
+        std::cerr << "***ERROR cmd_clear " << err.what() << '\n';
     }
 
     delete expr;
