@@ -204,8 +204,8 @@ void cmd_module::module(cmd_options_str *cos)
         string fname(cos->str);
         ModuleLibrary::LoadFile(fname);
       }
-      catch(Error *pError) {
-        cout << pError->get_errMsg();
+      catch(Error &pError) {
+        std::cout << pError.what();
       }
 
       break;
