@@ -20,21 +20,18 @@ Boston, MA 02111-1307, USA.  */
 
 #ifndef __CMD_SHELL_H__
 #define __CMD_SHELL_H__
-#include <list>
-using namespace std;
 
-class symbol;
+#include "command.h"
+class String;
 
 class cmd_shell : public command
 {
 public:
-
-  cmd_shell(void);
+  cmd_shell();
   void shell(String *cmd);
 };
 
 extern cmd_shell c_shell;
 
-
 #endif
 
