@@ -37,14 +37,12 @@ static cmd_options cmd_step_options[] =
 };
 
 
-cmd_step::cmd_step(void)
+cmd_step::cmd_step()
+  : command("step","s")
 { 
-  name = "step";
-  abbreviation = "s";
+  brief_doc = string("Execute one or more instructions.");
 
-    brief_doc = string("Execute one or more instructions.");
-
-    long_doc = string ("\nstep [over | n]\n\n\
+  long_doc = string ("\nstep [over | n]\n\n\
 \t    no arguments:  step one instruction.\n\
 \tnumeric argument:  step a number of instructions\n\
 \t \"over\" argument:  step over the next instruction\n\
@@ -57,28 +55,16 @@ cmd_step::cmd_step(void)
 
 void cmd_step::step(int instructions)
 {
-  if(!have_cpu(1))
-    return;
-
-  GetActiveCPU()->step(instructions);
-
+  get_interface().step_simulation(instructions);
 }
 
 void cmd_step::step(Expression *expr)
 {
-  if(!have_cpu(1))
-    return;
-
-  GetActiveCPU()->step((int)evaluate(expr));
-
+  get_interface().step_simulation((int)evaluate(expr));
 }
 
 void cmd_step::over(void)
 {
 
-  if(!have_cpu(1))
-    return;
-
-  GetActiveCPU()->step_over();
-
+  get_interface().advance_simulation(gpsimInterface::eAdvanceNextInstruction);
 }
