@@ -91,7 +91,7 @@ static cmd_options cmd_stimulus_options[] =
 
 cmd_stimulus::cmd_stimulus()
   : command("stimulus","stim")
-{ 
+{
 
   brief_doc = string("Create a stimulus");
 
@@ -194,7 +194,7 @@ void cmd_stimulus::stimulus()
 // is assigned to 'last_stimulus'. The last_stimulus also acts like
 // a flag. If it is non-null then a stimulus is in the process of
 // being created. When the stimulus 'end' option is specified at the
-// cli, then 'last_stimulus' is set to NULL. Note the memory for 
+// cli, then 'last_stimulus' is set to NULL. Note the memory for
 // used by the last stimulus is created here, but destroyed by the
 // stimulus code in ../src/stimuli.cc .
 //
@@ -403,10 +403,8 @@ void cmd_stimulus::stimulus(ExprList_t *eList)
 
       }
 
-      catch (Error *err) {
-	if(err)
-	  cout << "ERROR:" << err->toString() << endl;
-	delete err;
+      catch (Error &err) {
+        std::cout << "ERROR:" << err.what() << '\n';
       }
 
     }
