@@ -18,26 +18,29 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_X_H__
-#define __CMD_X_H__
+#ifndef CLI_CMD_X_H_
+#define CLI_CMD_X_H_
 
+#include "command.h"
 class Expression;
 
-class cmd_x : public command
-{
+class cmd_x : public command {
 public:
+  cmd_x();
 
-  cmd_x(void);
-  void x(void);
-
-  void x(int reg, Expression *pExpr = NULL);
+  void x();
+  void x(int reg, Expression *pExpr = nullptr);
   void x(char *reg_name, int val);
   void x(char *reg_name);
   void x(Expression *);
 
-  virtual int is_repeatable(void) { return 1; };
+  virtual int is_repeatable()
+  {
+    return 1;
+  }
 };
 
 extern cmd_x c_x;
+
 #endif
 
