@@ -18,25 +18,27 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __INPUT_H__
-#define __INPUT_H__
+#ifndef CLI_INPUT_H_
+#define CLI_INPUT_H_
+
+#include "../src/../config.h"
+class Processor;
 
 #define CONTINUING_LINE 1
 
-extern int gpsim_read (char *buf, unsigned max_size);
-extern void initialize_readline (void);
-extern void exit_cli(void);
-extern void exit_gpsim(int);
-extern void SetLastFullCommand(const char *pCmd);
-extern const char * GetLastFullCommand();
-extern void EnableSTCEcho(bool bEnable);
+int gpsim_read(char *buf, unsigned int max_size);
+void initialize_readline();
+void exit_cli();
+void exit_gpsim(int);
+void SetLastFullCommand(const char *pCmd);
+const char *GetLastFullCommand();
+void EnableSTCEcho(bool bEnable);
 
 #ifndef HAVE_GUI
-extern char *gnu_readline (char *s, unsigned int force_readline);
+char *gnu_readline(char *s, unsigned int force_readline);
 #endif
 
-class Processor;
-extern int gpsim_open(Processor *cpu, const char *file,
-                      const char *pProcessorType, const char *pProcessorName);
+int gpsim_open(Processor *cpu, const char *file,
+               const char *pProcessorType, const char *pProcessorName);
 
 #endif
