@@ -18,15 +18,15 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __MISC_H__
-#define __MISC_H__
+#ifndef CLI_MISC_H_
+#define CLI_MISC_H_
 
 #include "../src/cmd_gpsim.h"
 
 // miscellaneous definitions that are used
 
 struct cmd_options {
-  char *name;
+  const char *name;
   int  value;
   int  token_type;
 };
@@ -40,13 +40,13 @@ struct cmd_options_num {
 
    /* Command option with a string parameter */
 
-class cmd_options_str
-{
- public:
+class cmd_options_str {
+public:
+  explicit cmd_options_str(const char *);
+  ~cmd_options_str();
+
   cmd_options *co;
   char *str;
-  cmd_options_str(const char *);
-  ~cmd_options_str();
 };
 
 #endif
