@@ -39,6 +39,9 @@ Boston, MA 02111-1307, USA.  */
 #include "../src/breakpoints.h"
 #include "../src/gpsim_time.h"
 
+#include "../src/trigger.h"
+#include "../src/value.h"
+
 #ifndef _WIN32
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -52,8 +55,7 @@ void exit_gpsim(int);
 // Here is an experimental attribute for testing the socket interface.
 // The purpose is to isolate socket testing from the rest of the simulator.
 //
-class TestInt32Array : public Value
-{
+class TestInt32Array : public Value {
 public:
   TestInt32Array(const char *_name, int _sz)
     : Value(_name, " test array for testing sockets")
@@ -66,15 +68,16 @@ public:
     delete[] array;
   }
 
-  virtual void set(const char *cP,int len=0)
+  virtual void set(const char * /* cP */ , int len = 0)
   {
+    (void)len;
     std::cout << name() << " set\n";
   }
-  virtual void get(char *, int len)
+  virtual void get(char *, int /* len */ )
   {
     std::cout << name() << " get\n";
   }
-  virtual string toString()
+  virtual std::string toString()
   {
     return name();
   }
@@ -82,7 +85,6 @@ public:
 private:
   int size;
   int *array;
-
 };
 
 
@@ -104,17 +106,18 @@ bool server_started = false;
 
 void psocketerror(const char *str)
 {
-  fprintf (stderr, "%s: %s\n", str, g_win32_error_message(WSAGetLastError()));
+  fprintf(stderr, "%s: %s\n", str, g_win32_error_message(WSAGetLastError()));
 }
 
 
-bool winsockets_init(void)
+bool winsockets_init()
 {
   WSADATA wsaData;
   int err;
 
-  if (0 != (err = WSAStartup( MAKEWORD( 2, 2 ), &wsaData )))
+  if (0 != (err = WSAStartup(MAKEWORD(2, 2), &wsaData))) {
     return false;
+  }
 
   /* Confirm that the WinSock DLL supports 2.2.*/
   /* Note that if the DLL supports versions greater    */
@@ -122,15 +125,17 @@ bool winsockets_init(void)
   /* 2.2 in wVersion since that is the version we      */
   /* requested.                                        */
 
-  if (LOBYTE( wsaData.wVersion ) != 2 || HIBYTE( wsaData.wVersion ) != 2 ) {
+  if (LOBYTE(wsaData.wVersion) != 2 || HIBYTE(wsaData.wVersion) != 2) {
     /* Tell the user that we could not find a usable */
     /* WinSock DLL.                                  */
-    WSACleanup( );
+    WSACleanup();
     return false;
   }
 
   return true;
 }
+
+
 #else
 #define psocketerror(s) perror(s)
 #define closesocket(s)  close(s)
@@ -208,19 +213,16 @@ bool ParseSocketLink(Packet *buffer, SocketLink **);
 //------------------------------------------------------------------------
 //
 
-class SocketInterface : public Interface
-{
+class SocketInterface : public Interface {
 private:
-//  Socket *sock;
+  //  Socket *sock;
 
 public:
-
-  virtual void SimulationHasStopped (gpointer object);
-  virtual void Update  (gpointer object);
-
+  explicit SocketInterface(Socket *);
   virtual ~SocketInterface();
 
-  SocketInterface(Socket *);
+  virtual void SimulationHasStopped(gpointer object);
+  virtual void Update(gpointer object);
 };
 
 
@@ -231,10 +233,9 @@ public:
 //
 
 
-class SocketBase
-{
+class SocketBase {
 public:
-  SocketBase(SOCKET s);
+  explicit SocketBase(SOCKET s);
   ~SocketBase();
 
   SOCKET getSocket();
@@ -243,27 +244,24 @@ public:
   void Service();
   void ParseObject();
 
-  Packet     *packet;
+  Packet *packet;
 
 private:
   SOCKET socket;
 };
 
+
 //------------------------------------------------------------------------
 // Socket class
 // This class is responsible for listening to clients.
 //
-class Socket
-{
+class Socket {
 public:
-
-
   Socket();
   ~Socket();
 
-
   void init(int port);
-  void AssignChannel(gboolean (*server_func)(GIOChannel *,GIOCondition,void *));
+  void AssignChannel(gboolean(*server_func)(GIOChannel *, GIOCondition, void *));
 
   void Close(SocketBase**);
   void Bind();
@@ -276,8 +274,7 @@ public:
 };
 
 
-class SocketLink
-{
+class SocketLink {
 public:
   SocketLink(unsigned int _handle, SocketBase *);
 
@@ -287,16 +284,23 @@ public:
 
   /// Send a response back to the link.
   /// if the bTimeStamp is true, then the cycle counter is sent too.
-  bool Send(bool bTimeStamp=false);
+  bool Send(bool bTimeStamp = false);
   bool Receive();
 
-  virtual void set(Packet &)=0;
-  virtual void get(Packet &)=0;
-  unsigned int getHandle() { return handle; }
-  void setBlocking(bool bBlocking) {
+  virtual void set(Packet &) = 0;
+  virtual void get(Packet &) = 0;
+  unsigned int getHandle()
+  {
+    return handle;
+  }
+  void setBlocking(bool bBlocking)
+  {
     bWaitForResponse = bBlocking;
   }
-  bool bBlocking()  { return bWaitForResponse; }
+  bool bBlocking()
+  {
+    return bWaitForResponse;
+  }
 
 private:
   unsigned int handle;
@@ -304,6 +308,7 @@ private:
   bool bWaitForResponse;
 };
 
+
 ///========================================================================
 /// AttributeLink
 /// An attribute link is a link associated with a gpsim attribute.
@@ -312,8 +317,7 @@ private:
 /// for parsing the link name and looking it up in the table only
 /// has to be done once.
 
-class AttributeLink : public SocketLink
-{
+class AttributeLink : public SocketLink {
 public:
   AttributeLink(unsigned int _handle, SocketBase *, Value *);
 
@@ -324,47 +328,52 @@ public:
   void set(Packet &);
   void get(Packet &);
 
-  Value *getValue() { return v; }
+  Value *getValue()
+  {
+    return v;
+  }
+
 private:
   /// This is a pointer to the gpsim Value object associated with
   /// this link.
   Value *v;
 };
 
+
 ///========================================================================
 /// NotifyLink
 /// A notify link is a link designed to be a sort of cross reference. It
 /// is associated with a gpsim attribute in such a way that whenever the
 /// gpsim attribute changes, the notify link will notify a client socket.
 
-class NotifyLink : public Value
-{
+class NotifyLink : public Value {
 public:
+  explicit NotifyLink(AttributeLink *);
   virtual void set(gint64);
-  NotifyLink(AttributeLink *);
+
 private:
   AttributeLink *sl;
 };
 
+
 ///========================================================================
 /// CyclicCallBackLink
 /// A cyclic call back link is a link that periodically sends a message
 /// to the client.
 
-class CyclicCallBackLink : public TriggerObject
-{
+class CyclicCallBackLink : public TriggerObject {
 public:
-
-  CyclicCallBackLink(guint64 , SocketBase *);
+  CyclicCallBackLink(guint64, SocketBase *);
 
   virtual void callback();
-  virtual void callback_print(void);
+  virtual void callback_print();
+
 private:
   guint64 interval;
   SocketBase *sb;
-
 };
 
+
 //========================================================================
 #define nSOCKET_LINKS 16
 
@@ -372,86 +381,99 @@ SocketLink *links[nSOCKET_LINKS];
 
 AttributeLink *gCreateSocketLink(unsigned int, Packet &, SocketBase *);
 
+
 unsigned int FindFreeHandle()
 {
   unsigned int i;
   static unsigned int sequence = 0;
 
-  for(i=0; i<nSOCKET_LINKS; i++)
-    if(links[i] == 0)
+  for (i = 0; i < nSOCKET_LINKS; i++)
+    if (links[i] == 0) {
       return i | (++sequence << 16);
+    }
 
   return 0xffff;
 }
+
+
 //========================================================================
 SocketBase::SocketBase(SOCKET s)
   : socket(s)
 {
-  packet = new Packet(BUFSIZE,BUFSIZE);
+  packet = new Packet(BUFSIZE, BUFSIZE);
 }
 
+
 SocketBase::~SocketBase()
 {
   delete packet;
 }
 
+
 SOCKET SocketBase::getSocket()
 {
   return socket;
 }
 
+
 void SocketBase::Close()
 {
-  if(socket != INVALID_SOCKET)
+  if (socket != INVALID_SOCKET) {
     closesocket(socket);
+  }
 
   socket = INVALID_SOCKET;
-
 }
 
+
 //========================================================================
 bool ParseSocketLink(Packet *buffer, SocketLink **sl)
 {
-  if(!sl)
-    return 0;
+  if (!sl) {
+    return false;
+  }
 
   unsigned int handle;
 
-  if(buffer->DecodeUInt32(handle)) {
+  if (buffer->DecodeUInt32(handle)) {
+    unsigned int index = handle & 0xffff;
+    *sl = links[index & 0x0f];
 
-    unsigned int index    = handle & 0xffff;
-
-    *sl = links[index&0x0f];
-    if( (*sl) && (*sl)->getHandle() != handle)
-      *sl = 0;
+    if ((*sl) && (*sl)->getHandle() != handle) {
+      *sl = nullptr;
+    }
 
     return true;
   }
 
   return false;
-
 }
 
+
 //========================================================================
 void CloseSocketLink(SocketLink *sl)
 {
-  if(!sl)
+  if (!sl) {
     return;
+  }
 
   unsigned int handle = sl->getHandle();
-  std::cout << " closing link with handle 0x" << hex << handle << endl;
-
-  if(links[handle&0x000f] == sl)
-    links[handle&0x000f] = 0;
+  std::cout << " closing link with handle 0x" << std::hex << handle << '\n';
 
+  if (links[handle & 0x000f] == sl) {
+    links[handle & 0x000f] = nullptr;
+  }
 }
+
+
 //========================================================================
 Socket::Socket()
 {
   my_socket = 0;
 
-  for(int i=0; i<nSOCKET_LINKS; i++)
-    links[i] = 0;
+  for (int i = 0; i < nSOCKET_LINKS; i++) {
+    links[i] = nullptr;
+  }
 }
 
 
@@ -471,9 +493,9 @@ void Socket::init(int port)
   }
 
   my_socket = new SocketBase(new_socket);
-
   int on = 1;
-  if ( setsockopt ( new_socket, SOL_SOCKET, SO_REUSEADDR, ( const char* ) &on, sizeof ( on ) ) != 0 ) {
+
+  if (setsockopt(new_socket, SOL_SOCKET, SO_REUSEADDR, (const char*) &on, sizeof(on)) != 0) {
     psocketerror("setsockopt");
     exit_gpsim(1);
   }
@@ -482,46 +504,43 @@ void Socket::init(int port)
   addr.sin_family = AF_INET;
   addr.sin_addr.s_addr = INADDR_ANY;
   addr.sin_port = htons(port);
-
   Bind();
   Listen();
 }
 
-void Socket::AssignChannel(gboolean (*server_function)(GIOChannel *,GIOCondition,void *))
+
+void Socket::AssignChannel(gboolean(*server_function)(GIOChannel *, GIOCondition, void *))
 {
-
-  if(my_socket->getSocket() > 0) {
-
+  if (my_socket->getSocket() > 0) {
     GIOChannel *channel = g_io_channel_unix_new(my_socket->getSocket());
     GIOCondition condition = (GIOCondition)(G_IO_IN | G_IO_HUP | G_IO_ERR);
-
-    GError *err = NULL;
-
-    g_io_channel_set_encoding (channel, NULL, &err);
+    GError *err = nullptr;
+    g_io_channel_set_encoding(channel, nullptr, &err);
 #if !defined _WIN32 || defined _DEBUG
-        g_io_channel_set_flags (channel, G_IO_FLAG_SET_MASK, &err);
+    g_io_channel_set_flags(channel, G_IO_FLAG_SET_MASK, &err);
 #endif
-
     g_io_add_watch(channel,
                    condition,
                    server_function,
                    (void*)this);
   }
-
 }
 
+
 void Socket::Close(SocketBase **sock)
 {
   if (sock && *sock) {
     (*sock)->Close();
-    *sock = 0;
+    *sock = nullptr;
   }
 }
 
+
 void Socket::Bind()
 {
-  if(!my_socket)
+  if (!my_socket) {
     return;
+  }
 
   if (bind(my_socket->getSocket(), (struct sockaddr *) &addr, sizeof(addr)) != 0) {
     psocketerror("bind");
@@ -531,8 +550,9 @@ void Socket::Bind()
 
 void Socket::Listen()
 {
-  if(!my_socket)
+  if (!my_socket) {
     return;
+  }
 
   if (listen(my_socket->getSocket(), 5) != 0) {
     psocketerror("listen");
@@ -543,7 +563,7 @@ void Socket::Listen()
 SocketBase *Socket::Accept()
 {
   socklen_t addrlen = sizeof(addr);
-  SOCKET client_socket = accept(my_socket->getSocket(),(struct sockaddr *)  &addr, &addrlen);
+  SOCKET client_socket = accept(my_socket->getSocket(), (struct sockaddr *)  &addr, &addrlen);
 
   if (client_socket == INVALID_SOCKET) {
     psocketerror("accept");
@@ -556,8 +576,9 @@ SocketBase *Socket::Accept()
 
 bool SocketBase::Send(const char *b)
 {
-  if(!socket)
+  if (!socket) {
     return false;
+  }
 
   //std::cout << "Sending sock="<<socket << " data " << b << endl;
 
@@ -570,6 +591,7 @@ bool SocketBase::Send(const char *b)
   return true;
 }
 
+
 //------------------------------------------------------------------------
 // ParseObject
 //
@@ -584,192 +606,173 @@ bool SocketBase::Send(const char *b)
 
 void SocketBase::ParseObject()
 {
-
   unsigned int ObjectType;
-  if(!packet->DecodeObjectType(ObjectType))
+
+  if (!packet->DecodeObjectType(ObjectType)) {
     return;
+  }
 
   switch (ObjectType) {
+  case GPSIM_CMD_CREATE_SOCKET_LINK: {
+    unsigned int handle = FindFreeHandle();
+    AttributeLink *sl = gCreateSocketLink(handle, *packet, this);
 
-  case GPSIM_CMD_CREATE_SOCKET_LINK:
-    {
-      unsigned int handle = FindFreeHandle();
-      AttributeLink *sl = gCreateSocketLink(handle, *packet, this);
-
-      if(sl) {
-        links[handle&0x0f] = sl;
-        packet->EncodeHeader();
-        packet->EncodeUInt32(handle);
-        packet->txTerminate();
-        Send(packet->txBuff());
-      }
-    }
-    break;
-
-  case GPSIM_CMD_CREATE_NOTIFY_LINK:
-    {
-      unsigned int handle = FindFreeHandle();
-      AttributeLink *sl = gCreateSocketLink(handle, *packet, this);
-
-      if(sl) {
-        unsigned int i=0;
-
-        if(packet->DecodeUInt32(i) && i)
-          sl->setBlocking(true);
-
-        //NotifyLink *nl = new NotifyLink(sl);
-
-        links[handle&0x0f] = sl;
-        packet->EncodeHeader();
-        packet->EncodeUInt32(handle);
-        packet->txTerminate();
-        Send(packet->txBuff());
-      }
-    }
-    break;
-
-  case GPSIM_CMD_CREATE_CALLBACK_LINK:
-    {
-      unsigned int handle = FindFreeHandle();
-      guint64 interval=0;
-      std::cout << "Creating callback link\n";
-      if(packet->DecodeUInt64(interval) && interval) {
-
-        std::cout << "Creating callback link interval=" << interval << endl;
-
-        //CyclicCallBackLink *cl = new CyclicCallBackLink(interval,this);
-
-        //links[handle&0x0f] = sl;
-        packet->EncodeHeader();
-        packet->EncodeUInt32(handle);
-        packet->txTerminate();
-        Send(packet->txBuff());
-      }
-    }
-    break;
-
-  case GPSIM_CMD_REMOVE_SOCKET_LINK:
-    {
-      SocketLink *sl=0;
-      std::cout << "remove socket link command\n";
-      ParseSocketLink(packet, &sl);
-
-      if(sl)
-        CloseSocketLink(sl);
-      Send("$");
-    }
-    break;
-
-  case GPSIM_CMD_QUERY_SOCKET_LINK:
-    {
-      SocketLink *sl=0;
-
-      ParseSocketLink(packet, &sl);
-
-      if(sl)
-        sl->Send();
-    }
-    break;
-
-  case GPSIM_CMD_WRITE_TO_SOCKET_LINK:
-    {
-      SocketLink *sl=0;
-
-      ParseSocketLink(packet, &sl);
-      if(sl) {
-        sl->set(*packet);
-        Send("$");
-      }
-
-    }
-    break;
-
-  case GPSIM_CMD_QUERY_SYMBOL:
-    {
-      char tmp[256];
-
-      if(packet->DecodeString(tmp,256)) {
-
-        Value *sym = globalSymbolTable().findValue(tmp);
-        if(sym) {
-          packet->EncodeHeader();
-          sym->get(*packet);
-          packet->txTerminate();
-          Send(packet->txBuff());
-
-        } else
-          Send("-");
-      }
-    }
-    break;
-
-
-  case GPSIM_CMD_WRITE_TO_SYMBOL:
-    {
-
-      // The client has requested to write directly to a symbol
-      // (without using a SocketLink). So, we'll extract the symbol
-      // name from the packet and look it up in the symbol table.
-      // If the symbol is found then, it will get assigned the
-      // value that's stored in the packet.
-
-      char tmp[256];
-
-      if(packet->DecodeString(tmp,256)) {
-
-        Value *sym = globalSymbolTable().findValue(tmp);
-
-        if(sym) {
-
-          // We'll define the response header before we decode
-          // the rest of the packet. The reason for this is that
-          // some symbols may wish to generate a response.
-
-          packet->EncodeHeader();
-          sym->set(*packet);
-          packet->txTerminate();
-
-          Send(packet->txBuff());
-
-        } else
-          Send("-");
-      }
-    }
-    break;
-
-  case GPSIM_CMD_RUN:
-    {
-      guint64 nCycles;
-      guint64 startCycle = get_cycles().get();
-
-      // Extract from the packet the number of cycles we should run.
-      // If the number of cycles is greater than 0, then we'll set
-      // a cycle breakpoint; otherwise we'll run forever.
-
-      if(packet->DecodeUInt64(nCycles)) {
-        guint64 fc = startCycle + nCycles;
-        if(nCycles) {
-          get_bp().set_cycle_break(0,fc);
-        }
-
-      }
-
-      // Start running...
-
-      get_interface().start_simulation();
-
-      // The simulation has stopped. For the response (to the run
-      // command) we'll send the current value of the cycle counter.
-      // (A client can use this to determine if the break was due to
-      // cycle break set above or to something else).
-
-      packet->EncodeObjectType(GPSIM_CMD_RUN);
-      packet->EncodeUInt64(get_cycles().get() - startCycle);
+    if (sl) {
+      links[handle & 0x0f] = sl;
+      packet->EncodeHeader();
+      packet->EncodeUInt32(handle);
       packet->txTerminate();
       Send(packet->txBuff());
-
     }
-    break;
+  }
+  break;
+
+  case GPSIM_CMD_CREATE_NOTIFY_LINK: {
+    unsigned int handle = FindFreeHandle();
+    AttributeLink *sl = gCreateSocketLink(handle, *packet, this);
+
+    if (sl) {
+      unsigned int i = 0;
+
+      if (packet->DecodeUInt32(i) && i) {
+        sl->setBlocking(true);
+      }
+
+      //NotifyLink *nl = new NotifyLink(sl);
+      links[handle & 0x0f] = sl;
+      packet->EncodeHeader();
+      packet->EncodeUInt32(handle);
+      packet->txTerminate();
+      Send(packet->txBuff());
+    }
+  }
+  break;
+
+  case GPSIM_CMD_CREATE_CALLBACK_LINK: {
+    unsigned int handle = FindFreeHandle();
+    guint64 interval = 0;
+    std::cout << "Creating callback link\n";
+
+    if (packet->DecodeUInt64(interval) && interval) {
+      std::cout << "Creating callback link interval=" << interval << '\n';
+      //CyclicCallBackLink *cl = new CyclicCallBackLink(interval,this);
+      //links[handle&0x0f] = sl;
+      packet->EncodeHeader();
+      packet->EncodeUInt32(handle);
+      packet->txTerminate();
+      Send(packet->txBuff());
+    }
+  }
+  break;
+
+  case GPSIM_CMD_REMOVE_SOCKET_LINK: {
+    SocketLink *sl = nullptr;
+    std::cout << "remove socket link command\n";
+    ParseSocketLink(packet, &sl);
+
+    if (sl) {
+      CloseSocketLink(sl);
+    }
+
+    Send("$");
+  }
+  break;
+
+  case GPSIM_CMD_QUERY_SOCKET_LINK: {
+    SocketLink *sl = nullptr;
+    ParseSocketLink(packet, &sl);
+
+    if (sl) {
+      sl->Send();
+    }
+  }
+  break;
+
+  case GPSIM_CMD_WRITE_TO_SOCKET_LINK: {
+    SocketLink *sl = nullptr;
+    ParseSocketLink(packet, &sl);
+
+    if (sl) {
+      sl->set(*packet);
+      Send("$");
+    }
+  }
+  break;
+
+  case GPSIM_CMD_QUERY_SYMBOL: {
+    char tmp[256];
+
+    if (packet->DecodeString(tmp, 256)) {
+      Value *sym = globalSymbolTable().findValue(tmp);
+
+      if (sym) {
+        packet->EncodeHeader();
+        sym->get(*packet);
+        packet->txTerminate();
+        Send(packet->txBuff());
+
+      } else {
+        Send("-");
+      }
+    }
+  }
+  break;
+
+  case GPSIM_CMD_WRITE_TO_SYMBOL: {
+    // The client has requested to write directly to a symbol
+    // (without using a SocketLink). So, we'll extract the symbol
+    // name from the packet and look it up in the symbol table.
+    // If the symbol is found then, it will get assigned the
+    // value that's stored in the packet.
+    char tmp[256];
+
+    if (packet->DecodeString(tmp, 256)) {
+      Value *sym = globalSymbolTable().findValue(tmp);
+
+      if (sym) {
+        // We'll define the response header before we decode
+        // the rest of the packet. The reason for this is that
+        // some symbols may wish to generate a response.
+        packet->EncodeHeader();
+        sym->set(*packet);
+        packet->txTerminate();
+        Send(packet->txBuff());
+
+      } else {
+        Send("-");
+      }
+    }
+  }
+  break;
+
+  case GPSIM_CMD_RUN: {
+    guint64 nCycles;
+    guint64 startCycle = get_cycles().get();
+
+    // Extract from the packet the number of cycles we should run.
+    // If the number of cycles is greater than 0, then we'll set
+    // a cycle breakpoint; otherwise we'll run forever.
+
+    if (packet->DecodeUInt64(nCycles)) {
+      guint64 fc = startCycle + nCycles;
+
+      if (nCycles) {
+        get_bp().set_cycle_break(0, fc);
+      }
+    }
+
+    // Start running...
+    get_interface().start_simulation();
+    // The simulation has stopped. For the response (to the run
+    // command) we'll send the current value of the cycle counter.
+    // (A client can use this to determine if the break was due to
+    // cycle break set above or to something else).
+    packet->EncodeObjectType(GPSIM_CMD_RUN);
+    packet->EncodeUInt64(get_cycles().get() - startCycle);
+    packet->txTerminate();
+    Send(packet->txBuff());
+  }
+  break;
 
   case GPSIM_CMD_RESET:
     get_interface().reset();
@@ -779,10 +782,10 @@ void SocketBase::ParseObject()
   default:
     printf("Invalid object type: %u\n", ObjectType);
     Send("-");
-
   }
-
 }
+
+
 //------------------------------------------------------------------------
 // Service()
 //
@@ -791,8 +794,7 @@ void SocketBase::ParseObject()
 
 void SocketBase::Service()
 {
-  if(packet->brxHasData()) {
-
+  if (packet->brxHasData()) {
     // If the data is a 'pure socket command', which is to say it begins
     // with a header as defined in ../src/protocol.h, then the data
     // will be further parsed by ParseObject(). If the data has an
@@ -800,30 +802,36 @@ void SocketBase::Service()
     // line and we let the CLI parse_string() function handle it.
     // FIXME gpsim poorly handles this CLI interface. We should send
     // the output of the CLI back to the client socket.
-
     if (packet->DecodeHeader()) {
       ParseObject();
+
     } else {
-      if(parse_string(packet->rxBuff()) >= 0)
+      if (parse_string(packet->rxBuff()) >= 0) {
         Send("+ACK");
-      else
+
+      } else {
         Send("+BUSY");
+      }
     }
   }
-
 }
 
+
 //========================================================================
 // Socket Interface
 
-SocketInterface::SocketInterface(Socket *new_socket)
+SocketInterface::SocketInterface(Socket * )
 //  : sock(new_socket)
 {
 }
-void SocketInterface::SimulationHasStopped (gpointer object)
+
+
+void SocketInterface::SimulationHasStopped(gpointer /* object */ )
 {
 }
-void SocketInterface::Update  (gpointer object)
+
+
+void SocketInterface::Update(gpointer /* object */ )
 {
   /*
   if(sock)
@@ -832,6 +840,7 @@ void SocketInterface::Update  (gpointer object)
   */
 }
 
+
 SocketInterface::~SocketInterface()
 {
   /*
@@ -840,6 +849,7 @@ SocketInterface::~SocketInterface()
   */
 }
 
+
 //========================================================================
 
 SocketLink::SocketLink(unsigned int _handle, SocketBase *sb)
@@ -847,14 +857,18 @@ SocketLink::SocketLink(unsigned int _handle, SocketBase *sb)
 {
 }
 
+
 bool SocketLink::Send(bool bTimeStamp)
 {
-  if(parent) {
+  if (parent) {
     parent->packet->prepare();
     parent->packet->EncodeHeader();
     get(*parent->packet);
-    if(bTimeStamp)
+
+    if (bTimeStamp) {
       parent->packet->EncodeUInt64(get_cycles().get());
+    }
+
     parent->packet->txTerminate();
 
     /*
@@ -864,27 +878,29 @@ bool SocketLink::Send(bool bTimeStamp)
               << parent->packet->txBuff() << endl;
     */
 
-    if(bWaitForResponse) {
+    if (bWaitForResponse) {
       //std::cout << "SocketLink::Send waiting for response\n";
-      if(parent->Send(parent->packet->txBuff()))
+      if (parent->Send(parent->packet->txBuff())) {
         return Receive();
-    } else
+      }
+
+    } else {
       return parent->Send(parent->packet->txBuff());
+    }
   }
 
   return false;
 }
 
+
 bool SocketLink::Receive()
 {
-  if(parent) {
-
+  if (parent) {
     //cout << "SocketLink is waiting for a client response\n";
     parent->packet->prepare();
-
-    int bytes= recv(parent->getSocket(),
-                    parent->packet->rxBuff(),
-                    parent->packet->rxSize(), 0);
+    int bytes = recv(parent->getSocket(),
+                     parent->packet->rxBuff(),
+                     parent->packet->rxSize(), 0);
 
     if (bytes  == -1) {
       perror("recv");
@@ -896,49 +912,60 @@ bool SocketLink::Receive()
     cout << "SocketLink got client response: " << parent->packet->rxBuff() <<
       endl;
     */
-
     return true;
   }
+
   return false;
 }
+
+
 //========================================================================
 AttributeLink::AttributeLink(unsigned int _handle, SocketBase *_sb, Value *_v)
-  : SocketLink(_handle,_sb), v(_v)
+  : SocketLink(_handle, _sb), v(_v)
 {
 }
 
+
 void AttributeLink::set(Packet &p)
 {
-  if(v)
+  if (v) {
     v->set(p);
+  }
 }
 
+
 void AttributeLink::get(Packet &p)
 {
-  if(v)
+  if (v) {
     v->get(p);
+  }
 }
+
+
 //========================================================================
 NotifyLink::NotifyLink(AttributeLink *_sl)
   : Value(), sl(_sl)
 {
   new_name("notifylink");
+  std::cout << "Creating a notify link \n";
 
-  std::cout<< "Creating a notify link \n";
-  if(sl && sl->getValue()) {
+  if (sl && sl->getValue()) {
     Value *v = sl->getValue();
-    std::cout<< "Creating a notify link and asoc with "<< v->name()<<endl;
+    std::cout << "Creating a notify link and asoc with " << v->name() << '\n';
     //FIXME: removed 27JAN06 sl->getValue()->set_xref(this);
   }
 }
-void NotifyLink::set(gint64 i)
+
+
+void NotifyLink::set(gint64 )
 {
   //std::cout << "notify link is sending data back to client\n";
-  if(sl)
+  if (sl) {
     sl->Send(true);
-
+  }
 }
 
+
 //========================================================================
 
 CyclicCallBackLink::CyclicCallBackLink(guint64 i, SocketBase *_sb)
@@ -948,14 +975,16 @@ CyclicCallBackLink::CyclicCallBackLink(guint64 i, SocketBase *_sb)
   get_cycles().set_break(get_cycles().get() + interval, this);
 }
 
+
 void CyclicCallBackLink::callback(void)
 {
   std::cout << " cyclic callback\n ";
-  if(sb) {
+
+  if (sb) {
     static bool bfirst = true;
     static char st[5];
-    static int seq=0;
-    if(bfirst) {
+
+    if (bfirst) {
       bfirst = false;
       st[0] = 'h';
       st[1] = 'e';
@@ -964,106 +993,130 @@ void CyclicCallBackLink::callback(void)
       st[4] = 0;
     }
 
-    if(++st[3] > '9')
+    if (++st[3] > '9') {
       st[3] = '0';
+    }
 
-    if(sb->Send(st))
+    if (sb->Send(st)) {
       get_cycles().set_break(get_cycles().get() + interval, this);
-    else
-      std::cout << "socket callback failed seq:" << seq++ << endl;
-  }
 
+    } else {
+      static int seq = 0;
+
+      std::cout << "socket callback failed seq:" << seq++ << '\n';
+    }
+  }
 }
 
-void CyclicCallBackLink::callback_print(void)
+
+void CyclicCallBackLink::callback_print()
 {
   std::cout << " cyclic callback\n ";
-
 }
+
+
 //========================================================================
 
 AttributeLink *gCreateSocketLink(unsigned int handle, Packet &p, SocketBase *sb)
 {
-
   char tmp[256];
 
-  if(p.DecodeString(tmp,256)) {
-
+  if (p.DecodeString(tmp, 256)) {
     Value *sym = globalSymbolTable().findValue(tmp);
-    if(sym)
-      return new AttributeLink(handle,sb,sym);
+
+    if (sym) {
+      return new AttributeLink(handle, sb, sym);
+    }
   }
 
-  return 0;
+  return nullptr;
 }
 
+
 //////////////////////////////////////////////////////////////////////////
 
 #ifdef USE_THREADS_BUT_NOT_RECOMMENDED_BECAUSE_OF_CROSS_PLATFORM_ISSUES
+
+
 void *server_thread(void *ignored)
 {
   std::cout << "running....\n";
-
   Socket s;
 
-  while ( true )
-    {
-      s.receive();
-    }
+  while (true) {
+    s.receive();
+  }
 
-  return 0;
+  return nullptr;
 }
 
 
 pthread_t thSocketServer;
 pthread_attr_t thAttribute;
-int something=1;
+int something = 1;
 
-void start_server(void)
+
+void start_server()
 {
   std::cout << "starting server....\n";
-
   pthread_attr_init(&thAttribute);
   pthread_attr_setdetachstate(&thAttribute, PTHREAD_CREATE_JOINABLE);
   pthread_create(&thSocketServer, &thAttribute, server_thread, (void *)&something);
-
   std::cout << " started server\n";
 }
+
+
 #else   // if USE_THREADS
 
+
 static void debugPrintChannelStatus(GIOStatus stat)
 {
   switch (stat) {
   case G_IO_STATUS_ERROR:
     std::cout << "G_IO_STATUS_ERROR\n";
     break;
+
   case G_IO_STATUS_NORMAL:
     std::cout << "G_IO_STATUS_NORMAL\n";
     break;
+
   case G_IO_STATUS_EOF:
     std::cout << "G_IO_STATUS_EOF\n";
     break;
+
   case G_IO_STATUS_AGAIN:
     std::cout << "G_IO_STATUS_AGAIN\n";
     break;
   }
 }
 
+
 #if 0 // defined but not used
 static void debugPrintCondition(GIOCondition cond)
 {
-  if(cond & G_IO_IN)
+  if (cond & G_IO_IN) {
     std::cout << "  G_IO_IN\n";
-  if(cond & G_IO_OUT)
+  }
+
+  if (cond & G_IO_OUT) {
     std::cout << "  G_IO_OUT\n";
-  if(cond & G_IO_PRI)
+  }
+
+  if (cond & G_IO_PRI) {
     std::cout << "  G_IO_PRI\n";
-  if(cond & G_IO_ERR)
+  }
+
+  if (cond & G_IO_ERR) {
     std::cout << "  G_IO_ERR\n";
-  if(cond & G_IO_HUP)
+  }
+
+  if (cond & G_IO_HUP) {
     std::cout << "  G_IO_HUP\n";
-  if(cond & G_IO_NVAL)
+  }
+
+  if (cond & G_IO_NVAL) {
     std::cout << "  G_IO_NVAL\n";
+  }
 }
 #endif
 
@@ -1085,57 +1138,53 @@ static void debugPrintCondition(GIOCondition cond)
 
 static gboolean server_callback(GIOChannel *channel,
                                 GIOCondition condition,
-                                void *pSocketBase )
+                                void *pSocketBase)
 {
+  SocketBase *s = static_cast<SocketBase *>(pSocketBase);
 
-
-  SocketBase *s = (SocketBase *)pSocketBase;
-
-  if(condition & G_IO_HUP) {
-    std::cout<< "client has gone away\n";
-
-    GError *err=NULL;
+  if (condition & G_IO_HUP) {
+    std::cout << "client has gone away\n";
+    GError *err = nullptr;
     GIOStatus stat = g_io_channel_shutdown(channel, TRUE, &err);
-    std::cout << "channel status " << hex << stat << "  " ;
+    std::cout << "channel status " << std::hex << stat << "  " ;
     debugPrintChannelStatus(stat);
-
     delete s;
-
     return FALSE;
   }
 
-  if(condition & G_IO_IN) {
-    gsize bytes_read=0;
-
+  if (condition & G_IO_IN) {
+    gsize bytes_read = 0;
     s->packet->prepare();
     memset(s->packet->rxBuff(), 0, 256);
-
-    GError *err=NULL;
+    GError *err = nullptr;
     gsize b;
-
 #if !defined _WIN32 || defined _DEBUG
-    g_io_channel_set_flags (channel, G_IO_FLAG_NONBLOCK, &err);
+    g_io_channel_set_flags(channel, G_IO_FLAG_NONBLOCK, &err);
 #endif
     g_io_channel_read_chars(channel,
-                                   s->packet->rxBuff(),
-                                   s->packet->rxSize(),
-                                   &b,
-                                   &err);
+                            s->packet->rxBuff(),
+                            s->packet->rxSize(),
+                            &b,
+                            &err);
     bytes_read = b;
     s->packet->rxAdvance(bytes_read);
 
-    if(err) {
-      std::cout << "GError:" << err->message << endl;
+    if (err) {
+      std::cout << "GError:" << err->message << '\n';
     }
 
-    if(bytes_read) {
-      if(get_interface().bSimulating()) {
+    if (bytes_read) {
+      if (get_interface().bSimulating()) {
         std::cout << "setting a socket break point because sim is running \n";
         get_bp().set_socket_break();
-      } else
+
+      } else {
         s->Service();
-    } else
+      }
+
+    } else {
       return FALSE;
+    }
 
     return TRUE;
   }
@@ -1143,6 +1192,7 @@ static gboolean server_callback(GIOChannel *channel,
   return FALSE;
 }
 
+
 /*========================================================================
 
   server_accept( )
@@ -1158,55 +1208,48 @@ static gboolean server_callback(GIOChannel *channel,
 
  */
 
-static gboolean sink_server_accept(GIOChannel *channel, GIOCondition condition, void *d )
+static gboolean sink_server_accept(GIOChannel *channel, GIOCondition /* condition */ , void *d)
 {
-  Socket *s = (Socket *)d;
-
+  Socket *s = static_cast<Socket *>(d);
   std::cout << " SourceSink accepting new client connect\n";
-
   SocketBase *client = s->Accept();
 
-  if(!client)
+  if (!client) {
     return FALSE;
+  }
 
   GIOChannel *new_channel = g_io_channel_unix_new(client->getSocket());
   GIOCondition new_condition = (GIOCondition)(G_IO_IN | G_IO_HUP | G_IO_ERR);
-
-  GError *err = NULL;
-
-  g_io_channel_set_encoding (channel, NULL, &err);
+  GError *err = nullptr;
+  g_io_channel_set_encoding(channel, nullptr, &err);
 #if !defined _WIN32 || defined _DEBUG
   //stat = g_io_channel_set_flags (channel, G_IO_FLAG_SET_MASK, &err);
-  g_io_channel_set_flags (channel, G_IO_FLAG_NONBLOCK, &err);
+  g_io_channel_set_flags(channel, G_IO_FLAG_NONBLOCK, &err);
 #endif
-
   g_io_add_watch(new_channel,
                  new_condition,
                  server_callback,
                  (void*)client);
-
   return TRUE;
 }
 
 
-static gboolean source_server_accept(GIOChannel *channel, GIOCondition condition, void *d )
+static gboolean source_server_accept(GIOChannel * /* channel */ , GIOCondition /* condition */ , void *d)
 {
-  Socket *s = (Socket *)d;
-
+  Socket *s = static_cast<Socket *>(d);
   std::cout << " SourceServer accepting new client connect\n";
-
   SocketBase *client = s->Accept();
   std::cout << " SourceServer accepted connection\n";
 
-  if(!client)
+  if (!client) {
     return FALSE;
+  }
 
-  int bytes= recv(client->getSocket(),
-                  client->packet->rxBuff(),
-                  client->packet->rxSize(), 0);
-
+  int bytes = recv(client->getSocket(),
+                   client->packet->rxBuff(),
+                   client->packet->rxSize(), 0);
   std::cout << " SourceServer received data" << client->packet->rxBuff()
-            << endl;
+            << '\n';
 
   if (bytes  == -1) {
     perror("recv");
@@ -1214,58 +1257,51 @@ static gboolean source_server_accept(GIOChannel *channel, GIOCondition condition
   }
 
   client->packet->rxAdvance(bytes);
-
   client->Service();
-
   std::cout << " SourceServer serviced client\n";
-
   // FIXME: SocketBase *client goes out of scope almost certainly leaking resources.
-
   return TRUE;
 }
 
-void start_server(void)
+
+void start_server()
 {
   //  TestInt32Array *test = new TestInt32Array("test",16);
   //  symbol_table.add(test);
-
   std::cout << "starting server....\n";
-
 #ifdef _WIN32
+
   if (!winsockets_init()) {
     fprintf(stderr, "Could not find a usable WinSock DLL, sockets are disabled.\n");
     server_started = false;
     return;
   }
+
   server_started = true;
 #endif
-
   // Create the Sink and Source servers
-
   static Socket sinkServer;
-
   sinkServer.init(SIM_SINK_PORT);
   sinkServer.AssignChannel(sink_server_accept);
   get_interface().add_interface(new SocketInterface(&sinkServer));
-
-
-
   static Socket sourceServer;
   sourceServer.init(SIM_SOURCE_PORT);
   sourceServer.AssignChannel(source_server_accept);
-
   std::cout << " started server\n";
-
-
 }
 
 
-void stop_server(void)
+void stop_server()
 {
 #ifdef _WIN32
-  if (server_started)
+
+  if (server_started) {
     WSACleanup();
+  }
+
 #endif
 }
+
+
 #endif   // if USE_THREADS
 
