@@ -19,11 +19,10 @@ the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
 
-#if !defined(__SSD0323_H__)
-#define __SSD0323_H__
+#ifndef EXTRAS_GRAPHIC_LCD_SRC_SSD0323_H_
+#define EXTRAS_GRAPHIC_LCD_SRC_SSD0323_H_
 
-class SSD0323
-{
+class SSD0323 {
   enum {
     e8080Mode = 6,
     e6800Mode = 4,
@@ -36,7 +35,7 @@ class SSD0323
     eRES   = 2,          // /Reset /Reset /Reset
     eE_RD  = 4,          // /Rd    Enable /Enable
     eRW    = 8,          // /Wr    Rd /Wr /Wr
-    eDC    = 0x10        // D /C   D /C   D /C   --- Data /Command 
+    eDC    = 0x10        // D /C   D /C   D /C   --- Data /Command
   };
 
 public:
@@ -65,15 +64,14 @@ public:
   unsigned int getData();
   unsigned int getStatus();
 
-  inline unsigned int &operator[] (unsigned int index)
+  inline unsigned int &operator[](unsigned int index)
   {
-    return (index < 128*80/2) ?  m_ram[index] : prBadRam(index);
+    return (index < 128 * 80 / 2) ?  m_ram[index] : prBadRam(index);
   }
 
   void showState();
 
 private:
-
   void advanceColumnAddress();
   void advanceRowAddress();
 
@@ -84,7 +82,7 @@ private:
   unsigned int m_controlState;
   unsigned int m_dataBus;
 
-  // Communication - 
+  // Communication -
   // The commMode selects one of three possible communication modes
   // The commState holds the communication state for that mode.
 
@@ -97,16 +95,22 @@ private:
   unsigned int m_expectedCommandWords;
   unsigned char cmdWords[20];
 
-  // Display ram
-  unsigned int m_ram[128*80/2];
+  // Display ram + one for bad memory access
+  unsigned int m_ram[(128 * 80 / 2) + 1];
 
   // State information
   unsigned int m_colAddr;
   unsigned int m_rowAddr;
 
   // helper functions
-  bool bEnabled() { return (m_controlState &(eCS|eRES)) == eRES; }
-  bool bBitState(unsigned int b) { return (m_controlState&b)==b; }
+  bool bEnabled()
+  {
+    return (m_controlState & (eCS | eRES)) == eRES;
+  }
+  bool bBitState(unsigned int b)
+  {
+    return (m_controlState & b) == b;
+  }
   void abortCurrentTransaction();
 
   // configuration data controlled by the SSD0323 commands
@@ -118,4 +122,4 @@ private:
   unsigned int m_ContrastControl;
 };
 
-#endif // __SSD0323_H__
+#endif 
