@@ -19,8 +19,8 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __GUI_BREADBOARD_H__
-#define __GUI_BREADBOARD_H__
+#ifndef GUI_GUI_BREADBOARD_H_
+#define GUI_GUI_BREADBOARD_H_
 
 #include "../src/packages.h"
 #include "../src/stimuli.h"
@@ -44,18 +44,19 @@ enum eDirection {PIN_INPUT, PIN_OUTPUT};
 typedef enum {PIN_DIGITAL, PIN_ANALOG, PIN_OTHER} pintype;
 
 // Routing types
-typedef enum {R_NONE,R_LEFT, R_RIGHT, R_UP, R_DOWN} route_direction;
+typedef enum {R_NONE, R_LEFT, R_RIGHT, R_UP, R_DOWN} route_direction;
+
 class point {
 public:
   int x;
   int y;
 };
 
+
 class path {
 public:
   point p;
   route_direction dir;
-  path *next;
 };
 // End routing types
 
@@ -68,24 +69,40 @@ class GuiModule;
 //                       breadboard window.
 //
 
-class GuiBreadBoardObject
-{
+class GuiBreadBoardObject {
 public:
-  GuiBreadBoardObject(Breadboard_Window *,int x, int y);
+  GuiBreadBoardObject(Breadboard_Window *, int x, int y);
   virtual ~GuiBreadBoardObject();
 
-  virtual void Draw()=0;
-  virtual void Update()=0;
-  virtual void Destroy()=0;
+  virtual void Draw() = 0;
+  virtual void Update() = 0;
+  virtual void Destroy() = 0;
 
-
-  bool IsBuilt() { return m_bIsBuilt;}
-  Breadboard_Window *bbw() { return m_bbw;}
+  bool IsBuilt()
+  {
+    return m_bIsBuilt;
+  }
+  Breadboard_Window *bbw()
+  {
+    return m_bbw;
+  }
   void SetPosition(int x, int y);
-  int x()      { return m_x;}
-  int y()      { return m_y;}
-  int width()  { return m_width; }
-  int height() { return m_height; }
+  int x()
+  {
+    return m_x;
+  }
+  int y()
+  {
+    return m_y;
+  }
+  int width()
+  {
+    return m_width;
+  }
+  int height()
+  {
+    return m_height;
+  }
 
 protected:
   Breadboard_Window *m_bbw;
@@ -97,14 +114,20 @@ protected:
   bool   m_bIsBuilt;        // True after the object gets displayed.
 };
 
+
 //------------------------------------------------------------------------
 // GuiPin
-class GuiPin : public GuiBreadBoardObject
-{
+class GuiPin : public GuiBreadBoardObject {
 public:
-  GuiPin(Breadboard_Window *, GuiModule *,Package *, unsigned int pin_number);
-  bool getState() {return value;}
-  void putState(bool bNewState) { value = bNewState;}
+  GuiPin(Breadboard_Window *, GuiModule *, Package *, unsigned int pin_number);
+  bool getState()
+  {
+    return value;
+  }
+  void putState(bool bNewState)
+  {
+    value = bNewState;
+  }
   void toggleState();
   void toggleDirection();
 
@@ -114,20 +137,44 @@ public:
   virtual void Destroy();
 
   void SetModulePosition(int x, int y);
-  int module_x() { return m_module_x; }
-  int module_y() { return m_module_y; }
+  int module_x()
+  {
+    return m_module_x;
+  }
+  int module_y()
+  {
+    return m_module_y;
+  }
 
   void SetLabelPosition(int x, int y);
-  int label_x() { return m_label_x; }
-  int label_y() { return m_label_y; }
+  int label_x()
+  {
+    return m_label_x;
+  }
+  int label_y()
+  {
+    return m_label_y;
+  }
   bool DrawGUIlabel();
   void DrawLabel(cairo_t *cr);
 
-  void SetOrientation(eOrientation o) { orientation = o; }
+  void SetOrientation(eOrientation o)
+  {
+    orientation = o;
+  }
 
-  unsigned int number() { return m_pkgPinNumber; }
-  Stimulus_Node *getSnode() {return getIOpin() ? getIOpin()->snode : 0;}
-  IOPIN *getIOpin() {return package->get_pin(m_pkgPinNumber);}
+  unsigned int number()
+  {
+    return m_pkgPinNumber;
+  }
+  Stimulus_Node *getSnode()
+  {
+    return getIOpin() ? getIOpin()->snode : nullptr;
+  }
+  IOPIN *getIOpin()
+  {
+    return package->get_pin(m_pkgPinNumber);
+  }
   const char *pinName();
 
   GtkWidget *m_pinDrawingArea;
@@ -138,7 +185,7 @@ public:
 
 protected:
   bool   value;
-//  IOPIN *iopin;
+  //  IOPIN *iopin;
   Package *package;
   CrossReferenceToGUI *xref;
 
@@ -153,7 +200,7 @@ protected:
 
 private:
   static gboolean expose_pin(GtkWidget *widget, GdkEventExpose *event,
-    GuiPin *p);
+                             GuiPin *p);
 };
 
 
@@ -164,12 +211,16 @@ public:
   BB_ModuleLabel(const std::string &text, PangoFontDescription *font);
   ~BB_ModuleLabel();
 
-  GtkWidget *gobj() {return m_label;}
+  GtkWidget *gobj()
+  {
+    return m_label;
+  }
 
 private:
   GtkWidget *m_label;
 };
 
+
 //------------------------------------------------------------------------
 // GuiModule
 //
@@ -181,10 +232,10 @@ private:
 // All GuiModules have a one-to-one with a gpsim Module. (see src/modules.h)
 // The GuiModule knows how to get access to a Module's pin information.
 //
-class GuiModule : public GuiBreadBoardObject
-{
+class GuiModule : public GuiBreadBoardObject {
 public:
   GuiModule(Module *, Breadboard_Window *);
+
   void SetPosition(int x, int y);
   void GetPosition(int &x, int &y);
   double Distance(int x, int y);
@@ -199,15 +250,32 @@ public:
   virtual void AddPin(unsigned int);
   virtual void AddPinGeometry(GuiPin *);
 
-  int pin_count() { return m_pin_count; }
-  std::vector<GuiPin *> * pins() { return &m_pins; }
-  Module *module() { return m_module; }
-  GtkWidget *module_widget() { return m_module_widget; }
-  GtkWidget *pinLabel_widget() { return m_pinLabel_widget; }
-  GtkWidget *name_widget() { return m_name_widget->gobj(); }
+  int pin_count()
+  {
+    return m_pin_count;
+  }
+  std::vector<GuiPin *> * pins()
+  {
+    return &m_pins;
+  }
+  Module *module()
+  {
+    return m_module;
+  }
+  GtkWidget *module_widget()
+  {
+    return m_module_widget;
+  }
+  GtkWidget *pinLabel_widget()
+  {
+    return m_pinLabel_widget;
+  }
+  GtkWidget *name_widget()
+  {
+    return m_name_widget->gobj();
+  }
 
 protected:
-
   Module    *m_module;
   GtkWidget *m_module_widget;  // As returned from module. If NULL, it becomes a static GtkPixmap
   GtkWidget *m_pinLabel_widget;// A drawing area for pin labels.
@@ -226,24 +294,22 @@ private:
   static gboolean module_expose(GtkWidget *widget, GdkEventExpose *event, GuiModule *p);
 };
 
-class GuiDipModule : public GuiModule
-{
+
+class GuiDipModule : public GuiModule {
 public:
   GuiDipModule(Module *, Breadboard_Window *);
   virtual void DrawCaseOutline(cairo_t *);
 };
 
-struct gui_node
-{
-    Breadboard_Window *bbw;
-    Stimulus_Node *node;
-    GtkWidget *tree_item;
+
+struct gui_node {
+  Breadboard_Window *bbw;
+  Stimulus_Node *node;
+  GtkWidget *tree_item;
 };
 
 
-
-class Breadboard_Window : public GUI_Object
-{
+class Breadboard_Window : public GUI_Object {
 public:
 
   PangoFontDescription *pinstatefont;
@@ -282,11 +348,11 @@ public:
   GuiModule *selected_module;
 
   explicit Breadboard_Window(GUI_Processor *gp);
-  ~Breadboard_Window();
+  virtual ~Breadboard_Window();
 
-  virtual void Build(void);
+  virtual void Build();
   virtual void NewProcessor(GUI_Processor *gp);
-  virtual void Update(void);
+  virtual void Update();
   virtual void NewModule(Module *module);
   virtual void NodeConfigurationChanged(Stimulus_Node *node);
 
@@ -295,23 +361,22 @@ public:
   void clear_nodes();
 
   GtkWidget *status_line;
-protected:
-  virtual const char *name();
 
 private:
-
+  GtkWidget *bb_vbox();
+  GtkWidget *bb_hbox();
   GtkWidget *add_button(const char *label, GCallback f, GtkWidget *box);
 
   static void pointer_cb(GtkWidget *w, GdkEventButton *event,
-    Breadboard_Window *bbw);
+                         Breadboard_Window *bbw);
+  static void remove_module(GtkWidget *button, Breadboard_Window *bbw);
 
   GuiModule *m_MainCpuModule;
 
   static gboolean layout_expose(GtkWidget *widget,
-    GdkEventExpose *event, Breadboard_Window *bbw);
+                                GdkEventExpose *event, Breadboard_Window *bbw);
 };
 
 
-
-#endif //__GUI_BREADBOARD_H__
+#endif // GUI_GUI_BREADBOARD_H_
 
