@@ -34,8 +34,8 @@ class linkXREF : public CrossReferenceToGUI
 public:
 
   GUI_Processor *gp;
-  
-  virtual void Update(int new_value)
+
+  virtual void Update(int /* new_value */)
   {
     int address;
 
