@@ -61,8 +61,8 @@ void link_src_to_gpsim(GUI_Processor *gp);
  * --- Global variables
  */
 
-GUI_Processor *gpGuiProcessor=0;
-unsigned int interface_id=0;
+GUI_Processor *gpGuiProcessor;
+unsigned int interface_id;
 
 Settings *settings;
 
@@ -93,7 +93,7 @@ private:
 
 public:
 
-  virtual void UpdateObject (gpointer xref,int new_value);
+  virtual void UpdateObject (gpointer xref, int new_value);
   virtual void RemoveObject (gpointer xref);
   virtual void SimulationHasStopped (gpointer object);
   virtual void NewProcessor (Processor *);
@@ -105,20 +105,18 @@ public:
   virtual ~GUI_Interface();
 
   explicit GUI_Interface(GUI_Processor *_gp);
-
 };
 
 
-GUI_Interface::GUI_Interface(GUI_Processor *_gp) : Interface ( (gpointer *) _gp)
+GUI_Interface::GUI_Interface(GUI_Processor *_gp)
+  : Interface ( (gpointer *) _gp)
 {
-
   gp = _gp;
-
 }
 
 GUI_Interface::~GUI_Interface()
 {
-  if(gp) {
+  if (gp) {
     gp->regwin_ram->set_config();
     gp->regwin_eeprom->set_config();
     gp->program_memory->set_config();
@@ -146,11 +144,11 @@ GUI_Interface::~GUI_Interface()
  * this list and updates each instance of the object.
  */
 
-void GUI_Interface::UpdateObject(gpointer gui_xref,int new_value)
+void GUI_Interface::UpdateObject(gpointer gui_xref, int new_value)
 {
   CrossReferenceToGUI  *xref = static_cast<CrossReferenceToGUI *>(gui_xref);
   xref->Update(new_value);
- }
+}
 
 /*------------------------------------------------------------------
  * RemoveObject
@@ -172,7 +170,7 @@ extern int gui_animate_delay; // in milliseconds
 
 void GUI_Interface::SimulationHasStopped(gpointer callback_data)
 {
-  if(callback_data) {
+  if (callback_data) {
     GUI_Processor *lgp = static_cast<GUI_Processor *>(callback_data);
 
     while (gtk_events_pending())
@@ -190,7 +188,9 @@ void GUI_Interface::SimulationHasStopped(gpointer callback_data)
     lgp->stopwatch_window->Update();
     lgp->scope_window->Update();
 
-    if (gui_animate_delay!=0)
+// TODO: should have an alternative way of doing a delay.
+// This causes the GUI to become unresponsive.
+    if (gui_animate_delay != 0)
       g_usleep(1000 * gui_animate_delay);
 
     dispatch_Update();
@@ -207,9 +207,8 @@ void GUI_Interface::SimulationHasStopped(gpointer callback_data)
  * a communication link between the gui and the simulator is established.
  */
 
-void GUI_Interface::NewProcessor (Processor *new_cpu)
+void GUI_Interface::NewProcessor(Processor *new_cpu)
 {
-
   // Create a gui representation of the new processor
 
   if(gp) {
@@ -235,9 +234,8 @@ void GUI_Interface::NewProcessor (Processor *new_cpu)
 /*------------------------------------------------------------------
  *
  */
-void GUI_Interface::NewModule (Module *module)
+void GUI_Interface::NewModule(Module *module)
 {
-
   // FIX ME - need to search for *p in the gp list...
   if(gp)
     gp->breadboard_window->NewModule(module);
@@ -246,9 +244,8 @@ void GUI_Interface::NewModule (Module *module)
 /*------------------------------------------------------------------
  *
  */
-void GUI_Interface::NodeConfigurationChanged (Stimulus_Node *node)
+void GUI_Interface::NodeConfigurationChanged(Stimulus_Node *node)
 {
-
   // FIX ME - need to search for *p in the gp list...
   if(gp)
     gp->breadboard_window->NodeConfigurationChanged(node);
@@ -257,10 +254,9 @@ void GUI_Interface::NodeConfigurationChanged (Stimulus_Node *node)
 /*------------------------------------------------------------------
  *
  */
-void GUI_Interface::NewProgram (Processor *new_cpu)
+void GUI_Interface::NewProgram(Processor *)
 {
-
-  if(gp) {
+  if (gp) {
     gp->regwin_eeprom->NewProcessor(gp);
 
     gp->source_browser->CloseSource();
@@ -283,9 +279,9 @@ void GUI_Interface::Update(gpointer object)
  * quit_gui
  *
  */
-void quit_gui(void)
+void quit_gui()
 {
-  if(!get_interface().bUsingGUI())
+  if (!get_interface().bUsingGUI())
     return;
 
   int x, y, width, height;
@@ -309,7 +305,7 @@ void quit_gui(void)
  *
  */
 
-int gui_init (int argc, char **argv)
+int gui_init(int argc, char **argv)
 {
 #ifndef _WIN32
   settings = new SettingsEXdbm("gpsim");
@@ -317,9 +313,8 @@ int gui_init (int argc, char **argv)
   settings = new SettingsReg("gpsim");
 #endif
 
-  if (!gtk_init_check (&argc, &argv))
-  {
-      return -1;
+  if (!gtk_init_check(&argc, &argv)) {
+    return -1;
   }
 
   // standardize IO format ref bug 1832702
@@ -328,7 +323,7 @@ int gui_init (int argc, char **argv)
   gpGuiProcessor = new GUI_Processor();
   interface_id = get_interface().add_interface(new GUI_Interface(gpGuiProcessor));
 
-  return(0);
+  return 0;
 }
 
 void gui_main()
