@@ -31,7 +31,6 @@ Boston, MA 02111-1307, USA.  */
 
 #include "gui.h"
 #include "preferences.h"
-#include "gui_callbacks.h"
 #include "gui_breadboard.h"
 #include "gui_processor.h"
 #include "gui_profile.h"
@@ -54,9 +53,9 @@ GtkUIManager *ui;
 extern GUI_Processor *gpGuiProcessor;
 
 static void
-do_quit_app(GtkWidget *widget)
+do_quit_app(GtkWidget *)
 {
-        exit_gpsim(0);
+  exit_gpsim(0);
 }
 
 
@@ -69,7 +68,7 @@ static const gchar * const authors[] = {
 };
 
 static void
-about_cb(GtkAction *action, gpointer user_data)
+about_cb(GtkAction *, gpointer)
 {
   gtk_show_about_dialog(NULL,
     "authors", authors,
@@ -249,12 +248,12 @@ private:
 };
 
 
-void gpsimGuiPreferences::setup (GtkAction *action, gpointer user_data)
+void gpsimGuiPreferences::setup(GtkAction *, gpointer)
 {
   new gpsimGuiPreferences();
 }
 
-void gpsimGuiPreferences::response_cb(GtkDialog *dialog, gint response_id,
+void gpsimGuiPreferences::response_cb(GtkDialog *, gint response_id,
   gpsimGuiPreferences *Self)
 {
   if (response_id == gint(GTK_RESPONSE_CANCEL))
@@ -268,7 +267,7 @@ void gpsimGuiPreferences::response_cb(GtkDialog *dialog, gint response_id,
 //------------------------------------------------------------------------
 // ColorButton Constructor
 ColorButton::ColorButton(GtkWidget *pParent, GtkTextTag *pStyle,
-                         const char *colorName, SourceBrowserPreferences *prefs)
+                         const char *colorName, SourceBrowserPreferences *)
   : m_pStyle(pStyle)
 {
   GtkWidget *hbox        = gtk_hbox_new(0,0);
@@ -339,11 +338,12 @@ MarginButton::MarginButton(GtkWidget *pParent, const char *pName,
                       this);
 }
 //------------------------------------------------------------------------
-void MarginButton::toggle_cb(GtkToggleButton *widget,
+void MarginButton::toggle_cb(GtkToggleButton *,
                              MarginButton    *This)
 {
   This->set_active();
 }
+
 void MarginButton::set_active()
 {
   bool bNewState = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_button)) ? true : false;
@@ -375,11 +375,12 @@ TabButton::TabButton(GtkWidget *pParent, GtkWidget *pButton,
                       this);
 }
 //------------------------------------------------------------------------
-void TabButton::toggle_cb(GtkToggleButton *widget,
+void TabButton::toggle_cb(GtkToggleButton *,
                           TabButton    *This)
 {
   This->set_active();
 }
+
 void TabButton::set_active()
 {
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_button)))
@@ -415,11 +416,12 @@ FontSelection::FontSelection (GtkWidget *pParent,
   gtk_widget_show (hbox);
 }
 //------------------------------------------------------------------------
-void FontSelection::setFont_cb (GtkFontButton *pFontButton,
+void FontSelection::setFont_cb (GtkFontButton *,
                                 FontSelection *This)
 {
   This->setFont();
 }
+
 void FontSelection::setFont()
 {
   m_prefs->setFont(gtk_font_button_get_font_name (GTK_FONT_BUTTON(m_fontButton)));
@@ -427,13 +429,13 @@ void FontSelection::setFont()
 
 //------------------------------------------------------------------------
 
-void SourceBrowserPreferences::toggleBreak(int line)
+void SourceBrowserPreferences::toggleBreak(int)
 {
 
 }
 
 
-void SourceBrowserPreferences::movePC(int line)
+void SourceBrowserPreferences::movePC(int)
 {
 }
 
@@ -633,19 +635,22 @@ void SourceBrowserPreferences::cancel()
   m_pParent->setTabPosition(m_originalTabPosition);
 }
 
-int SourceBrowserPreferences::getPCLine(int page)
+int SourceBrowserPreferences::getPCLine(int)
 {
   return 1;
 }
-int SourceBrowserPreferences::getAddress(NSourcePage *pPage, int line)
+
+int SourceBrowserPreferences::getAddress(NSourcePage *, int)
 {
   return 0x1234;
 }
-bool SourceBrowserPreferences::bAddressHasBreak(int address)
+
+bool SourceBrowserPreferences::bAddressHasBreak(int)
 {
   return false;
 }
-int SourceBrowserPreferences::getOpcode(int address)
+
+int SourceBrowserPreferences::getOpcode(int)
 {
   return 0xABCD;
 }
@@ -686,7 +691,7 @@ gpsimGuiPreferences::~gpsimGuiPreferences()
 
 void gui_message(const char *message);
 
-static void update_preview(GtkFileChooser *file_chooser, gpointer data)
+static void update_preview(GtkFileChooser *file_chooser, gpointer)
 {
   gchar *file = gtk_file_chooser_get_preview_filename(file_chooser);
   gboolean show = FALSE;
@@ -713,15 +718,13 @@ static void file_selection_changed(GtkTreeSelection *sel, gpointer data)
   if (gtk_tree_selection_get_selected(sel, &model, &iter)) {
     gtk_tree_model_get (model, &iter, 0, &processor, -1);
     gchar *p = *d;
-    if (p) {
-      g_free(p);
-    }
+    g_free(p);
     *d = processor;
   }
 }
 
 static void
-fileopen_dialog(GtkAction *action, gpointer user_data)
+fileopen_dialog(GtkAction *, gpointer)
 {
   GtkWidget *dialog = gtk_file_chooser_dialog_new("Open file",
     NULL,
@@ -803,6 +806,9 @@ fileopen_dialog(GtkAction *action, gpointer user_data)
         "Open failed. Could not open \"%s\"", filename);
       gui_message(msg);
       g_free(msg);
+    } else {
+      GtkAction *menu_item = gtk_ui_manager_get_action(ui, "/menu/FileMenu/Open");
+      gtk_action_set_sensitive(menu_item, FALSE);
     }
     g_free(filename);
   }
@@ -818,7 +824,7 @@ fileopen_dialog(GtkAction *action, gpointer user_data)
 
 // Menuhandler for Windows menu buttons
 static void
-toggle_window(GtkToggleAction *action, gpointer user_data)
+toggle_window(GtkToggleAction *action, gpointer)
 {
   if (gpGuiProcessor) {
     std::string item = gtk_action_get_name(GTK_ACTION(action));
@@ -855,44 +861,43 @@ toggle_window(GtkToggleAction *action, gpointer user_data)
 //========================================================================
 // Button callbacks
 static void
-runbutton_cb(GtkWidget *widget)
+runbutton_cb(GtkWidget *)
 {
   get_interface().start_simulation();
 }
 
 static void
-stopbutton_cb(GtkWidget *widget)
+stopbutton_cb(GtkWidget *)
 {
-  if(gpGuiProcessor && gpGuiProcessor->cpu)
+  if (gpGuiProcessor && gpGuiProcessor->cpu)
     gpGuiProcessor->cpu->pma->stop();
 }
 
 static void
-stepbutton_cb(GtkWidget *widget)
+stepbutton_cb(GtkWidget *)
 {
-  if(gpGuiProcessor && gpGuiProcessor->cpu)
+  if (gpGuiProcessor && gpGuiProcessor->cpu)
     gpGuiProcessor->cpu->pma->step(1);
 }
 
 static void
-overbutton_cb(GtkWidget *widget)
+overbutton_cb(GtkWidget *)
 {
-  if(gpGuiProcessor && gpGuiProcessor->cpu)
+  if (gpGuiProcessor && gpGuiProcessor->cpu)
     gpGuiProcessor->cpu->pma->step_over();
-
 }
 
 static void
-finishbutton_cb(GtkWidget *widget)
+finishbutton_cb(GtkWidget *)
 {
-  if(gpGuiProcessor && gpGuiProcessor->cpu)
+  if (gpGuiProcessor && gpGuiProcessor->cpu)
     gpGuiProcessor->cpu->pma->finish();
 }
 
 static void
-resetbutton_cb(GtkWidget *widget)
+resetbutton_cb(GtkWidget *)
 {
-  if(gpGuiProcessor && gpGuiProcessor->cpu)
+  if (gpGuiProcessor && gpGuiProcessor->cpu)
     gpGuiProcessor->cpu->reset(POR_RESET);
 }
 
@@ -1223,39 +1228,39 @@ TimeWidget::TimeWidget()
 
 
 //========================================================================
-static int dispatcher_delete_event(GtkWidget *widget,
-                                   GdkEvent  *event,
-                                   gpointer data)
+static int dispatcher_delete_event(GtkWidget *,
+                                   GdkEvent  *,
+                                   gpointer)
 {
-    do_quit_app(0);
+  do_quit_app(0);
 
-    return 0;
+  return 0;
 }
 
 static const GtkActionEntry entries[] = {
-  {"FileMenu", NULL, "_File"},
+  {"FileMenu", NULL, "_File", nullptr, nullptr, nullptr},
   {"Open", GTK_STOCK_OPEN, "_Open", "<control>O", NULL, G_CALLBACK(fileopen_dialog)},
   {"Quit", GTK_STOCK_QUIT, "_Quit", "<control>Q", "Quit", G_CALLBACK(do_quit_app)},
-  {"Windows", NULL, "_Windows"},
-  {"Edit", NULL, "_Edit"},
+  {"Windows", NULL, "_Windows", nullptr, nullptr, nullptr},
+  {"Edit", NULL, "_Edit", nullptr, nullptr, nullptr},
   {"Preferences", GTK_STOCK_PREFERENCES, "Preferences", NULL, NULL, G_CALLBACK(gpsimGuiPreferences::setup)},
-  {"Help", NULL, "_Help"},
+  {"Help", NULL, "_Help", nullptr, nullptr, nullptr},
   {"About", GTK_STOCK_ABOUT, "_About", NULL, NULL, G_CALLBACK(about_cb)}
 };
 
 static const GtkToggleActionEntry toggle_entries[] = {
-  {"Program memory", NULL, "Program _memory", NULL, NULL, G_CALLBACK(toggle_window)},
-  {"Source", NULL, "_Source", NULL, NULL, G_CALLBACK(toggle_window)},
-  {"Ram", NULL, "_Ram", NULL, NULL, G_CALLBACK(toggle_window)},
-  {"EEPROM", NULL, "_EEPROM", NULL, NULL, G_CALLBACK(toggle_window)},
-  {"Watch", NULL, "_Watch", NULL, NULL, G_CALLBACK(toggle_window)},
-  {"Stack", NULL, "Sta_ck", NULL, NULL, G_CALLBACK(toggle_window)},
-  {"Symbols", NULL, "Symbo_ls", NULL, NULL, G_CALLBACK(toggle_window)},
-  {"Breadboard", NULL, "_Breadboard", NULL, NULL, G_CALLBACK(toggle_window)},
-  {"Trace", NULL, "_Trace", NULL, NULL, G_CALLBACK(toggle_window)},
-  {"Profile", NULL, "Pro_file", NULL, NULL, G_CALLBACK(toggle_window)},
-  {"Stopwatch", NULL, "St_opwatch", NULL, NULL, G_CALLBACK(toggle_window)},
-  {"Scope", NULL, "Sco_pe", NULL, NULL, G_CALLBACK(toggle_window)}
+  {"Program memory", NULL, "Program _memory", NULL, NULL, G_CALLBACK(toggle_window), FALSE},
+  {"Source", NULL, "_Source", NULL, NULL, G_CALLBACK(toggle_window), FALSE},
+  {"Ram", NULL, "_Ram", NULL, NULL, G_CALLBACK(toggle_window), FALSE},
+  {"EEPROM", NULL, "_EEPROM", NULL, NULL, G_CALLBACK(toggle_window), FALSE},
+  {"Watch", NULL, "_Watch", NULL, NULL, G_CALLBACK(toggle_window), FALSE},
+  {"Stack", NULL, "Sta_ck", NULL, NULL, G_CALLBACK(toggle_window), FALSE},
+  {"Symbols", NULL, "Symbo_ls", NULL, NULL, G_CALLBACK(toggle_window), FALSE},
+  {"Breadboard", NULL, "_Breadboard", NULL, NULL, G_CALLBACK(toggle_window), FALSE},
+  {"Trace", NULL, "_Trace", NULL, NULL, G_CALLBACK(toggle_window), FALSE},
+  {"Profile", NULL, "Pro_file", NULL, NULL, G_CALLBACK(toggle_window), FALSE},
+  {"Stopwatch", NULL, "St_opwatch", NULL, NULL, G_CALLBACK(toggle_window), FALSE},
+  {"Scope", NULL, "Sco_pe", NULL, NULL, G_CALLBACK(toggle_window), FALSE}
 };
 
 static const gchar *ui_info =
