@@ -627,27 +627,17 @@ void Profile_Window::NewProgram(GUI_Processor *_gp)
  *
  */
 
-void Profile_Window::NewProcessor(GUI_Processor *_gp)
+void Profile_Window::NewProcessor(GUI_Processor *)
 {
-
-  if(!gp)
+  if (!gp)
     return;
 
-  if(!enabled)
+  if (!enabled)
     return;
 }
 
-static int delete_event(GtkWidget *widget,
-                        GdkEvent  *event,
-                        Profile_Window *rw)
-{
-  rw->ChangeView(VIEW_HIDE);
-
-  return TRUE;
-}
-
 // Call-back to format an address for the cell renderer
-static void address_data_func(GtkTreeViewColumn *tree_column,
+static void address_data_func(GtkTreeViewColumn *,
   GtkCellRenderer *renderer,
   GtkTreeModel *tree_model,
   GtkTreeIter *iter,
@@ -665,7 +655,7 @@ static void address_data_func(GtkTreeViewColumn *tree_column,
 }
 
 // Call-back to format the count for the cell renderer
-static void cycles_data_func(GtkTreeViewColumn *tree_column,
+static void cycles_data_func(GtkTreeViewColumn *,
   GtkCellRenderer *renderer,
   GtkTreeModel *tree_model,
   GtkTreeIter *iter,
@@ -683,7 +673,7 @@ static void cycles_data_func(GtkTreeViewColumn *tree_column,
 }
 
 // Call-back to formation floating point information
-static void float_data_func(GtkTreeViewColumn *tree_column,
+static void float_data_func(GtkTreeViewColumn *,
   GtkCellRenderer *renderer,
   GtkTreeModel *tree_model,
   GtkTreeIter *iter,
@@ -702,19 +692,15 @@ static void float_data_func(GtkTreeViewColumn *tree_column,
 
 void Profile_Window::Build()
 {
-  if(bIsBuilt)
+  if (bIsBuilt)
     return;
 
   GtkWidget *label;
   GtkWidget *main_vbox;
   GtkWidget *scrolled_window;
 
-  window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  g_signal_connect(window, "delete_event",
-                     G_CALLBACK (delete_event), this);
-
-  main_vbox=gtk_vbox_new(FALSE,1);
-  gtk_container_set_border_width(GTK_CONTAINER(main_vbox),0);
+  main_vbox = gtk_vbox_new(FALSE, 1);
+  gtk_container_set_border_width(GTK_CONTAINER(main_vbox), 0);
   gtk_container_add(GTK_CONTAINER(window), main_vbox);
   gtk_widget_show(main_vbox);
 
@@ -908,21 +894,13 @@ void Profile_Window::Build()
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook),scrolled_window,label);
   ///////////////////////////////////////////////////
 
+  gtk_widget_show(window);
 
-  gtk_window_set_default_size(GTK_WINDOW(window), width, height);
-  gtk_window_move(GTK_WINDOW(window), x, y);
-  gtk_window_set_wmclass(GTK_WINDOW(window), name(), "Gpsim");
-
-  g_signal_connect_after(window, "configure_event",
-                           G_CALLBACK (gui_object_configure_event),this);
-
-  gtk_widget_show (window);
-
-  bIsBuilt=true;
+  bIsBuilt = true;
 
   NewProcessor(gp);
 
-  if(program)
+  if (program)
     NewProgram(gp);
 
   Update();
@@ -930,21 +908,15 @@ void Profile_Window::Build()
   UpdateMenuItem();
 }
 
-const char *Profile_Window::name()
-{
-  return "profile";
-}
-
 Profile_Window::Profile_Window(GUI_Processor *_gp)
-  : program(0), histogram_profile_list(0)
+  : GUI_Object("profile"),
+    program(0), histogram_profile_list(0)
 {
   menu = "/menu/Windows/Profile";
 
   gp = _gp;
 
-  get_config();
-
-  if(enabled)
+  if (enabled)
       Build();
 }
 
