@@ -104,10 +104,14 @@ public:
 };
 
 inline GUIRegister *GUIRegisterList::Get(int iAddress) {
+   if (iAddress >= MAX_REGISTERS)
+	return nullptr;
   return m_paRegisters[iAddress];
 }
 
 inline GUIRegister *GUIRegisterList::Get(unsigned int uAddress) {
+  if (uAddress >= MAX_REGISTERS)
+	return nullptr;
   return m_paRegisters[uAddress];
 }
 
