@@ -263,7 +263,7 @@ class RegisterWindowXREF : public CrossReferenceToGUI
 {
 public:
 
-  virtual void Update(int new_value)
+  virtual void Update(int /* new_value */)
   {
     GUIRegister *reg;
     Register_Window *rw;
@@ -298,7 +298,7 @@ public:
 
 class InvalidGuiRegister : public GUIRegister {
 public:
-  void put_value(unsigned int new_value)
+  void put_value(unsigned int /* new_value */ )
   {
     printf("(gui_regwin)Warning: writing to invalid register\n");
   };
@@ -308,7 +308,7 @@ public:
     rma=0;
   }
 private:
-  void operator delete(void *ignore) {};
+  void operator delete(void * /* ignore */ ) {};
 };
 
 static InvalidGuiRegister THE_invalid_register;
@@ -686,7 +686,7 @@ GtkWidget *Register_Window::build_menu()
 }
 
 // button press handler
-void Register_Window::do_popup(GtkWidget *widget, GdkEventButton *event)
+void Register_Window::do_popup(GtkWidget *, GdkEventButton *event)
 {
   int button, event_time;
 
@@ -805,7 +805,7 @@ int Register_Window::column_width(int col)
 }
 
 //------------------------------------------------------------------------
-int Register_Window::row_height(int row)
+int Register_Window::row_height(int)
 {
   return char_height ? char_height : 20;
 }
@@ -1594,7 +1594,7 @@ GUIRegisterList::~GUIRegisterList() {
 }
 
 //------------------------------------------------------------------------
-void Register_Window::NewProcessor(GUI_Processor *_gp)
+void Register_Window::NewProcessor(GUI_Processor *)
 {
   gint i,j, border_mask, border_width;
   unsigned int reg_number;
@@ -1715,8 +1715,7 @@ void Register_Window::NewProcessor(GUI_Processor *_gp)
   SelectRegister(0);
 }
 
-static int show_event(GtkWidget *widget,
-                      Register_Window *rw)
+static int show_event(GtkWidget *, Register_Window *rw)
 {
   Dprintf((" show_event\n"));
 
@@ -1724,15 +1723,6 @@ static int show_event(GtkWidget *widget,
   return TRUE;
 }
 
-static int delete_event(GtkWidget *widget,
-                        GdkEvent  *event,
-                        Register_Window *rw)
-{
-  Dprintf((" delete_event\n"));
-  rw->ChangeView(VIEW_HIDE);
-  return TRUE;
-}
-
 //------------------------------------------------------------------------
 // Build
 //
@@ -1740,8 +1730,7 @@ static int delete_event(GtkWidget *widget,
 
 void Register_Window::Build()
 {
-
-  if(bIsBuilt)
+  if (bIsBuilt)
     return;
 
   Dprintf((" Register_Window::Build()\n"));
@@ -1753,13 +1742,7 @@ void Register_Window::Build()
 
   char *fontstring;
 
-  if (window) {
-    gtk_widget_destroy(window);
-  }
-
-  window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
-
-  main_vbox=gtk_vbox_new(FALSE,1);
+  main_vbox = gtk_vbox_new(FALSE,1);
   gtk_container_set_border_width(GTK_CONTAINER(main_vbox),0);
   gtk_container_add(GTK_CONTAINER(window), main_vbox);
   gtk_widget_show(main_vbox);
@@ -1779,11 +1762,7 @@ void Register_Window::Build()
   /* create popupmenu */
   popup_menu=build_menu();
 
-  build_entry_bar(main_vbox,this);
-
-  gtk_window_set_default_size(GTK_WINDOW(window), width,height);
-  gtk_window_move(GTK_WINDOW(window), x, y);
-  gtk_window_set_wmclass(GTK_WINDOW(window),name(),"Gpsim");
+  build_entry_bar(main_vbox, this);
 
   /**************************** load fonts *********************************/
 #define DEFAULT_NORMALFONT "Monospace 10"
@@ -1804,8 +1783,6 @@ void Register_Window::Build()
       }
   }
   UpdateStyle();
-  g_signal_connect(window, "delete_event",
-                     G_CALLBACK(delete_event), this);
 
   g_signal_connect(window, "show",
                   G_CALLBACK(show_event), this);
@@ -1864,10 +1841,6 @@ void Register_Window::Build()
                      G_CALLBACK(set_cell),
                      this);
 
-  g_signal_connect_after(window, "configure_event",
-                           G_CALLBACK(gui_object_configure_event),
-                           this);
-
   SetRegisterSize();
 
   gtk_widget_show (window);
@@ -1884,8 +1857,9 @@ void Register_Window::Build()
 
 //------------------------------------------------------------------------
 
-Register_Window::Register_Window(GUI_Processor *_gp, REGISTER_TYPE _type)
-  : normalfont(0), current_line_number_style(0), breakpoint_line_number_style(0),
+Register_Window::Register_Window(GUI_Processor *_gp, REGISTER_TYPE _type, const char *name)
+  : GUI_Object(name),
+    normalfont(0), current_line_number_style(0), breakpoint_line_number_style(0),
     type(_type),
     registers(0), register_sheet(NULL), rma(0), entry(0), location(0),
     popup_menu(0), registers_loaded(0), register_size(0),
@@ -1897,23 +1871,15 @@ Register_Window::Register_Window(GUI_Processor *_gp, REGISTER_TYPE _type)
   std::fill_n(row_to_address, MAX_ROWS, -1);
 }
 
-const char *RAM_RegisterWindow::name()
-{
-  return "register_viewer_ram";
-}
-
 RAM_RegisterWindow::RAM_RegisterWindow(GUI_Processor *_gp) :
-  Register_Window(_gp, REGISTER_RAM)
+  Register_Window(_gp, REGISTER_RAM, "register_viewer_ram")
 {
   menu = "/menu/Windows/Ram";
 
-  get_config();
-
-  if(enabled)
-      Build();
+  if (enabled)
+    Build();
 }
 
-
 void RAM_RegisterWindow::NewProcessor(GUI_Processor *_gp)
 {
   if(!_gp || !_gp->cpu)
@@ -1931,23 +1897,15 @@ void RAM_RegisterWindow::Update()
   Register_Window::Update();
 }
 
-const char *EEPROM_RegisterWindow::name()
-{
-  return "register_viewer_eeprom";
-}
-
 EEPROM_RegisterWindow::EEPROM_RegisterWindow(GUI_Processor *_gp) :
-  Register_Window(_gp, REGISTER_EEPROM)
+  Register_Window(_gp, REGISTER_EEPROM, "register_viewer_eeprom")
 {
   menu = "/menu/Windows/EEPROM";
 
-  get_config();
-
-  if(enabled)
-      Build();
+  if (enabled)
+    Build();
 }
 
-
 void EEPROM_RegisterWindow::NewProcessor(GUI_Processor *_gp)
 {
   if(!_gp || !_gp->cpu)
