@@ -29,20 +29,23 @@ Boston, MA 02111-1307, USA.  */
 #include <glib.h>
 
 #include "gui_src.h"
+#include "gui_processor.h"
+
+#include "../src/gpsim_interface.h"
+#include "../src/pic-instructions.h"
+#include "../src/processor.h"
+#include "../src/value.h"
 
 static gint
-key_press(GtkWidget *widget,
-          GdkEventKey *key,
-          gpointer data)
+key_press(GtkWidget *, GdkEventKey *key, gpointer data)
 {
-
   SourceBrowser_Window *sbw = static_cast<SourceBrowser_Window *>(data);
 
   if (!sbw) return FALSE;
   if (!sbw->pma) return FALSE;
   if (!sbw->gp) return FALSE;
   if (!sbw->gp->cpu) return FALSE;
-  
+
   switch (key->keyval) {
   case 's':
   case 'S':
@@ -74,12 +77,21 @@ key_press(GtkWidget *widget,
   return TRUE;
 }
 
-static int delete_event(GtkWidget *widget,
-                        GdkEvent  *event,
-                        SourceBrowser_Window *sbw)
+SourceBrowser_Window::SourceBrowser_Window(const char *name)
+  : GUI_Object(name)
 {
-    sbw->ChangeView(VIEW_HIDE);
-    return TRUE;
+  gtk_container_set_border_width(GTK_CONTAINER(window), 0);
+
+  vbox = gtk_vbox_new(FALSE, 0);
+  gtk_widget_show(vbox);
+  gtk_container_add(GTK_CONTAINER(window), vbox);
+
+  /* Add a signal handler for key press events. This will capture
+   * key commands for single stepping, running, etc.
+   */
+  g_signal_connect(window, "key_press_event",
+                     G_CALLBACK(key_press),
+                     (gpointer) this);
 }
 
 void SourceBrowser_Window::Update()
@@ -90,36 +102,9 @@ void SourceBrowser_Window::Update()
   SetPC(gp->cpu->pma->get_PC());
 }
 
-
 void SourceBrowser_Window::Create()
 {
   last_simulation_mode = eSM_INITIAL;
-
-  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-
-  gtk_window_set_default_size(GTK_WINDOW(window), width,height);
-  gtk_window_move(GTK_WINDOW(window), x, y);
-  gtk_window_set_wmclass(GTK_WINDOW(window),name(),"Gpsim");
-
-  g_signal_connect (window, "delete_event",
-                      G_CALLBACK(delete_event),
-                      (gpointer) this);
-
-  /* Add a signal handler for key press events. This will capture
-   * key commands for single stepping, running, etc.
-   */
-  g_signal_connect(window, "key_press_event",
-                     G_CALLBACK(key_press),
-                     (gpointer) this);
-
-
-
-  gtk_container_set_border_width (GTK_CONTAINER (window), 0);
-
-  vbox = gtk_vbox_new (FALSE, 0);
-  gtk_widget_show(vbox);
-  gtk_container_add (GTK_CONTAINER (window), vbox);
-
 }
 
 void SourceBrowser_Window::SetTitle() {
@@ -163,15 +148,4 @@ void SourceBrowser_Window::SelectAddress(Value *addrSym)
 
 }
 
-
-gboolean gui_object_configure_event(GtkWidget *widget, GdkEventConfigure *e, GUI_Object *go)
-{
-  gtk_window_get_position(GTK_WINDOW(widget), &go->x, &go->y);
-  gtk_window_get_size(GTK_WINDOW(widget), &go->width, &go->height);
-
-  go->set_config();
-
-  return FALSE;
-}
-
 #endif // HAVE_GUI
