@@ -22,62 +22,26 @@ Boston, MA 02111-1307, USA.  */
 #ifndef __GUI_SRC_H__
 #define __GUI_SRC_H__
 
-#include <list>
+#include "../src/modules.h"
+#include "gui_object.h"
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+
+#include <map>
 #include <string>
+#include <vector>
 
 // forward references
 class SourceBrowserParent_Window;
 class StatusBar_Window;
 class Value;
 class SourceWindow;
-
-//========================================================================
-class ColorHolder
-{
-public:
-  ColorHolder (const char *pcColor);
-
-
-  bool set(GdkColor *pNewColor, bool saveOld);
-  char *get(char *, int );
-  void apply();
-  bool revert();
-  GdkColor *CurrentColor();
-protected:
-  GdkColor mCurrentColor, mSaveColor;
-};
-//========================================================================
-// TextStyle
-//
-// A TextSyle is wrapper around a GtkTextTag and provides a simple way
-// to change the text foreground and background colors. Also, color
-// editing is supported.
-class TextStyle
-{
-public:
-  TextStyle (const char *pName,
-             const char *pFGColor,
-             const char *pBGColor);
-
-  virtual ~TextStyle()
-  {
-  }
-
-  GtkTextTag *tag() { return m_pTag; }
-
-  void apply();   // Permanently apply a change that the user has made.
-  void revert();  // Remove a change the user has made
-
-  void setFG(GdkColor *pNewColor);
-
-  virtual void doubleClickEvent(GtkTextIter *);
-
-  ColorHolder  mFG;  // Foreground color
-  ColorHolder  mBG;  // Background color
-
-protected:
-  GtkTextTag *m_pTag;
-};
+class FileContext;
+class GUI_Processor;
+class ProgramMemoryAccess;
 
 //========================================================================
 class SourceBuffer
@@ -86,8 +50,8 @@ public:
   SourceBuffer(GtkTextTagTable *,FileContext *,SourceBrowserParent_Window *);
   void parseLine(const char*, int parseStyle);
 
-  void addTagRange(TextStyle *,
-                   int start_index, int end_index);
+  void addTagRange(const char *pStyle, int start_index, int end_index);
+
   GtkTextBuffer *getBuffer();
   SourceBrowserParent_Window *m_pParent;
   FileContext   *m_pFC;
@@ -150,32 +114,29 @@ public:
   void invalidateView();
   void updateMargin(int y1, int y2);
 
-  void Close(void);
+  void Close();
   void setFont(const char *);
-  void setSource();
 
   FileContext *getFC();
 
-  // callbacks
-  static gboolean KeyPressHandler(GtkTextView *pView,
-                GdkEventKey *key,
-                SourceWindow *pSW);
-  static gint ButtonPressHandler(GtkTextView *pView,
-                  GdkEventButton *pButton,
-                  SourceWindow *pSW);
-  static gint ViewExposeEventHandler(GtkTextView *pView,
-                GdkEventExpose *pEvent,
-                SourceWindow *pSW);
+  unsigned int get_file_id() { return m_fileid; }
+  int get_margin_width() { return m_marginWidth; }
 
-
-  unsigned int   m_fileid;
-  SourceBuffer  *m_pBuffer;
-  int            m_marginWidth;
 private:
-  SourceWindow  *m_Parent;
-  std::string   m_cpFont;
-  GtkWidget     *m_pContainer;
+  // callbacks
+  static gboolean KeyPressHandler(GtkTextView *pView, GdkEventKey *key,
+    NSourcePage *page);
+  static gint ButtonPressHandler(GtkTextView *pView, GdkEventButton *pButton,
+    NSourcePage *pPage);
+  static gint ViewExposeEventHandler(GtkTextView *pView, GdkEventExpose *pEvent,
+    NSourcePage *pPage);
+
   GtkTextView   *m_view;
+  SourceBuffer  *m_pBuffer;
+  SourceWindow  *m_Parent;
+  unsigned int   m_fileid;
+  int            m_marginWidth;
+  std::string    m_cpFont;
 };
 
 class SearchDialog;
@@ -191,7 +152,6 @@ public:
   virtual void Build();
   virtual void SetTitle();
 
-
   void set_pma(ProgramMemoryAccess *new_pma);
 
   virtual void SelectAddress(int address);
@@ -206,7 +166,7 @@ public:
   virtual int getAddress(NSourcePage *pPage, int line);
   virtual bool bAddressHasBreak(int address);
   virtual int getOpcode(int address);
-  int  AddPage(SourceBuffer *pSourceBuffer, const char *fName);
+  int  AddPage(SourceBuffer *pSourceBuffer, const std::string &fName);
   void step(int n=1);
   void step_over();
   void stop();
@@ -225,17 +185,6 @@ public:
   const char *getFont();
   gint switch_page_cb(guint newPage);
 
-  // Font strings
-  std::string commentfont_string;
-  std::string sourcefont_string;
-
-  GtkStyle *symbol_text_style;       // for symbols in .asm display
-  GtkStyle *label_text_style;        // for label in .asm display
-  GtkStyle *instruction_text_style;  // for instruction in .asm display
-  GtkStyle *number_text_style;       // for numbers in .asm display
-  GtkStyle *comment_text_style;      // for comments in .asm display
-  GtkStyle *default_text_style;      // the rest
-
   // do we need this:
   bool m_bLoadSource;
   bool m_bSourceLoaded;
@@ -247,7 +196,7 @@ private:
   ProgramMemoryAccess *pma;      // pointer to the processor's pma.
   StatusBar_Window *status_bar;  // display's PC, status, etc.
   SIMULATION_MODES last_simulation_mode;
-  string sLastPmaName;
+  std::string sLastPmaName;
   unsigned int m_currentPage;          // Notebook page currently displayed.
 
   struct _PC {
@@ -280,76 +229,37 @@ private:
   std::string m_name;
 
 protected:
-  void set_style_colors(const char *fg_color, const char *bg_color, GtkStyle **style);
-  void addTagRange(NSourcePage *pPage, TextStyle *,
-                   int start_index, int end_index);
-
-  // FIXME - change these items to list objects
-  NSourcePage **pages;
-
+  std::map<int, NSourcePage *> pages;
   GtkWidget *m_Notebook;
-
   GtkPositionType m_TabPosition;
-
   SourceBrowserParent_Window *m_pParent;
 
-  virtual const char *name();
-
 public:
   const char *name_pub() {return name();}
 };
 
 class SourceBrowser_Window : public GUI_Object {
  public:
+  explicit SourceBrowser_Window(const char *name);
+
   GtkWidget *vbox;               // for children to put widgets in
 
   ProgramMemoryAccess *pma;      // pointer to the processor's pma.
-  StatusBar_Window *status_bar;  // display's PC, status, etc.
   SIMULATION_MODES last_simulation_mode;
-  string sLastPmaName;
+  std::string sLastPmaName;
 
   void set_pma(ProgramMemoryAccess *new_pma);
 
   void Create();
-  virtual void NewProcessor(GUI_Processor *gp);
+  virtual void NewProcessor(GUI_Processor *gp) = 0;
   virtual void SetTitle();
-  virtual void SelectAddress(int address);
+  virtual void SelectAddress(int address) = 0;
   virtual void SelectAddress(Value *);
   virtual void Update();
-  virtual void UpdateLine(int address);
-  virtual void SetPC(int address);
-  virtual void CloseSource(){};
-  virtual void NewSource(GUI_Processor *gp){};
-
-};
-
-//
-// Source page
-//
-
-class SourcePage
-{
- public:
-
-
-  GtkAdjustment *source_layout_adj;
-  GtkWidget *source_layout;
-  GtkWidget *source_text;
-  int 	    pageindex_to_fileid;
-  GtkWidget *source_pcwidget;
-  GtkWidget *notebook;   // parent
-  GtkWidget *notebook_child;
-
-  SourcePage() {
-    source_layout_adj = 0;
-    source_layout = 0;
-    source_text = 0;
-    pageindex_to_fileid = INVALID_VALUE;
-    source_pcwidget = 0;
-    notebook_child = 0;
-    notebook = 0;
-  }
-
+  virtual void UpdateLine(int address) = 0;
+  virtual void SetPC(int address) = 0;
+  virtual void CloseSource() {};
+  virtual void NewSource(GUI_Processor *) {};
 };
 
 //
@@ -358,49 +268,8 @@ class SourcePage
 class SourceBrowserOpcode_Window : public SourceBrowser_Window
 {
  public:
-
-  GtkListStore *list;
-  GtkWidget *tree;
-
-  unsigned int current_address;   // current PC
-
-  // Font strings
-  std::string normalfont_string;
-
-  PangoFontDescription *normalPFD;
-  PangoFontDescription *current_line_numberPFD;
-  PangoFontDescription *breakpoint_line_numberPFD;
-
-  std::string breakpointfont_string;
-  std::string pcfont_string;
-
-  GtkStyle *normal_style;
-  GtkStyle *current_line_number_style;
-  GtkStyle *breakpoint_line_number_style;
-
-  GdkColor pm_has_changed_color;
-  GdkColor normal_pm_bg_color;
-  GdkColor breakpoint_color;
-
-  GtkWidget *notebook;
-  GtkWidget *sheet;
-  GtkWidget *entry;
-  GtkWidget *label;
-
-  GtkWidget *sheet_popup_menu;
-  GtkWidget *list_popup_menu;
-
-  GdkPixbuf *break_pix;
-  GdkPixbuf *pc_pix;
-
-  unsigned int ascii_mode; // 0, 1 or 2 equals
-  // one byte/cell,
-  // two bytes/cell MSB first
-  // two bytes/cell LSB first
-
-  unsigned int *memory;
-
-  SourceBrowserOpcode_Window(GUI_Processor *gp);
+  explicit SourceBrowserOpcode_Window(GUI_Processor *gp);
+  ~SourceBrowserOpcode_Window();
   virtual void Build();
   virtual void NewProcessor(GUI_Processor *gp);
   virtual void SelectAddress(int address);
@@ -413,9 +282,6 @@ class SourceBrowserOpcode_Window : public SourceBrowser_Window
   void load_styles();
   void settings_dialog();
 
-protected:
-  virtual const char *name();
-
 private:
   GtkWidget *build_menu_for_sheet();
   GtkWidget *build_menu_for_list();
@@ -423,11 +289,44 @@ private:
   void update_values(int address);
   void update_styles(int address);
   void update(int address);
+  void update_label(int address);
 
-  static void popup_activated(GtkWidget *widget, gpointer data);
+  void do_popup_menu(GtkWidget *my_widget, GdkEventButton *event);
+
+  static void popup_activated(GtkWidget *widget, SourceBrowserOpcode_Window *sbow);
   static void cell_renderer(GtkTreeViewColumn *tree_column,
     GtkCellRenderer *cell, GtkTreeModel *tree_model,
     GtkTreeIter *iter, gpointer data);
+  static void show_entry(GtkWidget *widget, SourceBrowserOpcode_Window *sbow);
+  static gint activate_sheet_cell(GtkWidget *widget,
+    gint row, gint column, SourceBrowserOpcode_Window *sbow);
+  static gint button_press(GtkWidget *widget, GdkEventButton *event,
+    SourceBrowserOpcode_Window *sbow);
+  static gboolean popup_menu_handler(GtkWidget *widget,
+    SourceBrowserOpcode_Window *sbw);
+  static void row_selected(GtkTreeView *tree_view, GtkTreePath *path,
+    GtkTreeViewColumn *column, SourceBrowserOpcode_Window *sbow);
+
+  GtkListStore *list;
+  GtkWidget *tree;
+
+  unsigned int current_address;   // current PC
+
+  std::string normalfont_string;
+  PangoFontDescription *normalPFD;
+
+  GtkWidget *notebook;
+  GtkWidget *sheet;
+  GtkWidget *entry;
+  GtkWidget *label;
+
+  GtkWidget *sheet_popup_menu;
+  GtkWidget *list_popup_menu;
+
+  GdkPixbuf *break_pix;
+  GdkPixbuf *pc_pix;
+
+  unsigned int *memory;
 };
 
 //
@@ -442,8 +341,8 @@ private:
 class SourceBrowserParent_Window : public GUI_Object
 {
  public:
+  explicit SourceBrowserParent_Window(GUI_Processor *gp);
 
-  SourceBrowserParent_Window(GUI_Processor *gp);
   virtual void Build();
   virtual void NewProcessor(GUI_Processor *gp);
   virtual void SelectAddress(int address);
@@ -456,49 +355,31 @@ class SourceBrowserParent_Window : public GUI_Object
   virtual void ChangeView(int view_state);
   virtual int set_config();
 
-  list<SourceWindow *> children;
-
-  ProgramMemoryAccess *pma;      // pointer to the processor's pma.
-
   GtkTextTagTable *getTagTable() { return mpTagTable; }
   void CreateSourceBuffers(GUI_Processor *gp);
-  //void parseLine(gpsimTextBuffer *pBuffer, const char*, int parseStyle);
+
   void parseSource(SourceBuffer *pBuffer,FileContext *pFC);
   SourcePageMargin &margin();
   void setTabPosition(int tt);
   int getTabPosition() { return m_TabType; }
   void setFont(const char *);
   const char *getFont();
-  //protected:
+
+private:
+  gchar *get_color_string(const char *tag_name);
 
   GtkTextTagTable *mpTagTable;
+  std::vector<SourceWindow *> children;
 
-  TextStyle *mLabel;       // for label in .asm display
-  TextStyle *mMnemonic;    // for instruction in .asm display
-  TextStyle *mSymbol;      // for symbols in .asm display
-  TextStyle *mComment;     // for comments in .asm display
-  TextStyle *mConstant;    // for numbers in .asm display
-  TextStyle *mDefault;     // for everything else.
-
-  TextStyle *mBreakpointTag;   // for breakpoints
-  TextStyle *mNoBreakpointTag;
-  TextStyle *mCurrentLineTag;  // Highlights the line at the PC.
-  GtkStyle  *mBreakStyle;
+  ProgramMemoryAccess *pma;      // pointer to the processor's pma.
 
+private:
   SourcePageMargin m_margin;
   int m_TabType;
   std::string m_FontDescription;
 
-  // FIXME - change these items to list objects
-  SourceBuffer **ppSourceBuffers;
-
-protected:
-  virtual const char *name();
+public:
+  std::vector<SourceBuffer *> ppSourceBuffers;
 };
 
-
-
-
-
 #endif // __GUI_SRC_H__
-
