@@ -231,7 +231,7 @@ NSourcePage::ViewExposeEventHandler(GtkTextView *pView, GdkEventExpose *pEvent,
 //------------------------------------------------------------------------
 //
 gboolean
-SourceWindow::KeyPressHandler(GtkWidget *widget,
+SourceWindow::KeyPressHandler(GtkWidget *,
           GdkEventKey *key,
           SourceWindow *pSW)
 {
@@ -291,7 +291,6 @@ SourceWindow::KeyPressHandler(GtkWidget *widget,
   }
 
   return TRUE;
-
 }
 
 typedef enum {
@@ -400,16 +399,6 @@ NSourcePage::ButtonPressHandler(GtkTextView *pView, GdkEventButton *pButton,
   return FALSE;
 }
 
-//========================================================================
-int SourceWindow::DeleteEventHandler(GtkWidget *widget,
-                        GdkEvent  *event,
-                        SourceWindow *sw)
-{
-  sw->ChangeView(VIEW_HIDE);
-  return TRUE;
-}
-
-
 //========================================================================
 // Helper functions for parsing
 static int isString(const char *cP)
@@ -592,8 +581,8 @@ void SearchDialog::activate(GtkEntry *entry, SearchDialog *sd)
   sd->find(p);
 }
 
-void SearchDialog::icon_press(GtkEntry *entry, GtkEntryIconPosition icon_pos,
-  GdkEvent *event, gpointer user_data)
+void SearchDialog::icon_press(GtkEntry *entry, GtkEntryIconPosition ,
+  GdkEvent *, gpointer)
 {
   gtk_entry_set_text(entry, "");
 }
@@ -668,16 +657,12 @@ GtkTextBuffer *SourceBuffer::getBuffer()
   return m_buffer;
 }
 
-const char *SourceWindow::name()
-{
-  return m_name.c_str();
-}
-
 //------------------------------------------------------------------------
 SourceWindow::SourceWindow(GUI_Processor *pgp,
   SourceBrowserParent_Window *pParent, bool bUseConfig,
   const char *newName)
-  : GUI_Object (), m_bLoadSource(false), m_bSourceLoaded(false),
+  : GUI_Object(newName ? newName : "source_browser"),
+    m_bLoadSource(false), m_bSourceLoaded(false),
     m_LineAtButtonClick(-1), pma(0), status_bar(0),
     last_simulation_mode(eSM_INITIAL), stPSearchDialog(0), m_Notebook(0),
     m_pParent(pParent)
@@ -686,21 +671,14 @@ SourceWindow::SourceWindow(GUI_Processor *pgp,
 
   gp = pgp;
 
-  if (newName)
-    m_name = newName;
-  else
-    m_name = "source_browser";
-
   mProgramCounter.bIsActive = false;
 
   if (bUseConfig) {
-    get_config();
-
     if (enabled)
       Build();
   }
-
 }
+
 //------------------------------------------------------------------------
 void SourceWindow::step(int n)
 {
@@ -758,7 +736,7 @@ void SourceWindow::toggleBreak(NSourcePage *pPage, int line)
 // movePC
 //
 //
-void SourceWindow::movePC(int line)
+void SourceWindow::movePC(int)
 {
 }
 
@@ -949,8 +927,8 @@ int SourceWindow::findText(const char *pText, int start, bool bDirection, bool b
   return 0;
 }
 //------------------------------------------------------------------------
-void SourceWindow::cb_notebook_switchpage(GtkNotebook *notebook,
-  gpointer page, guint page_num, SourceWindow *pSW)
+void SourceWindow::cb_notebook_switchpage(GtkNotebook *,
+  gpointer, guint page_num, SourceWindow *pSW)
 {
   pSW->switch_page_cb(page_num);
 }
@@ -976,17 +954,22 @@ gint SourceWindow::switch_page_cb(guint newPage)
 }
 
 //------------------------------------------------------------------------
-static Register *findRegister(string text)
+static Register *findRegister(std::string text)
 {
+
   Register *pReg = dynamic_cast<Register *>(globalSymbolTable().find(text));
   if (!pReg)
-    pReg = dynamic_cast<Register *>(globalSymbolTable().find(text+string("_")));
+    pReg = dynamic_cast<Register *>(globalSymbolTable().find(text + std::string("_")));
   if (!pReg) {
-    toupper(text);
+    (void) toupper(text);
     pReg = dynamic_cast<Register *>(globalSymbolTable().find(text));
   }
   if (!pReg)
-    pReg = dynamic_cast<Register *>(globalSymbolTable().find(text+string("_")));
+    pReg = dynamic_cast<Register *>(globalSymbolTable().find(text + std::string("_")));
+  if (!pReg) {
+    transform(text.begin(), text.end(), text.begin(), ::tolower); 
+    pReg = dynamic_cast<Register *>(globalSymbolTable().find(text));
+  }
   return pReg;
 }
 //------------------------------------------------------------------------
@@ -1178,26 +1161,15 @@ void SourceWindow::Build()
 {
   Dprintf((" \n"));
 
-  if(bIsBuilt)
+  if (bIsBuilt)
     return;
 
   Dprintf((" \n"));
-  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-
-  //  get_config();
-
-  gtk_window_set_default_size(GTK_WINDOW(window), width,height);
-  gtk_window_move(GTK_WINDOW(window), x, y);
-  gtk_window_set_wmclass(GTK_WINDOW(window),name(),"Gpsim");
 
   g_signal_connect(window,"key_press_event",
     G_CALLBACK (KeyPressHandler),
     (gpointer) this);
 
-  g_signal_connect (window, "delete_event",
-    G_CALLBACK (DeleteEventHandler),
-    (gpointer) this);
-
   gtk_container_set_border_width (GTK_CONTAINER (window), 0);
 
   SetTitle();
@@ -1288,14 +1260,16 @@ void SourceWindow::set_pma(ProgramMemoryAccess *new_pma)
     status_bar->NewProcessor(gp, pma);
 }
 
-void SourceWindow::SelectAddress(int address)
+void SourceWindow::SelectAddress(int)
 {
   Dprintf((" \n"));
 }
+
 void SourceWindow::SelectAddress(Value *)
 {
   Dprintf((" \n"));
 }
+
 //------------------------------------------------------------------------
 // Update
 //
@@ -1968,11 +1942,6 @@ void SourceBrowser_Window::set_pma(ProgramMemoryAccess *new_pma)
   }
 }
 
-const char *SourceBrowserParent_Window::name()
-{
-  return "source_browser_parent";
-}
-
 //========================================================================
 //
 // SourceBrowserParent_Window
@@ -1981,7 +1950,7 @@ const char *SourceBrowserParent_Window::name()
 // windows.
 
 SourceBrowserParent_Window::SourceBrowserParent_Window(GUI_Processor *_gp)
-: GUI_Object()
+: GUI_Object("source_browser_parent")
 {
 
   gp = _gp;
