@@ -299,7 +299,7 @@ SourceBrowserOpcode_Window::popup_menu_handler(GtkWidget *widget,
 // Row selection handle (static)
 
 void SourceBrowserOpcode_Window::row_selected(GtkTreeView *tree_view,
-  GtkTreePath *path, GtkTreeViewColumn *column,
+  GtkTreePath *path, GtkTreeViewColumn *,
   SourceBrowserOpcode_Window *sbow)
 {
   GtkTreeIter iter;
@@ -528,7 +528,7 @@ void SourceBrowserOpcode_Window::show_entry(GtkWidget *widget,
 // Signal handler - static
 // when a cell is activated, we set the label and entry above the sheet
 //
-gint SourceBrowserOpcode_Window::activate_sheet_cell(GtkWidget *widget,
+gint SourceBrowserOpcode_Window::activate_sheet_cell(GtkWidget *,
   gint row, gint column, SourceBrowserOpcode_Window *sbow)
 {
     GtkSheet *sheet;
@@ -746,12 +746,12 @@ void SourceBrowserOpcode_Window::Fill()
 
 
 }
-void SourceBrowserOpcode_Window::NewSource(GUI_Processor *_gp)
+void SourceBrowserOpcode_Window::NewSource(GUI_Processor *)
 {
-  if(!gp)
+  if (!gp)
     return;
 
-  current_address=0;
+  current_address = 0;
 
   if(!enabled)
     return;
@@ -761,7 +761,7 @@ void SourceBrowserOpcode_Window::NewSource(GUI_Processor *_gp)
   /* Now create a cross-reference link that the
    * simulator can use to send information back to the gui
    */
-  if(gp->cpu && gp->cpu->pc) {
+  if (gp->cpu && gp->cpu->pc) {
     SourceOpcodeXREF *cross_reference;
 
     cross_reference = new SourceOpcodeXREF();
@@ -773,23 +773,21 @@ void SourceBrowserOpcode_Window::NewSource(GUI_Processor *_gp)
   }
 
   Fill();
-
 }
 
-void SourceBrowserOpcode_Window::NewProcessor(GUI_Processor *_gp)
+void SourceBrowserOpcode_Window::NewProcessor(GUI_Processor *)
 {
-
   GtkSheetRange range;
 
-  if(!gp || !gp->cpu)
+  if (!gp || !gp->cpu)
     return;
 
-  current_address=0;
+  current_address = 0;
 
-  if(!enabled)
+  if (!enabled)
     return;
 
-  if(!bIsBuilt)
+  if (!bIsBuilt)
     Build();
 
   pma = gp->cpu->pma;
@@ -805,13 +803,12 @@ void SourceBrowserOpcode_Window::NewProcessor(GUI_Processor *_gp)
   gtk_sheet_select_range(GTK_SHEET(sheet),&range);
 
   update_label(0);
-
 }
 
 void
-SourceBrowserOpcode_Window::cell_renderer(GtkTreeViewColumn *tree_column,
+SourceBrowserOpcode_Window::cell_renderer(GtkTreeViewColumn *,
   GtkCellRenderer *cell, GtkTreeModel *tree_model,
-  GtkTreeIter *iter, gpointer data)
+  GtkTreeIter *iter, gpointer)
 {
   gint addr;
   gchar buf[64];
@@ -826,7 +823,7 @@ SourceBrowserOpcode_Window::cell_renderer(GtkTreeViewColumn *tree_column,
 
 void SourceBrowserOpcode_Window::Build()
 {
-  if(bIsBuilt)
+  if (bIsBuilt)
     return;
 
   GtkWidget *hbox;
@@ -837,20 +834,13 @@ void SourceBrowserOpcode_Window::Build()
   gint column_width,char_width;
   gint i;
 
-  if(window!=0)
-    gtk_widget_destroy(window);
-
   SourceBrowser_Window::Create();
 
-
   gtk_window_set_title (GTK_WINDOW (window), "Program memory");
 
   notebook = gtk_notebook_new();
 
-  gtk_box_pack_start (GTK_BOX (vbox), notebook, TRUE, TRUE, 0);
-
-  gtk_window_set_default_size(GTK_WINDOW(window), width,height);
-  gtk_window_move(GTK_WINDOW(window), x, y);
+  gtk_box_pack_start(GTK_BOX(vbox), notebook, TRUE, TRUE, 0);
 
   //
   // create list
@@ -1017,9 +1007,6 @@ void SourceBrowserOpcode_Window::Build()
 
   /////////////////////////////////////////////////////////////////
 
-  g_signal_connect_after(window, "configure_event",
-                           G_CALLBACK (gui_object_configure_event), this);
-
   gtk_widget_show_all(window);
 
   bIsBuilt = true;
@@ -1036,13 +1023,9 @@ void SourceBrowserOpcode_Window::Build()
   UpdateMenuItem();
 }
 
-const char *SourceBrowserOpcode_Window::name()
-{
-  return "program_memory";
-}
-
 SourceBrowserOpcode_Window::SourceBrowserOpcode_Window(GUI_Processor *_gp)
-  : current_address(0), normalPFD(0), memory(0)
+  : SourceBrowser_Window("program_memory"),
+    current_address(0), normalPFD(0), memory(0)
 {
   menu = "/menu/Windows/Program memory";
 
@@ -1053,9 +1036,7 @@ SourceBrowserOpcode_Window::SourceBrowserOpcode_Window(GUI_Processor *_gp)
   break_pix = gdk_pixbuf_new_from_xpm_data(break_xpm);
   pc_pix = gdk_pixbuf_new_from_xpm_data(pc_xpm);
 
-  get_config();
-
-  if(enabled)
+  if (enabled)
     Build();
 }
 
