@@ -22,25 +22,26 @@ Boston, MA 02111-1307, USA.  */
 #ifndef __GUI_STACK_H__
 #define __GUI_STACK_H__
 
+#include "gui_object.h"
+#include <gtk/gtk.h>
+
+class GUI_Processor;
+
 //
 // The stack window
 //
 class Stack_Window : public GUI_Object
 {
  public:
-
-  int last_stacklen;
-
   explicit Stack_Window(GUI_Processor *gp);
-  virtual void Build(void);
-  virtual void Update(void);
+  virtual void Build();
+  virtual void Update();
 
+private:
+  int last_stacklen;
   GtkListStore *stack_list;
   GtkTreeModel *sort_stack_list;
   GtkWidget *tree;
-
-protected:
-  virtual const char *name();
 };
 
 
