@@ -20,9 +20,10 @@ the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
 
-#ifndef __GUI_STATUSBAR_H__
-#define __GUI_STATUSBAR_H__
+#ifndef GUI_GUI_STATUSBAR_H_
+#define GUI_GUI_STATUSBAR_H_
 
+#include <gtk/gtk.h>
 #include <vector>
 
 class RegisterLabeledEntry;	// in gui_statusbar.cc
@@ -34,7 +35,7 @@ class GUI_Processor;
 //
 
 class StatusBar_Window {
- public:
+public:
   explicit StatusBar_Window(GtkWidget *vbox_main);
 
   void NewProcessor(GUI_Processor *_gp, MemoryAccess *);
@@ -47,4 +48,4 @@ private:
   std::vector<RegisterLabeledEntry *> entries;
 };
 
-#endif //__GUI_STATUSBAR_H__
+#endif // GUI_GUI_STATUSBAR_H__
