@@ -19,19 +19,19 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __GUI_SYMBOLS_H__
-#define __GUI_SYMBOLS_H__
+#ifndef GUI_GUI_SYMBOLS_H_
+#define GUI_GUI_SYMBOLS_H_
 
 #include "gui_object.h"
+#include <gtk/gtk.h>
 
 class GUI_Processor;
 
 //
 // The symbol window
 //
-class Symbol_Window : public GUI_Object
-{
- public:
+class Symbol_Window : public GUI_Object {
+public:
   GtkWidget *symbol_view;
   GtkListStore *symbol_list;
 
@@ -53,23 +53,20 @@ class Symbol_Window : public GUI_Object
   void NewSymbols();
 
 protected:
-  virtual const char *name();
-
   // Signals
-  static void toggle_addresses (GtkToggleButton *button, Symbol_Window *sw);
-  static void toggle_constants (GtkToggleButton *button, Symbol_Window *sw);
-  static void toggle_registers (GtkToggleButton *button, Symbol_Window *sw);
+  static void toggle_addresses(GtkToggleButton *button, Symbol_Window *sw);
+  static void toggle_constants(GtkToggleButton *button, Symbol_Window *sw);
+  static void toggle_registers(GtkToggleButton *button, Symbol_Window *sw);
   static gboolean do_popup(GtkWidget *widget, GdkEventButton *event, Symbol_Window *sw);
   static void symbol_list_row_selected(GtkTreeSelection *treeselection,
-    gpointer user_data);
+                                       gpointer user_data);
   static gboolean delete_event(GtkWidget *widget, GdkEvent  *event,
-    Symbol_Window *sw);
+                               Symbol_Window *sw);
 
   GtkWidget *build_menu(GtkWidget *sheet);
   void do_symbol_select(Value *e);
 };
 
 
-
-#endif // __GUI_SYMBOLS_H__
+#endif // GUI_GUI_SYMBOLS_H_
 
