@@ -109,7 +109,7 @@ WatchWindowXREF::~WatchWindowXREF()
   gtk_tree_row_reference_free(static_cast<GtkTreeRowReference *>((void *)data));
 }
 
-void WatchWindowXREF::Update(int new_value)
+void WatchWindowXREF::Update(int)
 {
   Watch_Window *ww  = static_cast<Watch_Window *>(parent_window);
   if (ww) {
@@ -193,7 +193,7 @@ int Watch_Window::set_config(void) {
   return iRet;
 }
 
-gboolean Watch_Window::do_symbol_write(GtkTreeModel *model, GtkTreePath *path,
+gboolean Watch_Window::do_symbol_write(GtkTreeModel *, GtkTreePath *,
   GtkTreeIter *iter, gpointer data)
 {
   Watch_Window *ww = static_cast<Watch_Window *>(data);
@@ -374,7 +374,7 @@ void Watch_Window::build_menu()
 }
 
 // button press handler
-gboolean Watch_Window::do_popup(GtkWidget *widget, GdkEventButton *event,
+gboolean Watch_Window::do_popup(GtkWidget *, GdkEventButton *event,
   Watch_Window *ww)
 {
   GtkWidget *popup = ww->popup_menu;
@@ -388,7 +388,7 @@ gboolean Watch_Window::do_popup(GtkWidget *widget, GdkEventButton *event,
 }
 
 static gint
-key_press(GtkWidget *widget,
+key_press(GtkWidget *,
           GdkEventKey *key,
           gpointer data)
 {
@@ -429,14 +429,6 @@ void Watch_Window::watch_list_row_selected(GtkTreeSelection *sel, Watch_Window *
   ww->UpdateMenus();
 }
 
-static int delete_event(GtkWidget *widget,
-                        GdkEvent  *event,
-                        Watch_Window *ww)
-{
-  ww->ChangeView(VIEW_HIDE);
-  return TRUE;
-}
-
 //========================================================================
 // UpdateWatch
 // A single watch entry is updated here. Here's what's done:
@@ -510,7 +502,7 @@ void Watch_Window::UpdateWatch(GtkTreeIter *iter)
 //
 //
 
-static gboolean do_an_update(GtkTreeModel *model, GtkTreePath *path,
+static gboolean do_an_update(GtkTreeModel *, GtkTreePath *,
   GtkTreeIter *iter, gpointer data)
 {
   Watch_Window *ww = static_cast<Watch_Window *>(data);
@@ -527,6 +519,7 @@ void Watch_Window::Update()
 
 void Watch_Window::Add(REGISTER_TYPE type, GUIRegister *reg, Register * pReg)
 {
+
   if(!gp || !gp->cpu || !reg || !reg->bIsValid())
     return;
 
@@ -584,7 +577,8 @@ void Watch_Window::Add( Value *regSym)
 
     Register *reg = dynamic_cast<Register *>(regSym);
 
-    if(reg) {
+    if(reg) 
+    {
       GUIRegister *greg = gp->m_pGUIRamRegisters->Get(reg->getAddress());
       Add(REGISTER_RAM, greg, reg);
     }
@@ -593,9 +587,8 @@ void Watch_Window::Add( Value *regSym)
 //------------------------------------------------------------------------
 // NewSymbols
 //
-void Watch_Window::NewProcessor(GUI_Processor *_gp)
+void Watch_Window::NewProcessor(GUI_Processor *)
 {
-
   if (!gp || !gp->cpu)
     return;
 
@@ -607,27 +600,16 @@ void Watch_Window::NewProcessor(GUI_Processor *_gp)
 //
 //
 
-void Watch_Window::Build(void)
+void Watch_Window::Build()
 {
-  if(bIsBuilt)
+  if (bIsBuilt)
     return;
 
   GtkWidget *vbox;
   GtkWidget *scrolled_window;
 
-  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-
   gtk_window_set_title(GTK_WINDOW(window), "Watch Viewer");
 
-  gtk_window_set_default_size(GTK_WINDOW(window), width,height);
-  gtk_window_move(GTK_WINDOW(window), x, y);
-  gtk_window_set_wmclass(GTK_WINDOW(window),name(),"Gpsim");
-
-  g_signal_connect (window, "delete_event",
-                      G_CALLBACK(delete_event), (gpointer)this);
-  g_signal_connect_after(window, "configure_event",
-                           G_CALLBACK(gui_object_configure_event), this);
-
   watch_list = gtk_list_store_new(N_COLUMNS,
     G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
     G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
@@ -692,21 +674,15 @@ void Watch_Window::Build(void)
 
 }
 
-const char *Watch_Window::name()
-{
-  return "watch_viewer";
-}
-
 Watch_Window::Watch_Window(GUI_Processor *_gp)
+  : GUI_Object("watch_viewer")
 {
   menu = "/menu/Windows/Watch";
 
   gp = _gp;
   watch_list = 0;
 
-  get_config();
-
-  if(enabled)
+  if (enabled)
     Build();
 }
 
