@@ -23,9 +23,6 @@ Boston, MA 02111-1307, USA. */
 
 #include <string>
 
-
-using namespace std;
-
 class Settings
 {
 public:
@@ -44,7 +41,7 @@ public:
   }
 
 protected:
-  string name;
+  std::string name;
 };
 
 #endif  //_SETTINGS_H
