@@ -28,7 +28,7 @@ SettingsEXdbm::SettingsEXdbm(const char *appl_name)
 {
   int ret;
   const char *homedir;
-  string path;
+  std::string path;
 
   ret = eXdbmInit();
   if (ret == -1)
@@ -40,7 +40,7 @@ SettingsEXdbm::SettingsEXdbm(const char *appl_name)
   if (homedir == 0)
     homedir = ".";
 
-  path = string(homedir) + "/." + appl_name;
+  path = std::string(homedir) + "/." + appl_name;
 
   ret = eXdbmOpenDatabase((char *)path.c_str(), &dbid);
   if(ret == -1)
