@@ -15,21 +15,17 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
 /*
-
   encoder.cc
-
-
 */
 
 /* IN_MODULE should be defined for modules */
 #define IN_MODULE
 
-#include <cstdio>
 #include <cassert>
 #include <iostream>
 
@@ -46,24 +42,18 @@ License along with this library; if not, see
 #define PIN_B	(0x02)
 
 //--------------------------------------------------------------
-// create_iopin_map 
+// create_iopin_map
 //
 //  This is where the information for the Module's package is defined.
 // Specifically, the I/O pins of the module are created.
 
-void Encoder::create_iopin_map(void)
+void Encoder::create_iopin_map()
 {
-
-
   // Define the physical package.
   //   The Package class, which is a parent of all of the modules,
   //   is responsible for allocating memory for the I/O pins.
   //
-
-
   create_pkg(2);
-
-
   // Define the I/O pins and assign them to the package.
   //   There are two things happening here. First, there is
   //   a new I/O pin that is being created. For the binary
@@ -71,82 +61,69 @@ void Encoder::create_iopin_map(void)
   //   that the pins are "assigned" to the package. If we
   //   need to reference these newly created I/O pins (like
   //   below) then we can call the member function 'get_pin'.
-
   a_pin = new IO_bi_directional("a");
   addSymbol(a_pin);
   assign_pin(1, a_pin);
-  package->set_pin_position(1,(float)0.0);
+  package->set_pin_position(1, (float)0.0);
   b_pin = new IO_bi_directional("b");
   addSymbol(b_pin);
   assign_pin(2, b_pin);
-  package->set_pin_position(2,(float)0.9999);
+  package->set_pin_position(2, (float)0.9999);
 }
 
+
 //--------------------------------------------------------------
 // GUI
-static void
-cw_cb (GtkButton *button, Encoder *enc)
-
+static void cw_cb(GtkButton * , Encoder *enc)
 {
-    enc->send_cw();
+  enc->send_cw();
 }
 
-static void
-ccw_cb (GtkButton *button, Encoder *enc)
 
+static void ccw_cb(GtkButton * , Encoder *enc)
 {
-    enc->send_ccw();
+  enc->send_ccw();
 }
 
+
 void Encoder::create_widget(Encoder *enc)
 {
-
-  GtkWidget	*box1;
-  GtkWidget	*buttonl, *buttonr;
-	
-  box1 = gtk_hbox_new (FALSE, 0);
-
-  buttonl = gtk_button_new_with_label ("ccw");
-  buttonr = gtk_button_new_with_label (" cw");
-  gtk_container_set_border_width (GTK_CONTAINER (buttonl), 5);
-  gtk_container_set_border_width (GTK_CONTAINER (buttonr), 5);
-
-  g_signal_connect (buttonl, "pressed",			    
-		      G_CALLBACK(ccw_cb), (gpointer)enc);
-  g_signal_connect (buttonr, "pressed",			    
-		      G_CALLBACK(cw_cb), (gpointer)enc);
-	
-		
+  GtkWidget *box1 = gtk_hbox_new(FALSE, 0);
+  GtkWidget *buttonl = gtk_button_new_with_label("ccw");
+  GtkWidget *buttonr = gtk_button_new_with_label(" cw");
+  gtk_container_set_border_width(GTK_CONTAINER(buttonl), 5);
+  gtk_container_set_border_width(GTK_CONTAINER(buttonr), 5);
+  g_signal_connect(buttonl, "pressed",
+                   G_CALLBACK(ccw_cb), (gpointer)enc);
+  g_signal_connect(buttonr, "pressed",
+                   G_CALLBACK(cw_cb), (gpointer)enc);
   gtk_widget_show(buttonl);
   gtk_widget_show(buttonr);
-  gtk_box_pack_start (GTK_BOX (box1), buttonl, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (box1), buttonr, FALSE, FALSE, 0);
-	
-	
+  gtk_box_pack_start(GTK_BOX(box1), buttonl, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(box1), buttonr, FALSE, FALSE, 0);
   // Tell gpsim which widget to use in breadboard.
   enc->set_widget(box1);
 }
 
+
 //--------------------------------------------------------------
 // construct
-Module * Encoder::construct(const char *_new_name=NULL)
+Module *Encoder::construct(const char *_new_name = nullptr)
 {
-
   Encoder *enc_p = new Encoder(_new_name);
-
   enc_p->create_widget(enc_p);
-
   return enc_p;
-
 }
 
+
 Encoder::Encoder(const char * _name)
-    : Module(_name, "Encoder"), rs(rot_detent)
+  : Module(_name, "Encoder"), rs(rot_detent)
 {
   create_iopin_map();
 }
 
-Encoder::~Encoder(void)
+
+Encoder::~Encoder()
 {
   /* done elsewhere RRR
   delete a_pin;
@@ -154,73 +131,77 @@ Encoder::~Encoder(void)
   */
 }
 
-void
-Encoder::send_cw(void)
+
+void Encoder::send_cw()
 {
-    switch (rs) {
-	case rot_detent:
-	    rs = rot_moving_cw;
-	    toggle_a(); /* A toggles before B going clockwise */
-	    schedule_tick();
-	    break;
-	default:
-	    // XXX: ought to do something here as well
-	    break;
-    }
+  switch (rs) {
+  case rot_detent:
+    rs = rot_moving_cw;
+    toggle_a(); /* A toggles before B going clockwise */
+    schedule_tick();
+    break;
+
+  default:
+    // XXX: ought to do something here as well
+    break;
+  }
 }
 
-void
-Encoder::send_ccw(void)
+
+void Encoder::send_ccw()
 {
-    switch (rs) {
-	case rot_detent:
-	    rs = rot_moving_ccw;
-	    toggle_b();
-	    schedule_tick();
-	    break;
-	default:
-	    // XXX: ought to do something here as well
-	    break;
-    }
+  switch (rs) {
+  case rot_detent:
+    rs = rot_moving_ccw;
+    toggle_b();
+    schedule_tick();
+    break;
+
+  default:
+    // XXX: ought to do something here as well
+    break;
+  }
 }
 
-void
-Encoder::toggle_a()
+
+void Encoder::toggle_a()
 {
   a_pin->toggle();
 }
 
-void
-Encoder::toggle_b()
+
+void Encoder::toggle_b()
 {
   b_pin->toggle();
 }
 
-void
-Encoder::schedule_tick()
+
+void Encoder::schedule_tick()
 {
-    /* XXX: make the time delay configurable */
-    if (!get_cycles().set_break_delta(100, this)) {
-	std::cerr << "Encoder: error setting breakpoint." << std::endl;
-    }
+  /* XXX: make the time delay configurable */
+  if (!get_cycles().set_break_delta(100, this)) {
+    std::cerr << "Encoder: error setting breakpoint.\n";
+  }
 }
 
-void
-Encoder::callback()
+
+void Encoder::callback()
 {
-    switch (rs) {
-	case rot_detent:
-	    assert(false);
-	    break;
-	case rot_moving_cw:
-	    toggle_b();
-	    rs = rot_detent;
-	    break;
-	case rot_moving_ccw:
-	    toggle_a();
-	    rs = rot_detent;
-	    break;
-    }
+  switch (rs) {
+  case rot_detent:
+    assert(false);
+    break;
+
+  case rot_moving_cw:
+    toggle_b();
+    rs = rot_detent;
+    break;
+
+  case rot_moving_ccw:
+    toggle_a();
+    rs = rot_detent;
+    break;
+  }
 }
 
 #endif // HAVE_GUI
