@@ -14,7 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
@@ -37,8 +37,8 @@ to be used.
 Here are a list of functions that a gpsim compliant module library should
 support:
 
-  void mod_list(void) - Prints a list of the modules in a library
-  Module_Types * get_mod_list(void)  - Obtain pointer to the list of modules
+  void mod_list() - Prints a list of the modules in a library
+  Module_Types * get_mod_list()  - Obtain pointer to the list of modules
 */
 
 /* IN_MODULE should be defined for modules */
@@ -73,14 +73,13 @@ support:
 #include "i2c2par.h"
 
 
-Module_Types available_modules[] =
-{
+Module_Types available_modules[] = {
 
 #ifndef _WIN32
   // Parallel port interface
   /*
     TSD - removed 16APR06 - The parallel port interface uses the deprecated
-    IOPORT class. 
+    IOPORT class.
   { {"parallel_interface",         "paraface"}, Paraface::construct},
   */
 #endif
@@ -134,7 +133,7 @@ Module_Types available_modules[] =
   { {"i2c2par", "I2C2PAR"},   I2C2PAR_Modules::i2c2par::construct },
 
   // No more modules
-  { {0,0},0}
+  { {0, 0}, 0}
 };
 
 #ifdef __cplusplus
@@ -148,11 +147,9 @@ extern "C" {
  * This is a required function for gpsim compliant libraries.
  */
 
-Module_Types * get_mod_list(void)
+Module_Types *get_mod_list()
 {
-
-    return available_modules;
-
+  return available_modules;
 }
 
 
@@ -161,38 +158,39 @@ Module_Types * get_mod_list(void)
  *
  * This is a required function for gpsim compliant libraries.
  */
-void mod_list(void)
+void mod_list()
 {
+  size_t number_of = sizeof(available_modules) / sizeof(Module_Types);
+  size_t i, j, l;
+  size_t k, longest;
 
-  unsigned int number_of = sizeof(available_modules) / sizeof(Module_Types);
-  unsigned int i,j,l;
-  unsigned int k,longest;
+  for (i = 0, longest = 0; i < number_of; i++) {
+    k = strlen(available_modules[i].names[1]);
 
-  for(i=0,longest=0; i<number_of; i++)
-    {
-      k = (unsigned int)strlen(available_modules[i].names[1]);
-      if(k>longest)
-	longest = k;
+    if (k > longest) {
+      longest = k;
+    }
+  }
+
+  k = 0;
+
+  do {
+    for (i = 0; (i < 4) && (k < number_of); i++) {
+      std::cout << available_modules[k].names[1];
+
+      if (i < 3) {
+        l = longest + 2 - strlen(available_modules[k].names[1]);
+
+        for (j = 0; j < l; j++) {
+          std::cout << ' ';
+        }
+      }
+
+      k++;
     }
 
-  k=0;
-  do
-    {
-
-      for(i=0; (i<4) && (k<number_of); i++)
-	{
-	  cout << available_modules[k].names[1];
-	  if(i<3)
-	    {
-	      l = longest + 2 - (unsigned int)strlen(available_modules[k].names[1]);
-	      for(j=0; j<l; j++)
-		cout << ' ';
-	    }
-	  k++;
-	}
-      cout << '\n';
-    } while (k < number_of);
-
+    std::cout << '\n';
+  } while (k < number_of);
 }
 
 
@@ -200,11 +198,10 @@ void mod_list(void)
  *
  * _init() - this is called when the library is opened.
  */
-void init(void)
+void init()
 {
-
   //cout << "gpsim modules has been opened\n";
-  printf("%s\n",__FUNCTION__);
+  printf("%s\n", __FUNCTION__);
 }
 
 
@@ -212,19 +209,17 @@ void init(void)
  *
  * _fini() - this is called when the library is closed.
  */
-void fini(void)
+void fini()
 {
-
   //cout << "gpsim modules has been closed\n";
-  printf("%s\n",__FUNCTION__);
+  printf("%s\n", __FUNCTION__);
 }
 
 
-void test(void)
+void test()
 {
   //cout << "This is a test\n";
-  printf("%s\n",__FUNCTION__);
-
+  printf("%s\n", __FUNCTION__);
 }
 
 #ifdef __cplusplus
