@@ -19,8 +19,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 
-#ifndef __I2C2PAR_H__
-#define __I2C2PAR_H__
+#ifndef MODULES_I2C2PAR_H_
+#define MODULES_I2C2PAR_H_
 
 /* IN_MODULE should be defined for modules */
 #define IN_MODULE
@@ -36,30 +36,27 @@ class IOPort;
 class AddAttribute;
 namespace I2C2PAR_Modules {
 
-  class i2c2par : public i2c_slave, public Module, public TriggerObject
-  {
+class i2c2par : public i2c_slave, public Module { //, public TriggerObject
+public:
+  explicit i2c2par(const char *_name);
+  ~i2c2par();
 
-  public:
-    i2c2par(const char *_name);
-    ~i2c2par();
-    static Module *construct(const char *new_name);
-    virtual void create_iopin_map();
-    virtual void setEnable(bool bNewState, unsigned int m_bit){};
-    virtual bool match_address();
-    virtual void put_data(unsigned int data);
-    virtual unsigned int get_data();
-    virtual void slave_transmit(bool yes);
+  static Module *construct(const char *new_name);
+  virtual void create_iopin_map();
+  virtual void setEnable(bool /* bNewState */ , unsigned int /* m_bit */ ) {}
+  virtual bool match_address();
+  virtual void put_data(unsigned int data);
+  virtual unsigned int get_data();
+  virtual void slave_transmit(bool yes);
 
-    IOPort *io_port;
+  IOPort *io_port;
 
-  protected:
+protected:
+  AddAttribute *Addattr;
+  IO_bi_directional_pu **pins;
+};
 
-    AddAttribute *Addattr;
-    IO_bi_directional_pu **pins;
-  };
-
-  
 
 } // end of namespace I2C2PAR_Modules
 
-#endif // __I2C2PAR_H__
+#endif // MODULES_I2C2PAR_H_
