@@ -14,15 +14,13 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
 
-
-
-#ifndef __PSHB_H__
-#define __PSHB_H__
+#ifndef MODULES_PSHB_H_
+#define MODULES_PSHB_H_
 
 /* IN_MODULE should be defined for modules */
 #define IN_MODULE
@@ -33,29 +31,27 @@ License along with this library; if not, see
 
 class IOPIN;
 
-class PushButton : public Module
-{
-    void create_widget(PushButton *pb);
+class PushButton : public Module {
+  void create_widget(PushButton *pb);
+
 public:
+  explicit PushButton(const char *);
+  ~PushButton();
 
-    IOPIN *pshb_pin;
-
-    PushButton(const char *);
-    ~PushButton(void);
-
-
-    void test(void);
-    void update(void);
-
-    // Inheritances from the Package class
-    virtual void create_iopin_map(void);
-
-    // Inheritance from Module class
-    const virtual char *type(void) { return ("push_button"); };
-    static Module *construct(const char *new_name);
+  void test();
+  void update();
 
+  // Inheritances from the Package class
+  virtual void create_iopin_map();
 
+  // Inheritance from Module class
+  const virtual char *type()
+  {
+    return "push_button";
+  }
+  static Module *construct(const char *new_name);
 
+  IOPIN *pshb_pin;
 };
 
-#endif //  __PSHB_H__
+#endif // MODULES_PSHB_H_
