@@ -14,13 +14,13 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
 
-#ifndef __RESISTOR_H__
-#define __RESISTOR_H__
+#ifndef MODULES_RESISTOR_H_
+#define MODULES_RESISTOR_H_
 
 /* IN_MODULE should be defined for modules */
 #define IN_MODULE
@@ -32,7 +32,6 @@ struct GtkToggleButton;
 #endif
 
 
-
 #include <glib.h>
 
 #include "../src/modules.h"
@@ -42,10 +41,8 @@ class  ResistanceAttribute;
 class  CapacitanceAttribute;
 class  VoltageAttribute;
 
-class PullupResistor : public Module , public TriggerObject
-{
+class PullupResistor : public Module, public TriggerObject {
 public:
-
   IO_bi_directional_pu *res;
 
 #ifdef MANAGING_GUI
@@ -54,23 +51,23 @@ public:
 
 #endif
 
-  PullupResistor(const char *init_name=NULL, const char *desc=NULL, float vinit=5.0);
+  PullupResistor(const char *init_name = nullptr, const char *desc = nullptr, float vinit = 5.0);
   ~PullupResistor();
 
   // Inheritances from the Package class
-  virtual void create_iopin_map(void);
+  virtual void create_iopin_map();
 
-  static Module *pu_construct(const char *new_name=NULL);
-  static Module *pd_construct(const char *new_name=NULL);
+  static Module *pu_construct(const char *new_name = nullptr);
+  static Module *pd_construct(const char *new_name = nullptr);
 
 #ifdef MANAGING_GUI
-  void build_window(void);
+  void build_window();
 #endif
 private:
   ResistanceAttribute *attr;
   CapacitanceAttribute *cattr;
   VoltageAttribute *vattr;
-
-
 };
-#endif //  __RESISTOR_H__
+
+
+#endif // MODULES_RESISTOR_H_
