@@ -14,13 +14,13 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
 
-#ifndef __USART_MODULE_H__
-#define __USART_MODULE_H__
+#ifndef MODULES_USART_MODULE_H_
+#define MODULES_USART_MODULE_H_
 
 /* IN_MODULE should be defined for modules */
 #define IN_MODULE
@@ -48,15 +48,14 @@ class USART_TXPIN;
 class USART_RXPIN;
 class USART_IO;
 
-class USARTModule : public Module
-{
- public:
+class USARTModule : public Module {
+public:
 
 #ifdef HAVE_GUI
   GtkWidget *window, *text;
 #endif // HAVE_GUI
- 
-  void CreateGraphics(void);
+
+  void CreateGraphics();
   virtual void show_tx(unsigned int data);
   virtual void SendByte(unsigned tx_byte);
 
@@ -64,15 +63,16 @@ class USARTModule : public Module
   // Inheritances from the Package class
   virtual void create_iopin_map();
 
-  USARTModule(const char *new_name);
+  explicit USARTModule(const char *new_name);
   ~USARTModule();
 
-  static Module *USART_construct(const char *new_name=NULL);
+  static Module *USART_construct(const char *new_name = nullptr);
 
   virtual void new_rx_edge(unsigned int);
   virtual bool mGetTxByte(unsigned int &);
   virtual void newRxByte(unsigned int);
   virtual void get(char *, int len);
+
 private:
   RxBaudRateAttribute *m_RxBaud;
   TxBaudRateAttribute *m_TxBaud;
@@ -94,6 +94,7 @@ private:
   int m_FifoLen;
   int m_FifoHead;
   int m_FifoTail;
-
 };
-#endif //  __USART_MODULE_H__
+
+
+#endif // MODULES_USART_MODULE_H_
