@@ -14,13 +14,13 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
 
-#ifndef __VIDEO_H__
-#define __VIDEO_H__
+#ifndef MODULES_VIDEO_H_
+#define MODULES_VIDEO_H_
 
 /* IN_MODULE should be defined for modules */
 #define IN_MODULE
@@ -44,34 +44,49 @@ class Processor;
  */
 
 
-class IOPIN_Monitor : public IOPIN
-{
+class IOPIN_Monitor : public IOPIN {
 private:
   Video *video;
+
 public:
+  IOPIN_Monitor(Video *v, const char *opt_name)
+    : IOPIN(opt_name), video(v)
+  {
+  }
 
-  virtual void setDrivenState( bool new_state);
-
-  IOPIN_Monitor (Video *v, const char *opt_name) 
-    : IOPIN(opt_name) , video(v)
-    { 
-    }
-
+  virtual void setDrivenState(bool new_state);
 };
 
 
 #define XRES 640
 #define YRES 625
 
-class Video : public Module
-{
+class Video : public Module {
 public:
+  explicit Video(const char *);
+  ~Video();
 
-  IOPIN * sync_pin;
-  IOPIN * lume_pin;
+  // Inheritances from the Package class
+  virtual void create_iopin_map();
+
+  virtual void update_state();
+  virtual int get_num_of_pins()
+  {
+    return 2;
+  }
+  void copy_scanline_to_pixmap();
+  int check_for_vrt1();
+  int check_for_vrt2();
+  guint64 cycles_to_us(guint64 cycles);
+  guint64 us_to_cycles(guint64 cycles);
+  void refresh();
+  static Module *construct(const char *new_name);
+
+  IOPIN *sync_pin;
+  IOPIN *lume_pin;
   guint64 sync_time; // gpsim cycle counter at last H-sync
   int scanline;
-  unsigned char line[XRES]; // buffer for one line
+  unsigned char line[XRES];         // buffer for one line
   unsigned char shadow[XRES][YRES]; // pixmap mirror
   Processor *cpu;
 
@@ -82,26 +97,13 @@ public:
   int line_nr;
   int last_line_nr;
 
-  Video(const char *);
-  ~Video();
-
-  // Inheritances from the Package class
-  virtual void create_iopin_map();
-
-  virtual void update_state();
-  virtual int get_num_of_pins() {return 2;};
-  void copy_scanline_to_pixmap();
-  int check_for_vrt1();
-  int check_for_vrt2();
-  guint64 cycles_to_us(guint64 cycles);
-  guint64 us_to_cycles(guint64 cycles);
-  void refresh();
-  static Module *construct(const char *new_name);
-
 private:
-    Video_Interface *interface;
+  Video_Interface *interface;
 
+  int last_port_value = 0;
+  int shortsync_counter = 0;
+  int last_shortsync_counter = 0;
 };
 
-#endif //  __VIDEO_H__
+#endif // MODULES_VIDEO_H_
 
