@@ -22,9 +22,10 @@ touch $LOGFILE
 # Run the simulation and save the results
 ${MAKE:-make} $2 > $LOGFILE
 
+
+grep "FAILED" $LOGFILE
+if [ $? -eq 0 ] ; then
+  echo "!!! FAILED $1/make $2"
+fi
 grep "PASSED" $LOGFILE
 
-if [ $? -ne 0 ] ; then
-  echo "!!! FAILED $1/make $2"
-  grep "FAILED" $LOGFILE
-fi
