@@ -14,23 +14,26 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-
 #include "pic-processor.h"
 
+#ifndef SRC_12_BIT_PROCESSORS_H_
+#define SRC_12_BIT_PROCESSORS_H_
 
-#ifndef __12_BIT_PROCESSORS_H__
-#define __12_BIT_PROCESSORS_H__
+#include "14bit-registers.h"
+#include "gpsim_classes.h"
 
-     // forward references
-class _12bit_processor;
-class IOPIN;
+#include "registers.h"
+
+// forward references
 class OptionTraceType;
+class OPTION_REG;
+class instruction;
 
-extern instruction *disasm12 (pic_processor *cpu,unsigned int address,unsigned int inst);
+extern instruction *disasm12 (pic_processor *cpu, unsigned int address, unsigned int inst);
 
 
 class _12bit_processor : public pic_processor
@@ -61,26 +64,26 @@ enum _12BIT_DEFINITIONS
 
   virtual void create_symbols();
   #define FILE_REGISTERS  0x100
-  virtual unsigned int register_memory_size () const { return FILE_REGISTERS;};
+  virtual unsigned int register_memory_size () const { return FILE_REGISTERS;}
   virtual void dump_registers();
-  virtual void tris_instruction(unsigned int tris_register){return;};
+  virtual void tris_instruction(unsigned int){return;}
   virtual void create();
   virtual void create_config_memory();
-  virtual PROCESSOR_TYPE isa(){return _12BIT_PROCESSOR_;};
-  virtual PROCESSOR_TYPE base_isa(){return _12BIT_PROCESSOR_;};
+  virtual PROCESSOR_TYPE isa(){return _12BIT_PROCESSOR_;}
+  virtual PROCESSOR_TYPE base_isa(){return _12BIT_PROCESSOR_;}
   virtual instruction * disasm (unsigned int address, unsigned int inst)
     {
       return disasm12(this, address, inst);
     }
-  void interrupt() { return; };
+  void interrupt() { return; }
 
   // Declare a set of functions that will allow the base class to
   // get information about the derived classes. NOTE, the values returned here
   // will cause errors if they are used -- the derived classes must define their
   // parameters appropriately.
-  virtual unsigned int program_memory_size(){ return 3; }; // A bogus value that will cause errors if used
+  virtual unsigned int program_memory_size(){ return 3; } // A bogus value that will cause errors if used
   // The size of a program memory bank is 2^11 bytes for the 12-bit core
-  virtual void create_sfr_map() { return;};
+  virtual void create_sfr_map() { return;}
 
   // Return the portion of pclath that is used during branching instructions
   // Actually, the 12bit core has no pclath. However, the program counter class doesn't need
@@ -103,7 +106,7 @@ enum _12BIT_DEFINITIONS
 
   virtual unsigned int fsr_valid_bits()
     {
-      return 0x1f;  // Assume only 32 register addresses 
+      return 0x1f;  // Assume only 32 register addresses
     }
 
   virtual unsigned int fsr_register_page_bits()
@@ -114,7 +117,7 @@ enum _12BIT_DEFINITIONS
   virtual void put_option_reg(unsigned int);
   virtual void option_new_bits_6_7(unsigned int);
 
-  virtual unsigned int config_word_address() const {return 0xfff;};
+  virtual unsigned int config_word_address() const {return 0xfff;}
   virtual bool set_config_word(unsigned int address, unsigned int cfg_word);
   virtual void enter_sleep();
   virtual void exit_sleep();
