@@ -14,43 +14,42 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
+#ifndef SRC_16_BIT_REGISTERS_H_
+#define SRC_16_BIT_REGISTERS_H_
+
 #include <iostream>
-#include <stdio.h>
+#include <string>
 
-
-class InvalidRegister;   // Forward reference
-
-
-#ifndef __16_BIT_REGISTERS_H__
-#define __16_BIT_REGISTERS_H__
-
-#include "pic-processor.h"
-#include "14bit-registers.h"
 #include "14bit-tmrs.h"
-#include "pir.h"
-#include "uart.h"
-#include "a2dconverter.h"
-#include "ssp.h"
-#include "rcon.h"
+#include "eeprom.h"
+#include "gpsim_classes.h"
+#include "pic-registers.h"
+#include "registers.h"
+#include "stimuli.h"
+#include "tmr0.h"
+#include "trigger.h"
+#include "14bit-registers.h"
+
 #define _16BIT_REGISTER_MASK   0xfff
 
+class HLVDCON;
+class INTCON;
+class Indirect_Addressing;
+class InterruptSource;
+class PIR_SET;
+class PinModule;
+class Processor;
+class Stack16;
 class _16bit_processor;
-
-class stimulus;  // forward reference
-class IOPIN;
-class source_stimulus;
-class Stimulus_Node;
-class PORTB;
-
-
+class pic_processor;
 
 
 //---------------------------------------------------------
-// 
+//
 // Indirect_Addressing
 //
 // This class coordinates the indirect addressing on the 18cxxx
@@ -60,17 +59,17 @@ class PORTB;
 // in the Indirect_Addressing class. So accessing these registers
 // is the same as accessing any register: through the core cpu's
 // register memory. The only difference for these registers is that
-// the 
+// the
+
 
-class Indirect_Addressing;   // Forward reference
 
 //---------------------------------------------------------
 // FSR registers
 
-class FSRL : public sfr_register
-{
+class FSRL : public sfr_register {
 public:
   FSRL(Processor *, const char *pName, const char *pDesc, Indirect_Addressing *pIAM);
+
   void put(unsigned int new_value);
   void put_value(unsigned int new_value);
 
@@ -78,34 +77,34 @@ protected:
   Indirect_Addressing  *iam;
 };
 
-class FSRH : public sfr_register
-{
- public:
+
+class FSRH : public sfr_register {
+public:
   FSRH(Processor *, const char *pName, const char *pDesc, Indirect_Addressing *pIAM);
 
   void put(unsigned int new_value);
   void put_value(unsigned int new_value);
-      
+
 protected:
   Indirect_Addressing  *iam;
 };
 
-class INDF16 : public sfr_register
-{
- public:
+
+class INDF16 : public sfr_register {
+public:
   INDF16(Processor *, const char *pName, const char *pDesc, Indirect_Addressing *pIAM);
 
   void put(unsigned int new_value);
   void put_value(unsigned int new_value);
   unsigned int get();
   unsigned int get_value();
-      
+
 protected:
   Indirect_Addressing  *iam;
 };
 
-class PREINC : public sfr_register
-{
+
+class PREINC : public sfr_register {
 public:
   PREINC(Processor *, const char *pName, const char *pDesc, Indirect_Addressing *pIAM);
 
@@ -113,13 +112,13 @@ public:
   void put_value(unsigned int new_value);
   unsigned int get();
   unsigned int get_value();
-      
+
 protected:
   Indirect_Addressing  *iam;
 };
 
-class POSTINC : public sfr_register
-{
+
+class POSTINC : public sfr_register {
 public:
   POSTINC(Processor *, const char *pName, const char *pDesc, Indirect_Addressing *pIAM);
 
@@ -127,13 +126,13 @@ public:
   void put_value(unsigned int new_value);
   unsigned int get();
   unsigned int get_value();
-      
+
 protected:
   Indirect_Addressing  *iam;
 };
 
-class POSTDEC : public sfr_register
-{
+
+class POSTDEC : public sfr_register {
 public:
   POSTDEC(Processor *, const char *pName, const char *pDesc, Indirect_Addressing *pIAM);
 
@@ -141,13 +140,13 @@ public:
   void put_value(unsigned int new_value);
   unsigned int get();
   unsigned int get_value();
-      
+
 protected:
   Indirect_Addressing  *iam;
 };
 
-class PLUSW : public sfr_register
-{
+
+class PLUSW : public sfr_register {
 public:
   PLUSW(Processor *, const char *pName, const char *pDesc, Indirect_Addressing *pIAM);
 
@@ -155,18 +154,18 @@ public:
   void put_value(unsigned int new_value);
   unsigned int get();
   unsigned int get_value();
-      
+
 protected:
   Indirect_Addressing  *iam;
 };
 
-class Indirect_Addressing
-{
+
+class Indirect_Addressing {
 public:
-  Indirect_Addressing(pic_processor *cpu, const string &n);
+  Indirect_Addressing(pic_processor *cpu, const std::string &n);
 
   pic_processor *cpu;
-//RRR  _16bit_processor *cpu;
+  //RRR  _16bit_processor *cpu;
 
   unsigned int fsr_value;     // 16bit concatenation of fsrl and fsrh
   unsigned int fsr_state;     /* used in conjunction with the pre/post incr
@@ -175,7 +174,7 @@ public:
 			       * write operations on the indirect registers
 			       * eg. btg POSTINC1,4 . The post increment must
 			       * occur after the bit is toggled and not during
-			       * the read operation that's determining the 
+			       * the read operation that's determining the
 			       * current state.
 			       */
   int     fsr_delta;          /* If there's a pending update to the fsr register
@@ -183,7 +182,7 @@ public:
 			       * stored here.
 			       */
   guint64 current_cycle;      /* Stores the cpu cycle when the fsr was last
-			       * changed. 
+			       * changed.
 			       */
   FSRL    fsrl;
   FSRH    fsrh;
@@ -198,7 +197,10 @@ public:
   unsigned int get();
   unsigned int get_value();
   void put_fsr(unsigned int new_fsr);
-  unsigned int get_fsr_value(){return (fsr_value & 0xfff);};
+  unsigned int get_fsr_value()
+  {
+    return (fsr_value & 0xfff);
+  }
   void update_fsr_value();
   void preinc_fsr_value();
   void postinc_fsr_value();
@@ -228,56 +230,56 @@ public:
    * the common bit pattern 1111 11xx x011 for the left column.
    * Furthermore, the middle 3-bits, xxx, can only be 3,4, 5.
    * The ranges in the last two columns share the bit pattern
-   * 1111 11vv v1yy. The middle 3-bits, vvv, again can only be 
+   * 1111 11vv v1yy. The middle 3-bits, vvv, again can only be
    * 3,4, or 5. The least two lsbs, yy, are don't cares.
    */
 
   inline bool is_indirect_register(unsigned int reg_address)
-    {
-      if( ((reg_address & 0xfc7) == 0xfc3) || ((reg_address & 0xfc4) == 0xfc4))
-	{
-	  unsigned midbits = (reg_address >> 3) & 0x7;
-	  if(midbits >= 3 && midbits <= 5)
-	    return 1;
-	}
-      return 0;
+  {
+    if (((reg_address & 0xfc7) == 0xfc3) || ((reg_address & 0xfc4) == 0xfc4)) {
+      unsigned midbits = (reg_address >> 3) & 0x7;
+
+      if (midbits >= 3 && midbits <= 5) {
+        return true;
+      }
     }
-
-
+    return false;
+  }
 };
 
+
 //---------------------------------------------------------
-class Fast_Stack
-{
- public:
-
-  unsigned int w,status,bsr;
-  _16bit_processor *cpu;
-
+class Fast_Stack {
+public:
   void init(_16bit_processor *new_cpu);
   void push();
   void pop();
 
+  unsigned int w = 0;
+  unsigned int status = 0;
+  unsigned int bsr = 0;
+  _16bit_processor *cpu = nullptr;
 };
 
+
 //---------------------------------------------------------
-class PCL16 : public PCL
-{
+class PCL16 : public PCL {
 public:
+  PCL16(Processor *, const char *pName, const char *pDesc = nullptr);
 
   virtual unsigned int get();
   virtual unsigned int get_value();
-
-  PCL16(Processor *, const char *pName, const char *pDesc=0);
 };
 
+
 //---------------------------------------------------------
 // Program Counter
 //
 
-class Program_Counter16 : public Program_Counter
-{
+class Program_Counter16 : public Program_Counter {
 public:
+  explicit Program_Counter16(Processor *pCpu);
+
   //virtual void increment();
   //virtual void skip();
   //virtual void jump(unsigned int new_value);
@@ -285,137 +287,118 @@ public:
   virtual void computed_goto(unsigned int new_value);
   //virtual void new_address(unsigned int new_value);
   virtual void put_value(unsigned int new_value);
+  virtual void update_pcl();
   virtual unsigned int get_value();
   //virtual unsigned int get_next();
-
-  Program_Counter16(Processor *pCpu);
 };
 
 
 //---------------------------------------------------------
 // Stack
 //
-class Stack16;
 
-class STKPTR16 : public sfr_register
-{
+class STKPTR16 : public sfr_register {
 public:
-
   enum {
-	STKUNF = 1<<6,
-	STKOVF = 1<<7
+    STKUNF = 1 << 6,
+    STKOVF = 1 << 7
   };
-  STKPTR16(Processor *, const char *pName, const char *pDesc=0);
+  STKPTR16(Processor *, const char *pName, const char *pDesc = nullptr);
 
-  Stack16 *stack;
   void put_value(unsigned int new_value);
   void put(unsigned int new_value);
+
+  Stack16 *stack = nullptr;
 };
 
 
-class TOSU : public sfr_register
-{
+class TOSU : public sfr_register {
 public:
-  TOSU(Processor *, const char *pName, const char *pDesc=0);
-
-  Stack16 *stack;
+  TOSU(Processor *, const char *pName, const char *pDesc = nullptr);
 
   void put(unsigned int new_value);
   void put_value(unsigned int new_value);
   unsigned int get();
   unsigned int get_value();
-      
+
+  Stack16 *stack = nullptr;
 };
 
 
-class Stack16 : public Stack
-{
+class Stack16 : public Stack {
 public:
-  STKPTR16 stkptr;
-  TOSL   tosl;
-  TOSH   tosh;
-  TOSU   tosu;
-
-  Stack16(Processor *);
+  explicit Stack16(Processor *);
   ~Stack16();
+
   virtual bool push(unsigned int);
   virtual unsigned int pop();
   virtual void reset(RESET_TYPE);
   virtual bool stack_overflow();
   virtual bool stack_underflow();
 
+  STKPTR16 stkptr;
+  TOSL   tosl;
+  TOSH   tosh;
+  TOSU   tosu;
 };
 
 
-class TMR0_16;
-
-
 //---------------------------------------------------------
-class CPUSTA :  public sfr_register
-{
+class CPUSTA :  public sfr_register {
 public:
 
-  enum
-  {
-    BOR      = 1<<0,
-    POR      = 1<<1,
-    PD       = 1<<2,
-    TO       = 1<<3,
-    GLINTD   = 1<<4,
-    STKAV    = 1<<5,
+  enum {
+    BOR      = 1 << 0,
+    POR      = 1 << 1,
+    PD       = 1 << 2,
+    TO       = 1 << 3,
+    GLINTD   = 1 << 4,
+    STKAV    = 1 << 5,
   };
-  CPUSTA(Processor *, const char *pName, const char *pDesc=0);
+  CPUSTA(Processor *, const char *pName, const char *pDesc = nullptr);
 };
 
 
 //---------------------------------------------------------
 // T0CON - Timer 0 control register
-class T0CON : public OPTION_REG
-{
+class T0CON : public OPTION_REG {
 public:
 
   enum {
-    T08BIT = 1<<6,
-    TMR0ON = 1<<7
+    T08BIT = 1 << 6,
+    TMR0ON = 1 << 7
   };
 
-  T0CON(Processor *, const char *pName, const char *pDesc=0);
+  T0CON(Processor *, const char *pName, const char *pDesc = nullptr);
+
   void put(unsigned int new_value);
   void initialize();
 };
 
+
 //---------------------------------------------------------
 // TMR0 - Timer for the 16bit core.
 //
-// The 18cxxx extends TMR0 to a 16-bit timer. However, it maintains 
-// an 8-bit mode that is compatible with the 8-bit TMR0's in the 
+// The 18cxxx extends TMR0 to a 16-bit timer. However, it maintains
+// an 8-bit mode that is compatible with the 8-bit TMR0's in the
 // 14 and 12-bit cores. The 18cxxx TMR0 reuses this code by deriving
 // from the TMR0 class and providing definitions for many of the
 // virtual functions.
 
-class TMR0H : public sfr_register
-{
+class TMR0H : public sfr_register {
 public:
-
-  TMR0H(Processor *, const char *pName, const char *pDesc=0);
+  TMR0H(Processor *, const char *pName, const char *pDesc = nullptr);
 
   void put(unsigned int new_value);
   void put_value(unsigned int new_value);
   unsigned int get();
   unsigned int get_value();
-
 };
 
-class TMR0_16 : public TMR0
-{
+
+class TMR0_16 : public TMR0 {
 public:
-
-  TMR0_16(Processor *, const char *pName, const char *pDesc=0);
-
-  T0CON  *t0con;
-  INTCON *intcon;
-  TMR0H  *tmr0h;
-  unsigned int value16;
+  TMR0_16(Processor *, const char *pName, const char *pDesc = nullptr);
 
   virtual void callback();
   virtual void callback_print();
@@ -429,9 +412,14 @@ public:
   virtual void set_t0if();
   virtual bool get_t0cs();
   virtual void initialize();
-  virtual void start(int new_value,int sync=0);
+  virtual void start(int new_value, int sync = 0);
   virtual void sleep();
   virtual void wake();
+
+  T0CON  *t0con = nullptr;
+  INTCON *intcon = nullptr;
+  TMR0H  *tmr0h = nullptr;
+  unsigned int value16 = 0;
 };
 
 
@@ -449,125 +437,76 @@ public:
 
 };
 */
-class T3CON : public T1CON
-{
+
+
+class T3CON : public T1CON {
 public:
-  enum
-  {
-    T3CCP1 = 1<<3,
-    T3CCP2 = 1<<6,
-  };
+  enum { T3CCP1 = 1 << 3, T3CCP2 = 1 << 6,
+       };
 
-  CCPRL *ccpr1l;
-  CCPRL *ccpr2l;
-  TMRL  *tmr1l; 
+  T3CON(Processor *pCpu, const char *pName, const char *pDesc = nullptr);
 
-  T3CON(Processor *pCpu, const char *pName, const char *pDesc=0);
   virtual void put(unsigned int new_value);
+  virtual bool get_t1oscen()
+  {
+    if (t1con) {
+      return t1con->get_t1oscen();
+    }
 
+    return false;
+  }
+
+  CCPRL *ccpr1l = nullptr;
+  CCPRL *ccpr2l = nullptr;
+  TMRL  *tmr1l = nullptr;
+  T1CON *t1con = nullptr;
 };
 
+
 //---------------------------------------------------------
 //
 // TMR3_MODULE
 //
-// 
+//
 
-class TMR3_MODULE
-{
+class TMR3_MODULE {
 public:
-
-  _16bit_processor *cpu;
-  char * name_str;
-
-  T3CON *t3con;
-  PIR_SET  *pir_set;
-
   TMR3_MODULE();
+
   void initialize(T3CON *t1con, PIR_SET *pir_set);
 
+  _16bit_processor *cpu = nullptr;
+  char *name_str = nullptr;
+  T3CON *t3con = nullptr;
+  PIR_SET *pir_set = nullptr;
 };
 
+
 //-------------------------------------------------------------------
-#if 0
 
-class TABLAT : public sfr_register
-{
- public:
-
-  void put(unsigned int new_value);
-  void put_value(unsigned int new_value);
-  unsigned int get();
-  unsigned int get_value();
-
-};
-
-class TABPTRL : public sfr_register
-{
- public:
-
-  void put(unsigned int new_value);
-  void put_value(unsigned int new_value);
-  unsigned int get();
-  unsigned int get_value();
-
-};
-
-class TABPTRH : public sfr_register
-{
- public:
-
-  void put(unsigned int new_value);
-  void put_value(unsigned int new_value);
-  unsigned int get();
-  unsigned int get_value();
-
-};
-
-class TABPTRU : public sfr_register
-{
- public:
-
-  void put(unsigned int new_value);
-  void put_value(unsigned int new_value);
-  unsigned int get();
-  unsigned int get_value();
-
-};
-
-#endif
-
-class TBL_MODULE
-{
+class TBL_MODULE : public EEPROM_EXTND {
 public:
-  TBL_MODULE(_16bit_processor *pCpu);
-
-  unsigned int state;
-  unsigned int internal_latch;
-
-  _16bit_processor *cpu;
-
-#if 0
-  TABLAT    tablat;
-  TABPTRL   tabptrl;
-  TABPTRH   tabptrh;
-  TABPTRU   tabptru;
-#endif
-  sfr_register   tablat,
-                 tabptrl,
-                 tabptrh,
-                 tabptru;
+  explicit TBL_MODULE(_16bit_processor *pCpu);
 
   void increment();
   void decrement();
   void read();
   void write();
+  virtual void start_write();
   //void initialize(_16bit_processor *);
+
+  unsigned int state = 0;
+  unsigned int internal_latch = 0;
+
+  _16bit_processor *cpu;
+
+  sfr_register   tablat,
+                 tblptrl,
+                 tblptrh,
+                 tblptru;
 };
 
 
-
-
 //////////////////////////////////////////
 //////////////////////////////////////////
 //   vapid Place holders
@@ -575,21 +514,78 @@ public:
 //////////////////////////////////////////
 
 
-class LVDCON : public  sfr_register
-{
+class LVDCON : public  sfr_register {
 public:
   unsigned int valid_bits;
 
   enum {
-    LVDL0 = 1<<0,
-    LVDL1 = 1<<1,
-    LVDL2 = 1<<2,
-    LVDL3 = 1<<3,
-    LVDEN = 1<<4,
-    IRVST = 1<<5,
+    LVDL0 = 1 << 0,
+    LVDL1 = 1 << 1,
+    LVDL2 = 1 << 2,
+    LVDL3 = 1 << 3,
+    LVDEN = 1 << 4,
+    IRVST = 1 << 5,
   };
 
-  LVDCON(Processor *, const char *pName, const char *pDesc=0);
+  LVDCON(Processor *, const char *pName, const char *pDesc = nullptr);
 };
 
-#endif
+
+/*
+   High/Low-Voltage Detect Module
+*/
+
+class HLVD_stimulus : public stimulus {
+public:
+  HLVD_stimulus(HLVDCON *_hlvd, const char *n = nullptr);
+  ~HLVD_stimulus();
+
+  virtual void   set_nodeVoltage(double v);
+
+private:
+  HLVDCON *hlvd;
+};
+
+
+class HLVDCON : public  sfr_register, public TriggerObject {
+public:
+  enum {
+    VDIRMAG = 1 << 7, // Voltage Direction Magnitude Select bit
+    BGVST   = 1 << 6, // Band Gap Reference Voltages Stable Status Flag bit
+    IRVST   = 1 << 5, // Internal Reference Voltage Stable Flag bit
+    HLVDEN  = 1 << 4, // High/Low-Voltage Detect Power Enable bit
+    HLVDL3  = 1 << 3, // Voltage Detection Level bits
+    HLVDL2  = 1 << 2, // Voltage Detection Level bits
+    HLVDL1  = 1 << 1, // Voltage Detection Level bits
+    HLVDL0  = 1 << 0, // Voltage Detection Level bits
+    HLVDL_MASK = 0xf
+  };
+  HLVDCON(Processor *pCpu, const char *pName, const char *pDesc);
+  ~HLVDCON();
+
+  void put(unsigned int new_value);
+  virtual void callback_print()
+  {
+    std::cout <<  name() << " has callback, ID = " << CallBackID << '\n';
+  }
+  void callback();
+  void set_hlvdin(PinModule *_hlvdin)
+  {
+    hlvdin = _hlvdin;
+  }
+  void check_hlvd();
+  virtual void setIntSrc(InterruptSource *_IntSrc)
+  {
+    IntSrc = _IntSrc;
+  }
+
+private:
+  PinModule	   *hlvdin = nullptr;
+  HLVD_stimulus    *hlvdin_stimulus = nullptr;
+  bool		   stimulus_active = false;
+  unsigned int     write_mask;
+  InterruptSource *IntSrc = nullptr;
+};
+
+
+#endif // __16_BIT_REGISTERS_H__
