@@ -1,33 +1,35 @@
-#ifndef __CMD_MANAGER_H__
-#define __CMD_MANAGER_H__
-#include <stdio.h>
+#ifndef SRC_CMD_MANAGER_H_
+#define SRC_CMD_MANAGER_H_
+
 #include "cmd_gpsim.h"
 #include "gpsim_interface.h"
+
+#include <string.h>
+
+#include <list>
 #include <vector>
 #include <string>
 #include <functional>
-using namespace std;
 
 class CommandHandlerKey : public ICommandHandler {
 public:
-  CommandHandlerKey(const char *name) {
-    m_name = name;
+  CommandHandlerKey(const char *name)
+    : m_name(name)
+  {
   }
-  virtual const char *GetName(void) {return m_name; }
-  virtual int Execute(const char * commandline, ISimConsole *out) {
+  virtual const char *GetName() {return m_name; }
+  virtual int Execute(const char * /* commandline */ ,  ISimConsole * /* out */) {
     return CMD_ERR_COMMANDNOTDEFINED;}
-  virtual int ExecuteScript(list<string *> &script, ISimConsole *out)
+  virtual int ExecuteScript(std::list<std::string *> & /* script */ , ISimConsole * /* out */ )
   { return CMD_ERR_ERROR;}
   const char * m_name;
 };
 
-
-
 class CCommandManager {
 public:
   CCommandManager();
   int   Register(ICommandHandler * ch);
-  int   Execute(string &sName, const char *cmdline);
+  int   Execute(std::string &sName, const char *cmdline);
 
   static CCommandManager m_CommandManger;
   static CCommandManager &GetManager();
@@ -38,16 +40,16 @@ public:
   void ListToConsole();
 
 private:
-  struct lessThan : binary_function<ICommandHandler*, ICommandHandler*, bool> {
+  struct lessThan : std::binary_function<ICommandHandler*, ICommandHandler*, bool> {
     bool operator()(const ICommandHandler* left, const ICommandHandler* right) const {
       return strcmp(((ICommandHandler*)left)->GetName(),
         ((ICommandHandler*)right)->GetName()) < 0;
     }
   };
 
-  typedef vector<ICommandHandler*> List;
+  typedef std::vector<ICommandHandler*> List;
 
-  List                  m_HandlerList;
+  List m_HandlerList;
 };
 
 #endif
