@@ -23,6 +23,8 @@ License along with this library; if not, see
 #include "dspic-processors.h"
 #include "dspic-instructions.h"
 
+#include <assert.h>
+
 using namespace dspic;
 using namespace dspic_instructions;
 
@@ -307,7 +309,7 @@ namespace dspic_instructions
 
   AddressingMode::AddressingMode(dspic::dsPicProcessor *cpu,
 				 unsigned int addr)
-    : m_cpu(cpu), m_addr(addr)
+    : m_cpu(cpu), m_mode(0), m_addr(addr)
 
   {
   }
@@ -507,7 +509,7 @@ namespace dspic_instructions
   MultiWordBranch::MultiWordBranch(Processor *new_cpu,
 				       unsigned int new_opcode,
 				       unsigned int addr)
-    : MultiWordInstruction(new_cpu, new_opcode, addr)
+    : MultiWordInstruction(new_cpu, new_opcode, addr), destination_index(0)
   {
   }
 
@@ -786,7 +788,8 @@ namespace dspic_instructions
   //--------------------------------------------------
 
   BRA::BRA (Processor *new_cpu, unsigned int new_opcode, unsigned int addr)
-    : LiteralBranch(new_cpu, new_opcode, addr, "bra")
+    : LiteralBranch(new_cpu, new_opcode, addr, "bra"),
+      m_condition(0)
   {
     new_name("bra");
     switch ((opcode>>16) & 0x0f) {
