@@ -14,7 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
@@ -24,6 +24,7 @@ License along with this library; if not, see
 
 #include <iostream>
 #include <stdio.h>
+#include <string.h>
 
 #include "../../config.h"    // get the definition for HAVE_GUI
 
@@ -39,10 +40,9 @@ public:
   Module * (*module_constructor) (void);
 };
 */
-Module_Types available_modules[] =
-{
+Module_Types available_modules[] = {
   // No more modules
-  { {0,0},0}
+  { {0, 0}, 0}
 };
 
 #ifdef __cplusplus
@@ -56,50 +56,51 @@ extern "C" {
  * This is a required function for gpsim compliant libraries.
  */
 
-  Module_Types * get_mod_list(void)
-  {
+Module_Types * get_mod_list()
+{
+  return available_modules;
+}
 
-    return available_modules;
 
-  }
 /********************************************************************************
  * mod_list - Display all of the modules in this library.
  *
  * This is a required function for gpsim compliant libraries.
  */
 
-void mod_list(void)
+void mod_list()
 {
-
   unsigned int number_of = sizeof(available_modules) / sizeof(Module_Types);
-  unsigned int i,j,l;
-  unsigned int k,longest;
+  size_t i, j, l;
+  size_t k, longest;
 
-  for(i=0,longest=0; i<number_of; i++)
-    {
-      k = (unsigned int)strlen(available_modules[i].names[1]);
-      if(k>longest)
-	longest = k;
+  for (i = 0, longest = 0; i < number_of; i++) {
+    k = strlen(available_modules[i].names[1]);
+
+    if (k > longest) {
+      longest = k;
+    }
+  }
+
+  k = 0;
+
+  do {
+    for (i = 0; (i < 4) && (k < number_of); i++) {
+      std::cout << available_modules[k].names[1];
+
+      if (i < 3) {
+        l = longest + 2 - strlen(available_modules[k].names[1]);
+
+        for (j = 0; j < l; j++) {
+          std::cout << ' ';
+        }
+      }
+
+      k++;
     }
 
-  k=0;
-  do
-    {
-
-      for(i=0; (i<4) && (k<number_of); i++)
-	{
-	  cout << available_modules[k].names[1];
-	  if(i<3)
-	    {
-	      l = longest + 2 - (unsigned int)strlen(available_modules[k].names[1]);
-	      for(j=0; j<l; j++)
-		cout << ' ';
-	    }
-	  k++;
-	}
-      cout << '\n';
-    } while (k < number_of);
-
+    std::cout << '\n';
+  } while (k < number_of);
 }
 
 
@@ -108,11 +109,10 @@ void mod_list(void)
  * _init() - this is called when the library is opened.
  */
 
-void init(void)
+void init()
 {
-
   //cout << "gpsim modules has been opened\n";
-  printf("%s\n",__FUNCTION__);
+  printf("%s\n", __FUNCTION__);
 }
 
 #ifdef __cplusplus
