@@ -18,16 +18,23 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-#ifndef __GPSIM_INTERFACE_H__
-#define __GPSIM_INTERFACE_H__
+#ifndef SRC_GPSIM_INTERFACE_H_
+#define SRC_GPSIM_INTERFACE_H_
 
 #include "gpsim_classes.h"
 #include "interface.h"
 #include "trigger.h"
 
+#include <list>
+#include <string>
+
+#include <glib.h>
+
 class Stimulus;
 class Stimulus_Node;
 class ISimConsole;
+class Processor;
+class Module;
 
 //---------------------------------------------------------------------------
 //
@@ -61,7 +68,7 @@ public:
    *
    */
 
-  virtual void UpdateObject (gpointer xref,int new_value){};
+  virtual void UpdateObject(gpointer /* xref */, int /* new_value */) {}
 
   /*
    * remove_object - Invoked when gpsim has removed something.
@@ -72,7 +79,7 @@ public:
    *
    */
 
-  virtual void RemoveObject (gpointer xref) {};
+  virtual void RemoveObject(gpointer /* xref */) {}
 
 
   /*
@@ -83,14 +90,14 @@ public:
    * allows the interface to uniquely identify the particular one.
    */
 
-  virtual void SimulationHasStopped (gpointer object) {};
+  virtual void SimulationHasStopped(gpointer /* object */) {}
 
 
   /*
    * new_processor - Invoked when a new processor is added to gpsim
    */
 
-  virtual void NewProcessor (Processor *new_cpu) {};
+  virtual void NewProcessor(Processor *) {}
 
 
   /*
@@ -98,13 +105,13 @@ public:
    *
    */
 
-  virtual void NewModule (Module *module) {};
+  virtual void NewModule(Module *) {}
 
   /*
    * node_configuration_changed - invoked when stimulus configuration has changed
    */
 
-  virtual void NodeConfigurationChanged (Stimulus_Node *node) {};
+  virtual void NodeConfigurationChanged(Stimulus_Node *) {}
 
 
   /*
@@ -112,13 +119,13 @@ public:
    *
    */
 
-  virtual void NewProgram  (Processor *new_cpu) { };
+  virtual void NewProgram(Processor *) {}
 
   /*
    * Update - Invoked when the interface should update itself
    */
 
-  virtual void Update  (gpointer object) {};
+  virtual void Update(gpointer /* object */) {}
 
   /*
    * destructor - called when the interface is destroyed - this gives
@@ -128,9 +135,9 @@ public:
   {
   }
 
-  unsigned int get_id(void) { return interface_id;};
-  void set_id(unsigned int new_id) { interface_id = new_id;};
-  explicit Interface(gpointer new_object = NULL);
+  unsigned int get_id() { return interface_id;}
+  void set_id(unsigned int new_id) { interface_id = new_id;}
+  explicit Interface(gpointer new_object = nullptr);
 };
 
 
@@ -144,7 +151,7 @@ public:
    * start_simulation -begin simulating. Simulation stops whenever
    *  a breakpoint is encountered or the specified duration has expired.
    */
-  void start_simulation (double duration=0.0);
+  void start_simulation(double duration = 0.0);
 
   /*
    * step_simulation - run the simulation for one or more simulation cycles.
@@ -161,21 +168,21 @@ public:
     eAdvanceNextReturn,      // processors - run until next return
   };
   void advance_simulation(eAdvancementModes nAdvancement);
-  void reset (RESET_TYPE resetType=SIM_RESET);
-  void simulation_has_stopped ();
+  void reset(RESET_TYPE resetType = SIM_RESET);
+  void simulation_has_stopped();
   bool bSimulating();
   bool bUsingGUI();
   void setGUImode(bool);
   // gpsim will call these functions to notify gui and/or modules
   // that something has changed.
 
-  void update_object (gpointer xref,int new_value);
-  void remove_object (gpointer xref);
-  void update ();
-  void new_processor (Processor *);
-  void new_module  (Module *module);
-  void node_configuration_changed  (Stimulus_Node *node);
-  void new_program  (Processor *);
+  void update_object(gpointer xref, int new_value);
+  void remove_object(gpointer xref);
+  void update();
+  void new_processor(Processor *);
+  void new_module(Module *module);
+  void node_configuration_changed(Stimulus_Node *node);
+  void new_program(Processor *);
   void set_update_rate(guint64 rate);
   guint64 get_update_rate();
 
@@ -223,8 +230,6 @@ inline gpsimInterface &get_interface()
 
 //------------------------------------------------------------------------
 
-class Module;
-
 class ModuleInterface
 {
  public:
@@ -261,10 +266,10 @@ public:
   {
   }
 
-  virtual const char *GetName(void) = 0;
+  virtual const char *GetName() = 0;
   // Fixme: should Execute be renamed ExecuteCommand?
   virtual int Execute(const char * commandline, ISimConsole *out) = 0;
-  virtual int ExecuteScript(list<string *> &script, ISimConsole *out) = 0;
+  virtual int ExecuteScript(std::list<std::string *> &script, ISimConsole *out) = 0;
 };
 
-#endif // __GPSIM_INTERFACE_H__
+#endif // SRC_GPSIM_INTERFACE_H_
