@@ -1,46 +1,42 @@
-
 /*
    Copyright (C) 2004 T. Scott Dattalo
 
-This file is part of gpsim.
+This file is part of the libgpsim library of gpsim
 
-gpsim is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
 
-gpsim is distributed in the hope that it will be useful,
+This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Lesser General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with gpsim; see the file COPYING.  If not, write to
-the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, see
+<http://www.gnu.org/licenses/lgpl-2.1.html>.
+*/
 
 
-#ifndef __GPSIM_OBJECT_H__
-#define __GPSIM_OBJECT_H__
+#ifndef SRC_GPSIM_OBJECT_H_
+#define SRC_GPSIM_OBJECT_H_
 
 #include <string>
-using namespace std;
 
-class BreakType;
 class Expression;
 
 /// gpsimObject - base class for most of gpsim's objects
-/// 
+///
 
 class gpsimObject {
- public:
-
+public:
   gpsimObject();
-  gpsimObject(const char *_name, const char *desc=0);
+  gpsimObject(const char *_name, const char *desc = nullptr);
   virtual ~gpsimObject();
 
   /// Get the name of the object
-  virtual string &name(void) const;
+  virtual std::string &name() const;
 
   /// copy the name to a user char array
   virtual char *name(char *, int len);
@@ -52,24 +48,22 @@ class gpsimObject {
   /// Assign a new name to the object
   /// FIXME why have two ways of naming ???
   virtual void new_name(const char *);
-  virtual void new_name(string &);
+  virtual void new_name(std::string &);
 
   /// TEMPORARY -- remove after gpsimValue and Value have been merged.
   virtual unsigned int get_value();
 
-
-  /// description - get a description of this object. If the object has 
+  /// description - get a description of this object. If the object has
   /// a name, then 'help value_name' at the command line will display
   /// the description.
 
-  virtual string description();
+  virtual std::string description();
   void set_description(const char *);
 
   /// Access object-specific information
-  string show();
-  string showType();
-  virtual string toString();
-
+  std::string show();
+  std::string showType();
+  virtual std::string toString();
 
   // Breakpoint types supported by Value
   enum ObjectBreakTypes {
@@ -96,14 +90,14 @@ class gpsimObject {
   /// If the break fails, then -1 is returned.
   /// The ActionType specifies the action to take when the break is triggered.
 
-  virtual int set_break(ObjectBreakTypes bt=eBreakAny, ObjectActionTypes at=eActionHalt, Expression *expr=0);
+  virtual int set_break(ObjectBreakTypes bt = eBreakAny,
+                        ObjectActionTypes at = eActionHalt,
+                        Expression *expr = nullptr);
   virtual int clear_break();
 
 protected:
-
-  string  name_str;               // A unique name to describe the object
+  std::string  name_str;          // A unique name to describe the object
   const char *cpDescription;      // A desciption of the object
-
 };
 
 //------------------------------------------------------------------------
@@ -112,7 +106,7 @@ protected:
 class BreakType
 {
 public:
-  BreakType(int _type) 
+  explicit BreakType(int _type)
     : m_type(_type)
   {
   }
@@ -128,4 +122,5 @@ public:
 protected:
   int m_type;
 };
-#endif //  __GPSIM_OBJECT_H__
+
+#endif //  SRC_GPSIM_OBJECT_H_
