@@ -77,26 +77,20 @@ bool gUsingThreads()
 //---------------------------------------------------------------------------
 void gpsim_set_bulk_mode(int flag)
 {
-  if(get_use_icd())
-  {
+  if (get_use_icd()) {
     icd_set_bulk(flag);
   }
 }
 
-
-void  initialization_is_complete(void)
+void initialization_is_complete()
 {
   gpsim_is_initialized = 1;
 }
 
-
 //========================================================================
 //========================================================================
 
 
-
-
-
 //---------------------------------------------------------------------------
 //---------------------------------------------------------------------------
 /*
@@ -122,14 +116,11 @@ ModuleInterface::ModuleInterface(Module *new_module)
 //---------------------------------------------------------------------------
 //---------------------------------------------------------------------------
 
-ProcessorInterface::ProcessorInterface(Processor *new_cpu) : ModuleInterface(new_cpu)
+ProcessorInterface::ProcessorInterface(Processor *new_cpu)
+  : ModuleInterface(new_cpu)
 {
-
-
 }
 
-
-
 //--------------------------------------------------------------------------
 //
 // callback registration functions
@@ -137,10 +128,8 @@ ProcessorInterface::ProcessorInterface(Processor *new_cpu) : ModuleInterface(new
 //
 //--------------------------------------------------------------------------
 Interface::Interface(gpointer new_object)
+  : interface_id(0), objectPTR(new_object)
 {
-
-  objectPTR = new_object;
-
 }
 
 
@@ -165,14 +154,13 @@ Interface::Interface(gpointer new_object)
 //--------------------------------------------------------------------------
 
 
-void gpsimInterface::update  (void)
+void gpsimInterface::update()
 {
-
   GSList *external_interfaces = interfaces;
 
-  while(external_interfaces) {
+  while (external_interfaces) {
 
-    if(external_interfaces->data) {
+    if (external_interfaces->data) {
       Interface *an_interface = (Interface *)(external_interfaces->data);
 
       an_interface->Update(an_interface->objectPTR);
@@ -182,41 +170,41 @@ void gpsimInterface::update  (void)
   }
 }
 
-void gpsimInterface::callback(void)
+void gpsimInterface::callback()
 {
-  if(update_rate) {
+  if (update_rate) {
     future_cycle = get_cycles().get() + update_rate;
     get_cycles().set_break(future_cycle, this);
   }
 
   update();
 }
-void gpsimInterface::clear(void)
-{
 
+void gpsimInterface::clear()
+{
 }
 
-void gpsimInterface::print(void)
+void gpsimInterface::print()
 {
-  cout << "Interface update rate " << update_rate << endl;
+  std::cout << "Interface update rate " << update_rate << '\n';
 }
 
-void gpsimInterface::callback_print(void)
+void gpsimInterface::callback_print()
 {
-  cout << "gpsim Interface callback\n";
+  std::cout << "gpsim Interface callback\n";
 }
 
-void update_gui(void)
+void update_gui()
 {
   gi.update();
 }
 
-gpsimInterface::gpsimInterface (void )
+gpsimInterface::gpsimInterface()
 {
-  interfaces = 0;
+  interfaces = nullptr;
   future_cycle = 0;
   interface_seq_number = 0;
-  socket_interface = 0;
+  socket_interface = nullptr;
   mbSimulating = false;
   mbUseGUI = false;
 }
@@ -239,33 +227,28 @@ ISimConsole & gpsimInterface::GetConsole()
 // if there's a xref object associated with the register gpsim will
 // then notify the gui (or module) through the xref.
 
-void gpsimInterface::update_object (gpointer xref,int new_value)
+void gpsimInterface::update_object(gpointer xref, int new_value)
 {
-
   GSList *interface_list = interfaces;
 
-  while(interface_list) {
+  while (interface_list) {
 
-    if(interface_list->data) {
+    if (interface_list->data) {
       Interface *an_interface = (Interface *)(interface_list->data);
-
       an_interface->UpdateObject(xref, new_value);
     }
 
     interface_list = interface_list->next;
   }
-
 }
 
-void gpsimInterface::remove_object (gpointer xref)
+void gpsimInterface::remove_object(gpointer xref)
 {
-
-
   GSList *interface_list = interfaces;
 
-  while(interface_list) {
+  while (interface_list) {
 
-    if(interface_list->data) {
+    if (interface_list->data) {
       Interface *an_interface = (Interface *)(interface_list->data);
 
       an_interface->RemoveObject(xref);
@@ -273,109 +256,46 @@ void gpsimInterface::remove_object (gpointer xref)
 
     interface_list = interface_list->next;
   }
-
-
 }
 
-void gpsimInterface::simulation_has_stopped (void)
+void gpsimInterface::simulation_has_stopped()
 {
-
-
   GSList *interface_list = interfaces;
 
   profile_keeper.catchup();     // FIXME: remove this!
 
-  while(interface_list) {
+  while (interface_list) {
 
-    if(interface_list->data) {
+    if (interface_list->data) {
       Interface *an_interface = (Interface *)(interface_list->data);
       an_interface->SimulationHasStopped(an_interface->objectPTR);
     }
 
     interface_list = interface_list->next;
   }
-
 }
 
-// This code is not used anywhere, but uses currently depreciated calls RRR
-#ifdef GPSIM_THREAD
-
-GMutex *muRunMutex;
-GCond  *cvRunCondition;
-
-static Processor *tcpu=0;
-
-static void run_thread( void *ptr )
-{
-  printf("run thread\n");
-  while(1) {
-
-    g_mutex_lock(muRunMutex);
-    printf("running waiting for condition\n");
-
-    g_cond_wait(cvRunCondition, muRunMutex);
-    if(tcpu) {
-      printf("running\n");
-      tcpu->run();
-      printf("stopped running\n");
-    }
-
-    g_mutex_unlock(muRunMutex);
-
-  }
-}
-
-
-void start_run_thread(void)
-{
-  std::cout << "starting run thread....\n";
-
-  muRunMutex     = g_mutex_new ();
-  cvRunCondition = g_cond_new ();
-  g_mutex_lock (muRunMutex);
-
-  GError    *err = NULL ;
-
-  if( g_thread_create((GThreadFunc)run_thread,
-		      (void *)0,
-		      TRUE,
-		      &err) == NULL)
-  {
-    printf("Thread create failed: %s!!\n", err->message );
-    g_error_free ( err ) ;
-  }
-
-  g_mutex_unlock (muRunMutex);
-
-  std::cout << " started thread\n";
-}
-#endif //GPSIM_THREAD
-
 //========================================================================
 //
-void gpsimInterface::start_simulation (double duration)
+void gpsimInterface::start_simulation(double /* duration */ )
 {
-
-
   Processor *cpu = get_active_cpu();
   if (cpu) {
     mbSimulating = true;
-    cout << "running...\n";
+    std::cout << "running...\n";
     cpu->run(true);
     mbSimulating = false;
     trace.dump_last_instruction();
     simulation_has_stopped();
   }
-
 }
 
-void gpsimInterface::step_simulation (int nSteps)
+void gpsimInterface::step_simulation(int nSteps)
 {
   Processor *cpu = get_active_cpu();
 
   if (cpu)
     cpu->step(nSteps);
-
 }
 
 void gpsimInterface::advance_simulation(eAdvancementModes nAdvancement)
@@ -395,10 +315,10 @@ void gpsimInterface::advance_simulation(eAdvancementModes nAdvancement)
   case eAdvanceNextCall:
   case eAdvanceNextReturn:
     break;
-
   }
 }
-void gpsimInterface::reset (RESET_TYPE resetType)
+
+void gpsimInterface::reset(RESET_TYPE resetType)
 {
   CSimulationContext::GetContext()->Reset(resetType);
 }
@@ -412,18 +332,20 @@ bool gpsimInterface::bUsingGUI()
 {
   return mbUseGUI;
 }
+
 void gpsimInterface::setGUImode(bool bnewGUImode)
 {
   // We can only turn the gui on we can't turn it off.
   mbUseGUI |= bnewGUImode;
 }
-void gpsimInterface::new_processor (Processor *new_cpu)
+
+void gpsimInterface::new_processor(Processor *new_cpu)
 {
   GSList *interface_list = interfaces;
 
-  while(interface_list) {
+  while (interface_list) {
 
-    if(interface_list->data) {
+    if (interface_list->data) {
       Interface *an_interface = (Interface *)(interface_list->data);
 
       an_interface->NewProcessor(new_cpu);
@@ -431,17 +353,15 @@ void gpsimInterface::new_processor (Processor *new_cpu)
 
     interface_list = interface_list->next;
   }
-
 }
 
-void gpsimInterface::new_module (Module *module)
+void gpsimInterface::new_module(Module *module)
 {
-
   GSList *interface_list = interfaces;
 
-  while(interface_list) {
+  while (interface_list) {
 
-    if(interface_list->data) {
+    if (interface_list->data) {
       Interface *an_interface = (Interface *)(interface_list->data);
 
       an_interface->NewModule(module);
@@ -449,17 +369,15 @@ void gpsimInterface::new_module (Module *module)
 
     interface_list = interface_list->next;
   }
-
 }
 
-void gpsimInterface::node_configuration_changed (Stimulus_Node *node)
+void gpsimInterface::node_configuration_changed(Stimulus_Node *node)
 {
-
   GSList *interface_list = interfaces;
 
-  while(interface_list) {
+  while (interface_list) {
 
-    if(interface_list->data) {
+    if (interface_list->data) {
       Interface *an_interface = (Interface *)(interface_list->data);
 
       an_interface->NodeConfigurationChanged(node);
@@ -467,17 +385,15 @@ void gpsimInterface::node_configuration_changed (Stimulus_Node *node)
 
     interface_list = interface_list->next;
   }
-
 }
 
-void gpsimInterface::new_program  (Processor *cpu)
+void gpsimInterface::new_program(Processor *cpu)
 {
-
   GSList *interface_list = interfaces;
 
-  while(interface_list) {
+  while (interface_list) {
 
-    if(interface_list->data) {
+    if (interface_list->data) {
       Interface *an_interface = (Interface *)(interface_list->data);
 
       an_interface->NewProgram(cpu);
@@ -485,60 +401,56 @@ void gpsimInterface::new_program  (Processor *cpu)
 
     interface_list = interface_list->next;
   }
-
 }
 
-unsigned int  gpsimInterface::add_interface  (Interface *new_interface)
+unsigned int gpsimInterface::add_interface(Interface *new_interface)
 {
-
   interface_seq_number++;
 
   new_interface->set_id(interface_seq_number);
 
   gi.interfaces = g_slist_append(gi.interfaces, new_interface);
 
-
   return interface_seq_number;
 }
-unsigned int  gpsimInterface::prepend_interface  (Interface *new_interface)
-{
 
+unsigned int gpsimInterface::prepend_interface(Interface *new_interface)
+{
   interface_seq_number++;
 
   new_interface->set_id(interface_seq_number);
 
   gi.interfaces = g_slist_prepend(gi.interfaces, new_interface);
 
-
   return interface_seq_number;
 }
 
-unsigned int  gpsimInterface::add_socket_interface  (Interface *new_interface)
+unsigned int gpsimInterface::add_socket_interface(Interface *new_interface)
 {
-  if(!socket_interface)
+  if (!socket_interface)
     return add_interface(new_interface);
 
   return 0;
 }
 
-void  gpsimInterface::remove_interface  (unsigned int interface_id)
+void gpsimInterface::remove_interface(unsigned int interface_id)
 {
   GSList *interface_list = interfaces;
 
-  while(interface_list) {
+  while (interface_list) {
 
-    if(interface_list->data) {
+    if (interface_list->data) {
       Interface *an_interface = (Interface *)(interface_list->data);
 
-      if(an_interface->get_id()==interface_id)
-      {
+      if (an_interface->get_id() == interface_id) {
 
-	gi.interfaces = g_slist_remove(gi.interfaces, an_interface);
-	if(an_interface == socket_interface)
-	  socket_interface = 0;
+        gi.interfaces = g_slist_remove(gi.interfaces, an_interface);
+        if (an_interface == socket_interface)
+          socket_interface = nullptr;
 
-	delete an_interface;
-	return;
+        delete an_interface;
+        an_interface = nullptr;
+        return;
       }
     }
 
@@ -547,16 +459,15 @@ void  gpsimInterface::remove_interface  (unsigned int interface_id)
   return;
 }
 
-void  gpsimInterface::set_update_rate  (guint64 _update_rate)
+void gpsimInterface::set_update_rate(guint64 _update_rate)
 {
   update_rate = _update_rate;
 
-  if(update_rate)
-  {
+  if (update_rate) {
     guint64 fc = get_cycles().get() + _update_rate;
 
-    if(fc) {
-      if(future_cycle)
+    if (fc) {
+      if (future_cycle)
         get_cycles().reassign_break(future_cycle, fc, this);
       else
         get_cycles().set_break(fc, this);
@@ -566,14 +477,11 @@ void  gpsimInterface::set_update_rate  (guint64 _update_rate)
   }
 }
 
-
 guint64 gpsimInterface::get_update_rate()
 {
   return update_rate;
 }
 
-
-
 const char *get_dir_delim(const char *path)
 {
 #ifdef _WIN32
