@@ -21,21 +21,18 @@ License along with this library; if not, see
 
 #include "modules.h"
 
-#include <stdio.h>
 #include <ctype.h>
-#include <errno.h>
 #include <stdlib.h>
 #include <string>
 #include <list>
-#include <vector>
-#include <typeinfo>
+#include <iostream>
 
 #include "../config.h"
 
 #ifndef _WIN32
 #include <dlfcn.h>
 #if !defined(_MAX_PATH)
-  #define _MAX_PATH 1024
+#define _MAX_PATH 1024
 #endif
 #include <unistd.h>  // for getcwd
 
@@ -50,11 +47,11 @@ License along with this library; if not, see
 #undef interface
 #endif
 
-#include "pic-processor.h"
+#include "error.h"
+#include "gpsim_interface.h"
 #include "stimuli.h"
 #include "symbol.h"
 #include "xref.h"
-#include "value.h"
 #include "packages.h"
 #include "cmd_manager.h"
 
@@ -63,9 +60,11 @@ License along with this library; if not, see
 // it supports are placed into the ModuleTypes map. This
 // object is private to this file.
 
-typedef map<string, Module_Types *> ModuleTypeInfo_t;
+typedef std::map<std::string, Module_Types *> ModuleTypeInfo_t;
 ModuleTypeInfo_t ModuleTypes;
 
+ModuleLibraries_t ModuleLibraries;
+
 
 //------------------------------------------------------------------------
 // Add a new type to the ModuleTypes map if the name for that type
@@ -73,64 +72,68 @@ ModuleTypeInfo_t ModuleTypes;
 
 static void AddModuleType(const char *pName, Module_Types *pType)
 {
-  string sName(pName);
+  std::string sName = pName;
   ModuleTypeInfo_t::iterator mti = ModuleTypes.find(sName);
-  if (mti == ModuleTypes.end())
+
+  if (mti == ModuleTypes.end()) {
     ModuleTypes[sName] = pType;
+  }
 }
 
-DynamicModuleLibraryInfo::DynamicModuleLibraryInfo(string &sCanonicalName,
-                           string &sUserSuppliedName,
-                           void   *pHandle)
-    : m_sCanonicalName(sCanonicalName),
-      m_sUserSuppliedName(sUserSuppliedName),
-      m_pHandle(pHandle),
-      get_mod_list(0)
+
+DynamicModuleLibraryInfo::DynamicModuleLibraryInfo(std::string &sCanonicalName,
+    std::string &sUserSuppliedName,
+    void   *pHandle)
+  : m_sCanonicalName(sCanonicalName),
+    m_sUserSuppliedName(sUserSuppliedName),
+    m_pHandle(pHandle)
 {
-    const char * error;
-    if (m_pHandle)
-      get_mod_list = (Module_Types_FPTR)get_library_export("get_mod_list", m_pHandle, &error);
+  const char * error;
 
-    if (!get_mod_list) {
-      cout << "WARNING: non-conforming module library\n"
-           << "  gpsim libraries should have the get_mod_list() function defined\n";
-      fprintf(stderr, "%s\n",error);
-      free_error_message(error);
-    } else {
+  if (m_pHandle) {
+    get_mod_list = (Module_Types_FPTR)get_library_export("get_mod_list", m_pHandle, &error);
+  }
 
-      // Get a pointer to the list of modules that this library file supports.
-      Module_Types *pLibModList = get_mod_list();
+  if (!get_mod_list) {
+    std::cout << "WARNING: non-conforming module library\n"
+         "  gpsim libraries should have the get_mod_list() function defined\n";
+    std::cerr << error << '\n';
+    free_error_message(error);
 
-      // Loop through the list of modules supported by the library and an entry
-      // ModuleTypes map for each one.
+  } else {
+    // Get a pointer to the list of modules that this library file supports.
+    Module_Types *pLibModList = get_mod_list();
 
-      if(pLibModList)
-        for(Module_Types *pModTypes = pLibModList;  pModTypes->names[0]; pModTypes++) {
-          AddModuleType(pModTypes->names[0], pModTypes);
-          AddModuleType(pModTypes->names[1], pModTypes);
-        }
+    // Loop through the list of modules supported by the library and an entry
+    // ModuleTypes map for each one.
 
-      // If the module has an "initialize" function, then call it now.
-      typedef  void * (*void_FPTR)(void);
-      void * (*initialize)(void) = (void_FPTR)get_library_export("initialize", m_pHandle, NULL);
-      if(initialize)
-        initialize();
+    if (pLibModList)
+      for (Module_Types *pModTypes = pLibModList;  pModTypes->names[0]; pModTypes++) {
+        AddModuleType(pModTypes->names[0], pModTypes);
+        AddModuleType(pModTypes->names[1], pModTypes);
+      }
 
-      /*
-      ICommandHandler * pCliHandler = ml->GetCli();
-      if (pCliHandler != NULL)
-        CCommandManager::GetManager().Register(pCliHandler);
-      */
+    // If the module has an "initialize" function, then call it now.
+    typedef  void * (*void_FPTR)(void);
+    void * (*initialize)(void) = (void_FPTR)get_library_export("initialize", m_pHandle, nullptr);
+
+    if (initialize) {
+      initialize();
     }
 
+    /*
+    ICommandHandler * pCliHandler = ml->GetCli();
+    if (pCliHandler != NULL)
+      CCommandManager::GetManager().Register(pCliHandler);
+    */
+  }
 }
 
-ModuleLibraries_t ModuleLibraries;
-
 
 //========================================================================
 
-void MakeCanonicalName(string &sPath, string &sName) {
+void MakeCanonicalName(std::string &sPath, std::string &sName)
+{
 #ifdef _WIN32
   sName = sPath;
 #else
@@ -138,81 +141,72 @@ void MakeCanonicalName(string &sPath, string &sName) {
 #endif
 }
 
-int ModuleLibrary::LoadFile(string &fName)
+
+int ModuleLibrary::LoadFile(std::string &fName)
 {
-  void *handle;
   const char *pszError;
   bool bReturn = false;
-
-  string sPath= fName;
+  std::string sPath = fName;
   FixupLibraryName(sPath);
-  string sName;
+  std::string sName;
   MakeCanonicalName(sPath, sName);
   ModuleLibraries_t::iterator mli = ModuleLibraries.find(sName);
 
   if (mli == ModuleLibraries.end()) {
-    if ((handle = ::load_library(sPath.c_str(), &pszError)) == NULL) {
-#ifdef THROW
-      ostringstream stream;
-
-      stream << "failed to open library module ";
-      stream << sPath;
-      stream << ": ";
-      stream << pszError;
-      stream << endl;
-
+    void *handle = ::load_library(sPath.c_str(), &pszError);
+    if (handle == nullptr) {
+//#ifdef THROW
       char cw[_MAX_PATH];
       getcwd(cw, sizeof(cw));
-      stream << "current working directory is ";
-      stream << cw;
-      stream << endl << ends;
-      free_error_message(pszError);
-      throw new Error(stream.str());
-#endif //THROW
-    }
-    else {
 
+      std::string error_string = "failed to open library module " + sPath;
+      error_string += cw;
+      error_string += '\n';
+
+      free_error_message(pszError);
+      throw Error(error_string);
+//#endif //THROW
+
+    } else {
       ModuleLibraries[sName] = new DynamicModuleLibraryInfo(fName, sName, handle);
       bReturn = true;
     }
   }
+
   /*
   if(verbose)
     DisplayFileList();
   */
   return bReturn;
-
 }
-int ModuleLibrary::InstantiateObject(string &sObjectName, string &sInstantiatedName)
+
+
+int ModuleLibrary::InstantiateObject(std::string &sObjectName, std::string &sInstantiatedName)
 {
-
   ModuleTypeInfo_t::iterator mti = ModuleTypes.find(sObjectName);
-  if (mti != ModuleTypes.end()) {
 
+  if (mti != ModuleTypes.end()) {
     Module *pModule = mti->second->module_constructor(sInstantiatedName.c_str());
     pModule->set_module_type(sObjectName);
     globalSymbolTable().addModule(pModule);
-
     // Tell the gui or any modules that are interfaced to gpsim
     // that a new module has been added.
     gi.new_module(pModule);
-    return pModule!=0;
+    return pModule != 0;
   }
-  return 0;
 
+  return 0;
 }
 
+
 void ModuleLibrary::ListLoadableModules()
 {
-  ModuleTypeInfo_t::iterator mti = ModuleTypes.begin();
-  while (mti != ModuleTypes.end()) {
-
-    cout << " " << mti->first << endl;
-    ++mti;
+  for (auto &mt : ModuleTypes) {
+    std::cout << ' ' << mt.first << '\n';
   }
-
 }
 
+
 /*****************************************************************************
  *
  * Module.cc
@@ -226,31 +220,31 @@ void ModuleLibrary::ListLoadableModules()
  */
 
 Module::Module(const char *_name, const char *desc)
-  : gpsimObject(_name, desc), package(0), interface(0),
-  simulation_mode(eSM_STOPPED), widget(0), Vdd(5.0), version(0)
+  : gpsimObject(_name, desc), simulation_mode(eSM_STOPPED)
 {
   xref = new XrefObject;
 
   if (_name) {
     // If there is a module symbol already with this
     // name, then print a warning before deleting.
-
     gpsimObject *pOldModule = globalSymbolTable().find(name());
+
     if (pOldModule) {
-      cout << "Warning: There already is a symbol in the symbol table named " << _name << endl;
+      std::cout << "Warning: There already is a symbol in the symbol table named " << _name << '\n';
       return;
     }
   }
+
   globalSymbolTable().addModule(this);
 
   // Create position attribute place holders if we're not using the gui
-  if(!get_interface().bUsingGUI()) {
-    addSymbol(new Float("xpos",80.0));
-    addSymbol(new Float("ypos",80.0));
+  if (!get_interface().bUsingGUI()) {
+    addSymbol(new Float("xpos", 80.0));
+    addSymbol(new Float("ypos", 80.0));
   }
-
 }
 
+
 #if 0 // warning: 'void dumpOneSymbol(const SymbolEntry_t&)' defined but not used
 static void dumpOneSymbol(const SymbolEntry_t &sym)
 {
@@ -261,46 +255,40 @@ static void dumpOneSymbol(const SymbolEntry_t &sym)
 #endif
 
 
-Module::~Module(void)
+Module::~Module()
 {
-  map<string ,ModuleScript *>::iterator si;
-
-  for (si = m_scripts.begin();
-       si != m_scripts.end();
-       ++si) {
-    ModuleScript *pMS = (*si).second;
+  for (auto &si : m_scripts) {
+    ModuleScript *pMS = si.second;
     delete pMS;
   }
-  m_scripts.clear();
 
   deleteSymbol("xpos");
   deleteSymbol("ypos");
-
   /*
   cout << "Stuff still in the symbol table:\n";
   mSymbolTable.ForEachSymbolTable(dumpOneSymbol);
   */
   delete package;
   delete xref;
-  package = 0;
-  xref = 0;
 
   globalSymbolTable().removeModule(this);
-
 }
 
-void Module::reset(RESET_TYPE r)
+
+void Module::reset(RESET_TYPE )
 {
-  cout << " resetting module " << name() << endl;
+  std::cout << " resetting module " << name() << '\n';
 }
 
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
-int Module::addSymbol(gpsimObject *pSym, string *ps_AliasedName)
+int Module::addSymbol(gpsimObject *pSym, std::string *ps_AliasedName)
 {
   return mSymbolTable.addSymbol(pSym, ps_AliasedName);
 }
 
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
 int Module::removeSymbol(gpsimObject *pSym)
@@ -308,100 +296,118 @@ int Module::removeSymbol(gpsimObject *pSym)
   return mSymbolTable.removeSymbol(pSym);
 }
 
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
-int Module::removeSymbol(const string &s)
+int Module::removeSymbol(const std::string &s)
 {
   return mSymbolTable.removeSymbol(s);
 }
 
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
-int Module::deleteSymbol(const string &s)
+int Module::deleteSymbol(const std::string &s)
 {
   return mSymbolTable.deleteSymbol(s);
 }
 
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
 int Module::deleteSymbol(gpsimObject *pSym)
 {
-  if (!pSym)
+  if (!pSym) {
     return 0;
+  }
 
-  if (!removeSymbol(pSym))
+  if (!removeSymbol(pSym)) {
     return 0;
+  }
 
   delete pSym;
   return 1;
 }
 
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
-gpsimObject *Module::findSymbol(const string &searchString)
+gpsimObject *Module::findSymbol(const std::string &searchString)
 {
   return mSymbolTable.findSymbol(searchString);
 }
 
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
 void Module::create_pkg(unsigned int number_of_pins)
 {
-  if(package)
-    delete package;
+  delete package;
 
   package = new Package(number_of_pins);
-
 }
 
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
 void Module::assign_pin(unsigned int pin_number, IOPIN *pin)
 {
-  if(package)
+  if (package) {
     package->assign_pin(pin_number, pin);
-
+  }
 }
 
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
-int Module::get_pin_count(void)
+int Module::get_pin_count()
 {
-  if(package)
+  if (package) {
     return package->get_pin_count();
+  }
 
   return 0;
-
 }
+
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
-string &Module::get_pin_name(unsigned int pin_number)
+std::string &Module::get_pin_name(unsigned int pin_number)
 {
-  static string invalid("");
-  if(package)
-    return package->get_pin_name(pin_number);
-  return invalid;  //FIXME
+  static std::string invalid;
 
+  if (package) {
+    return package->get_pin_name(pin_number);
+  }
+
+  return invalid;  //FIXME
 }
+
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
 int Module::get_pin_state(unsigned int pin_number)
 {
-  if(package)
+  if (package) {
     return package->get_pin_state(pin_number);
+  }
 
   return 0;
 }
+
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
 IOPIN *Module::get_pin(unsigned int pin_number)
 {
-  if(package)
+  if (package) {
     return package->get_pin(pin_number);
+  }
 
-  return 0;
+  return nullptr;
 }
 
+
 //-------------------------------------------------------------------
 // Module Scripts
 //
@@ -417,9 +423,10 @@ IOPIN *Module::get_pin(unsigned int pin_number)
 //
 // Add a command line command to a Module Script.
 //-------------------------------------------------------------------
-void Module::add_command(string &script_name, string &command)
+void Module::add_command(std::string &script_name, std::string &command)
 {
   ModuleScript *script = m_scripts[script_name];
+
   if (!script) {
     script = new ModuleScript(script_name);
     m_scripts[script_name] = script;
@@ -428,68 +435,73 @@ void Module::add_command(string &script_name, string &command)
   script->add_command(command);
 }
 
+
 //-------------------------------------------------------------------
 // Module::run_script - execute a gpsim command line script
 //
 //-------------------------------------------------------------------
-void Module::run_script(string &script_name)
+void Module::run_script(std::string &script_name)
 {
   ModuleScript *script = m_scripts[script_name];
+
   if (script) {
     ICommandHandler *pCli = CCommandManager::GetManager().find("gpsimCLI");
-    if(pCli) {
+
+    if (pCli) {
       script->run(pCli);
     }
   }
 }
+
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
-Module::ModuleScript::ModuleScript(string &name_)
+Module::ModuleScript::ModuleScript(const std::string &name_)
   : name(name_)
 {
 }
+
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
 Module::ModuleScript::~ModuleScript()
 {
-  list <string *> :: iterator command_iterator;
-
-  for (command_iterator = m_commands.begin();
-       command_iterator != m_commands.end();
-       ++command_iterator)
-    delete *command_iterator;
-
-  m_commands.clear();
+  for (auto & command : m_commands) {
+    delete command;
+  }
 }
+
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
-void Module::ModuleScript::add_command(string &command)
+void Module::ModuleScript::add_command(const std::string &command)
 {
-  string *new_command = new string(command);
+  std::string *new_command = new std::string(command);
   m_commands.push_back(new_command);
 }
 
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
 void Module::ModuleScript::run(ICommandHandler *pCommandHandler)
 {
-  if (!pCommandHandler)
+  if (!pCommandHandler) {
     return;
+  }
 
-  pCommandHandler->ExecuteScript(m_commands,0);
+  pCommandHandler->ExecuteScript(m_commands, nullptr);
 }
 
+
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
 void Module::ModuleScript::concatenate(ModuleScript *pOtherScript)
 {
-  if (!pOtherScript)
+  if (!pOtherScript) {
     return;
+  }
 
-  list <string *> :: iterator command_iterator;
-
-  for (command_iterator = pOtherScript->m_commands.begin();
-       command_iterator != pOtherScript->m_commands.end();
-       ++command_iterator)
-    m_commands.push_back(*command_iterator);
+  for (auto &command : pOtherScript->m_commands) {
+    m_commands.push_back(command);
+  }
 }
