@@ -1,39 +1,50 @@
-#include <iostream>
+
 #include <cstdio>
 
 #include "operator.h"
 #include "errors.h"
 #include "symbol.h"
 #include "processor.h"
+#include "registers.h"
+#include "value.h"
 
 #include <typeinfo>
 
 static bool isFloat(Value *v)
 {
-  if(v &&  (typeid(*v) == typeid(Float)))
-    return true;
-  return false;
-}
-static bool isInteger(Value *v)
-{
-  if(v &&  (typeid(*v) == typeid(Integer)))
-    return true;
-  return false;
-}
-static bool isBoolean(Value *v)
-{
-  if(v &&  (typeid(*v) == typeid(Boolean)))
+  if (v && (typeid(*v) == typeid(Float))) {
     return true;
+  }
+
   return false;
 }
 
+
+static bool isInteger(Value *v)
+{
+  if (v && (typeid(*v) == typeid(Integer))) {
+    return true;
+  }
+
+  return false;
+}
+
+
+static bool isBoolean(Value *v)
+{
+  if (v && (typeid(*v) == typeid(Boolean))) {
+    return true;
+  }
+
+  return false;
+}
+
+
 BinaryOperator::BinaryOperator(const std::string  & opString,
-			       Expression* _leftExpr,
-			       Expression* _rightExpr) : Operator(opString)
+                               Expression* _leftExpr,
+                               Expression* _rightExpr)
+  : Operator(opString), leftExpr(_leftExpr), rightExpr(_rightExpr)
 {
-  leftExpr = _leftExpr;
-  rightExpr = _rightExpr;
-  value = 0;
 }
 
 
@@ -45,43 +56,56 @@ BinaryOperator::~BinaryOperator()
 }
 
 
-Value* BinaryOperator::shortCircuit(Value* leftValue)
+Value* BinaryOperator::shortCircuit(Value* /* leftValue */ )
 {
-  return 0;
+  return nullptr;
 }
 
-string BinaryOperator::show()
+
+std::string BinaryOperator::show()
 {
   return toString();
 }
 
-string BinaryOperator::showType()
+
+std::string BinaryOperator::showType()
 {
   return showOp();
 }
 
 
-string BinaryOperator::toString()
+std::string BinaryOperator::toString()
 {
-  return string("(" + leftExpr->toString() + showOp() + rightExpr->toString() + ")");
+  return std::string("(" + leftExpr->toString() + showOp() + rightExpr->toString() + ")");
 }
 
+
 Value *BinaryOperator::evaluate()
 {
-
   Value *left = leftExpr->evaluate();
   Value *right = rightExpr->evaluate();
   Value *out = applyOp(left, right);
 
-  if (left) delete left;
-  if (right) delete right;
+  if (left) {
+    delete left;
+  }
+
+  if (right) {
+    delete right;
+  }
+
   return out;
 }
-Expression *BinaryOperator::getLeft() {
+
+
+Expression *BinaryOperator::getLeft()
+{
   return leftExpr;
 }
 
-Expression *BinaryOperator::getRight() {
+
+Expression *BinaryOperator::getRight()
+{
   return rightExpr;
 }
 
@@ -90,46 +114,42 @@ Expression *BinaryOperator::getRight() {
  * The basic unary operator class.
  */
 UnaryOperator::UnaryOperator(const std::string & theOpString, Expression* expr_)
-  : Operator(theOpString)
+  : Operator(theOpString), expr(expr_)
 {
-  expr = expr_;
-  value = 0;
 }
 
+
 UnaryOperator::~UnaryOperator()
 {
   delete expr;
 }
 
 
-string UnaryOperator::showType()
+std::string UnaryOperator::showType()
 {
   return showOp();
 }
 
 
-string UnaryOperator::show()
+std::string UnaryOperator::show()
 {
   return toString();
 }
 
 
-string UnaryOperator::toString()
+std::string UnaryOperator::toString()
 {
-  return string(showOp() + "(" + expr->toString() + ")");
+  return std::string(showOp() + "(" + expr->toString() + ")");
 }
 
 
-
 Value* UnaryOperator::evaluate()
 {
-  Value* tmp, *vReturn;
-
   // start evaluating our operand expression:
-  tmp = expr->evaluate();
+  Value *tmp = expr->evaluate();
 
   // Apply the specific operator to the evaluated operand:
-  vReturn = applyOp(tmp);
+  Value *vReturn = applyOp(tmp);
 
   // If the result is constant, save the result for future use:
   //if (tmp->isConstant()) {
@@ -139,31 +159,35 @@ Value* UnaryOperator::evaluate()
   return vReturn;
 }
 
+
 /*****************************************************************
  * Comparison operators
  */
 ComparisonOperator::ComparisonOperator(const std::string &opString,
-				       Expression* leftExpr,
-				       Expression* rightExpr)
-  : BinaryOperator(opString,leftExpr,rightExpr),
-    bLess(false), bEqual(false), bGreater(false)
+                                       Expression* leftExpr,
+                                       Expression* rightExpr)
+  : BinaryOperator(opString, leftExpr, rightExpr)
 {
 }
 
+
 ComparisonOperator:: ~ComparisonOperator()
 {
 }
 
+
 Value* ComparisonOperator::applyOp(Value* leftValue, Value* rightValue)
 {
-  return new Boolean(leftValue->compare(this,rightValue));
+  return new Boolean(leftValue->compare(this, rightValue));
 }
-int ComparisonOperator::set_break(ObjectBreakTypes bt, ObjectActionTypes at, Expression *pExpr)
-{
-  return get_bp().set_break(bt, at, (Register *)0, this);
 
+
+int ComparisonOperator::set_break(ObjectBreakTypes bt, ObjectActionTypes at, Expression * /* pExpr */ )
+{
+  return get_bp().set_break(bt, at, (Register *)nullptr, this);
 }
 
+
 /******************************************************************************
  Operator: AbstractRange
 
@@ -181,192 +205,200 @@ OpAbstractRange::~OpAbstractRange()
 
 Value* OpAbstractRange::applyOp(Value* lVal, Value* rVal)
 {
-  Value* result=0;
-
+  Value* result = nullptr;
   Integer* lInteger = Integer::typeCheck(lVal, showOp());
   Integer* rInteger = Integer::typeCheck(rVal, showOp());
-
   int left = (int)lInteger->getVal();
   int right = (int)rInteger->getVal();
-
   result = new AbstractRange(left, right);
-  return(result);
+  return result;
 }
 
+
 //------------------------------------------------------------------------
 
 
 OpAdd::OpAdd(Expression* leftExpr, Expression* rightExpr)
-  : BinaryOperator("+",leftExpr,rightExpr)
+  : BinaryOperator("+", leftExpr, rightExpr)
 {
 }
 
+
 OpAdd::~OpAdd()
 {
 }
 
+
 Value *OpAdd::applyOp(Value *lval, Value *rval)
 {
-  if(isFloat(lval) || isFloat(rval)) {
-    double d1,d2;
-
+  if (isFloat(lval) || isFloat(rval)) {
+    double d1, d2;
     lval->get(d1);
     rval->get(d2);
-
-    return new Float(d1+d2);
+    return new Float(d1 + d2);
   }
 
   // Try to add as integers. (An exception is thrown if the values
   // cannot be type casted.
-
-  gint64 i1,i2;
-
+  gint64 i1, i2;
   lval->get(i1);
   rval->get(i2);
-
-  return new Integer(i1+i2);
-
-  //throw new TypeMismatch(showOp(), lval->showType(), rval->showType());
+  return new Integer(i1 + i2);
+  //throw TypeMismatch(showOp(), lval->showType(), rval->showType());
 }
 
+
 //------------------------------------------------------------------------
 
 
 OpAnd::OpAnd(Expression* leftExpr, Expression* rightExpr)
-  : BinaryOperator("&",leftExpr,rightExpr)
+  : BinaryOperator("&", leftExpr, rightExpr)
 {
 }
 
+
 OpAnd::~OpAnd()
 {
 }
 
+
 Value *OpAnd::applyOp(Value *lval, Value *rval)
 {
+  if (isFloat(lval) || isFloat(rval)) {
+    throw TypeMismatch(showOp(), lval->showType(), rval->showType());
+  }
 
-  if(isFloat(lval) || isFloat(rval))
-    throw new TypeMismatch(showOp(), lval->showType(), rval->showType());
-
-  gint64 i1,i2;
-
+  gint64 i1, i2;
   lval->get(i1);
   rval->get(i2);
-
   return new Integer(i1 & i2);
-
 }
 
+
 //------------------------------------------------------------------------
 OpEq::OpEq(Expression* leftExpr, Expression* rightExpr)
-  : ComparisonOperator("==",leftExpr,rightExpr)
+  : ComparisonOperator("==", leftExpr, rightExpr)
 {
   bEqual = true;
 }
 
+
 OpEq::~OpEq()
 {
 }
 
+
 //------------------------------------------------------------------------
 OpGe::OpGe(Expression* leftExpr, Expression* rightExpr)
-  : ComparisonOperator(">=",leftExpr,rightExpr)
+  : ComparisonOperator(">=", leftExpr, rightExpr)
 {
   bEqual = true;
   bGreater = true;
 }
 
+
 OpGe::~OpGe()
 {
 }
 
+
 //------------------------------------------------------------------------
 OpGt::OpGt(Expression* leftExpr, Expression* rightExpr)
-  : ComparisonOperator(">",leftExpr,rightExpr)
+  : ComparisonOperator(">", leftExpr, rightExpr)
 {
   bGreater = true;
 }
 
+
 OpGt::~OpGt()
 {
 }
 
+
 //------------------------------------------------------------------------
 OpLe::OpLe(Expression* leftExpr, Expression* rightExpr)
-  : ComparisonOperator("<=",leftExpr,rightExpr)
+  : ComparisonOperator("<=", leftExpr, rightExpr)
 {
   bLess = true;
   bEqual = true;
 }
 
+
 OpLe::~OpLe()
 {
 }
+
+
 //------------------------------------------------------------------------
 OpLt::OpLt(Expression* leftExpr, Expression* rightExpr)
-  : ComparisonOperator("<",leftExpr,rightExpr)
+  : ComparisonOperator("<", leftExpr, rightExpr)
 {
   bLess = true;
 }
 
+
 OpLt::~OpLt()
 {
 }
 
+
 //------------------------------------------------------------------------
 OpLogicalAnd::OpLogicalAnd(Expression* leftExpr, Expression* rightExpr)
-  : BinaryOperator("&&",leftExpr,rightExpr)
+  : BinaryOperator("&&", leftExpr, rightExpr)
 {
 }
 
+
 OpLogicalAnd::~OpLogicalAnd()
 {
 }
 
+
 Value *OpLogicalAnd::applyOp(Value* lval, Value* rval)
 {
-  if(isBoolean(lval) && isBoolean(rval)) {
+  if (isBoolean(lval) && isBoolean(rval)) {
     bool b1 = (static_cast<Boolean *>(lval))->getVal();
     bool b2 = (static_cast<Boolean *>(rval))->getVal();
-
     return new Boolean(b1 & b2);
   }
 
-  throw new TypeMismatch(showOp(), lval->showType(), rval->showType());
-
+  throw TypeMismatch(showOp(), lval->showType(), rval->showType());
 }
 
+
 //------------------------------------------------------------------------
 OpLogicalOr::OpLogicalOr(Expression* leftExpr, Expression* rightExpr)
-  : BinaryOperator("||",leftExpr,rightExpr)
+  : BinaryOperator("||", leftExpr, rightExpr)
 {
 }
 
+
 OpLogicalOr::~OpLogicalOr()
 {
 }
 
+
 Value *OpLogicalOr::applyOp(Value* lval, Value* rval)
 {
-  if(isBoolean(lval) && isBoolean(rval)) {
+  if (isBoolean(lval) && isBoolean(rval)) {
     bool b1 = (static_cast<Boolean *>(lval))->getVal();
     bool b2 = (static_cast<Boolean *>(rval))->getVal();
-
     return new Boolean(b1 | b2);
   }
 
-  throw new TypeMismatch(showOp(), lval->showType(), rval->showType());
-
+  throw TypeMismatch(showOp(), lval->showType(), rval->showType());
 }
 
 
 //------------------------------------------------------------------------
 OpNe::OpNe(Expression* leftExpr, Expression* rightExpr)
-  : ComparisonOperator("!=",leftExpr,rightExpr)
+  : ComparisonOperator("!=", leftExpr, rightExpr)
 {
   bLess = true;
   bGreater = true;
 }
 
+
 OpNe::~OpNe()
 {
 }
@@ -376,219 +408,220 @@ OpNe::~OpNe()
 
 
 OpSub::OpSub(Expression* leftExpr, Expression* rightExpr)
-  : BinaryOperator("-",leftExpr,rightExpr)
+  : BinaryOperator("-", leftExpr, rightExpr)
 {
 }
 
+
 OpSub::~OpSub()
 {
 }
 
+
 Value *OpSub::applyOp(Value *lval, Value *rval)
 {
-  if(isFloat(lval) || isFloat(rval)) {
-    double d1,d2;
-
+  if (isFloat(lval) || isFloat(rval)) {
+    double d1, d2;
     lval->get(d1);
     rval->get(d2);
-
-    return new Float(d1-d2);
+    return new Float(d1 - d2);
   }
 
-  gint64 i1,i2;
-
+  gint64 i1, i2;
   lval->get(i1);
   rval->get(i2);
-
-  return new Integer(i1-i2);
-
-  //  throw new TypeMismatch(showOp(), lval->showType(), rval->showType());
-
+  return new Integer(i1 - i2);
 }
 
+
 //------------------------------------------------------------------------
 
 
 OpMpy::OpMpy(Expression* leftExpr, Expression* rightExpr)
-  : BinaryOperator("*",leftExpr,rightExpr)
+  : BinaryOperator("*", leftExpr, rightExpr)
 {
 }
 
+
 OpMpy::~OpMpy()
 {
 }
 
+
 Value *OpMpy::applyOp(Value *lval, Value *rval)
 {
-  if(isFloat(lval) || isFloat(rval)) {
-    double d1,d2;
-
+  if (isFloat(lval) || isFloat(rval)) {
+    double d1, d2;
     lval->get(d1);
     rval->get(d2);
-
-    return new Float(d1*d2);
+    return new Float(d1 * d2);
   }
 
-  gint64 i1,i2;
-
+  gint64 i1, i2;
   lval->get(i1);
   rval->get(i2);
-
-  return new Integer(i1*i2);
-
-  throw new TypeMismatch(showOp(), lval->showType(), rval->showType());
+  return new Integer(i1 * i2);
 }
 
+
 //------------------------------------------------------------------------
 
 
 OpOr::OpOr(Expression* leftExpr, Expression* rightExpr)
-  : BinaryOperator("|",leftExpr,rightExpr)
+  : BinaryOperator("|", leftExpr, rightExpr)
 {
 }
 
+
 OpOr::~OpOr()
 {
 }
 
+
 Value *OpOr::applyOp(Value *lval, Value *rval)
 {
-  if(isFloat(lval) || isFloat(rval))
-    throw new TypeMismatch(showOp(), lval->showType(), rval->showType());
-
-  gint64 i1,i2;
+  if (isFloat(lval) || isFloat(rval)) {
+    throw TypeMismatch(showOp(), lval->showType(), rval->showType());
+  }
 
+  gint64 i1, i2;
   lval->get(i1);
   rval->get(i2);
-
   return new Integer(i1 | i2);
 }
 
+
 //------------------------------------------------------------------------
 
 
 OpXor::OpXor(Expression* leftExpr, Expression* rightExpr)
-  : BinaryOperator("^",leftExpr,rightExpr)
+  : BinaryOperator("^", leftExpr, rightExpr)
 {
 }
 
+
 OpXor::~OpXor()
 {
 }
 
+
 Value *OpXor::applyOp(Value *lval, Value *rval)
 {
+  if (isFloat(lval) || isFloat(rval)) {
+    throw TypeMismatch(showOp(), lval->showType(), rval->showType());
+  }
 
-  if(isFloat(lval) || isFloat(rval))
-    throw new TypeMismatch(showOp(), lval->showType(), rval->showType());
-
-  gint64 i1,i2;
-
+  gint64 i1, i2;
   lval->get(i1);
   rval->get(i2);
-
   return new Integer(i1 ^ i2);
 }
 
+
 //------------------------------------------------------------------------
 
 
 OpDiv::OpDiv(Expression* leftExpr, Expression* rightExpr)
-  : BinaryOperator("/",leftExpr,rightExpr)
+  : BinaryOperator("/", leftExpr, rightExpr)
 {
 }
 
+
 OpDiv::~OpDiv()
 {
 }
 
+
 Value *OpDiv::applyOp(Value *lval, Value *rval)
 {
-
-  if(isFloat(lval) || isFloat(rval)) {
-    double d1,d2;
-
+  if (isFloat(lval) || isFloat(rval)) {
+    double d1, d2;
     lval->get(d1);
     rval->get(d2);
 
-    if(d2 == 0.0)
-      throw new Error("Divide by zero");
+    // FIXME: Not a good way to check for a floating point zero
+    if (d2 == 0.0) {
+      throw Error("Divide by zero");
+    }
 
-    return new Float(d1/d2);
+    return new Float(d1 / d2);
   }
 
-  gint64 i1,i2;
-
+  gint64 i1, i2;
   lval->get(i1);
   rval->get(i2);
 
-  if(i2 == 0)
-    throw new Error("Divide by zero");
-
-  return new Integer(i1/i2);
+  if (i2 == 0) {
+    throw Error("Divide by zero");
+  }
 
+  return new Integer(i1 / i2);
 }
 
+
 //------------------------------------------------------------------------
 
 
 OpShl::OpShl(Expression* leftExpr, Expression* rightExpr)
-  : BinaryOperator("<<",leftExpr,rightExpr)
+  : BinaryOperator("<<", leftExpr, rightExpr)
 {
 }
 
+
 OpShl::~OpShl()
 {
 }
 
+
 Value *OpShl::applyOp(Value *lval, Value *rval)
 {
-
-  if(isFloat(lval) || isFloat(rval))
-    throw new TypeMismatch(showOp(), lval->showType(), rval->showType());
+  if (isFloat(lval) || isFloat(rval)) {
+    throw TypeMismatch(showOp(), lval->showType(), rval->showType());
+  }
 
   gint64 i1;
   gint64 i2;
-
   rval->get(i2);
 
-  if(i2 < 0  || i2 > 63)
-    throw new Error("Operator " + showOp() + " bad shift count");
+  if (i2 < 0  || i2 > 63) {
+    throw Error("Operator " + showOp() + " bad shift count");
+  }
 
   lval->get(i1);
-
-  return new Integer(i1<<i2);
+  return new Integer(i1 << i2);
 }
 
+
 //------------------------------------------------------------------------
 
 
 OpShr::OpShr(Expression* leftExpr, Expression* rightExpr)
-  : BinaryOperator(">>",leftExpr,rightExpr)
+  : BinaryOperator(">>", leftExpr, rightExpr)
 {
 }
 
+
 OpShr::~OpShr()
 {
 }
 
+
 Value *OpShr::applyOp(Value *lval, Value *rval)
 {
-
-  if(isFloat(lval) || isFloat(rval))
-    throw new TypeMismatch(showOp(), lval->showType(), rval->showType());
+  if (isFloat(lval) || isFloat(rval)) {
+    throw TypeMismatch(showOp(), lval->showType(), rval->showType());
+  }
 
   gint64 i1;
   gint64 i2;
-
   rval->get(i2);
 
-  if(i2 < 0  || i2 > 63)
-    throw new Error("Operator " + showOp() + " bad shift count");
+  if (i2 < 0  || i2 > 63) {
+    throw Error("Operator " + showOp() + " bad shift count");
+  }
 
   lval->get(i1);
-
-  return new Integer(i1>>i2);
+  return new Integer(i1 >> i2);
 }
 
 
@@ -600,20 +633,20 @@ OpLogicalNot::OpLogicalNot(Expression* expr)
 {
 }
 
+
 OpLogicalNot::~OpLogicalNot()
 {
 }
 
+
 Value* OpLogicalNot::applyOp(Value* operand)
 {
-  Boolean* op;
-  bool bVal;
-
-  op = Boolean::typeCheck(operand, showOp());
-  bVal = op->getVal();
+  Boolean *op = Boolean::typeCheck(operand, showOp());
+  bool bVal = op->getVal();
   return new Boolean(!bVal);
 }
 
+
 /******************************************************************************
  The unary 'negate' operator.
 ******************************************************************************/
@@ -622,6 +655,7 @@ OpNegate::OpNegate(Expression* expr)
 {
 }
 
+
 OpNegate::~OpNegate()
 {
 }
@@ -629,23 +663,26 @@ OpNegate::~OpNegate()
 
 Value* OpNegate::applyOp(Value* operand)
 {
-  Value* rVal=0;
+  Value* rVal = nullptr;
 
   if (isInteger(operand)) {
-    Integer* iOp = (Integer*)(operand);
+    // Safe to cast because of the above check
+    Integer *iOp = static_cast<Integer *>(operand);
     rVal = new Integer(-(iOp->getVal()));
-  }
-  else if (isFloat(operand)) {
-    Float* fOp = (Float*)(operand);
+
+  } else if (isFloat(operand)) {
+    // Safe to cast because of the above check
+    Float *fOp = static_cast<Float *>(operand);
     rVal = new Float(-(fOp->getVal()));
-  }
-  else {
-    throw new TypeMismatch(showOp(), operand->showType());
+
+  } else {
+    throw TypeMismatch(showOp(), operand->showType());
   }
 
   return rVal;
 }
 
+
 /******************************************************************************
  The unary ones complement operator '~'.
 ******************************************************************************/
@@ -654,6 +691,7 @@ OpOnescomp::OpOnescomp(Expression* expr)
 {
 }
 
+
 OpOnescomp::~OpOnescomp()
 {
 }
@@ -661,12 +699,11 @@ OpOnescomp::~OpOnescomp()
 
 Value* OpOnescomp::applyOp(Value* operand)
 {
-  Integer* op;
-
-  op = Integer::typeCheck(operand, showOp());
-  return new Integer(~ op->getVal() );
+  Integer *op = Integer::typeCheck(operand, showOp());
+  return new Integer(~ op->getVal());
 }
 
+
 /******************************************************************************
  The unary 'plus' operator.
 ******************************************************************************/
@@ -675,6 +712,7 @@ OpPlus::OpPlus(Expression* expr)
 {
 }
 
+
 OpPlus::~OpPlus()
 {
 }
@@ -682,23 +720,26 @@ OpPlus::~OpPlus()
 
 Value* OpPlus::applyOp(Value* operand)
 {
-  Value* rVal=0;
+  Value* rVal = nullptr;
 
   if (isInteger(operand)) {
-    Integer* iOp = (Integer*)(operand);
+    // Safe to cast because of the above check
+    Integer *iOp = static_cast<Integer *>(operand);
     rVal = new Integer(iOp->getVal());
-  }
-  else if (isFloat(operand) ) {
-    Float* fOp = (Float*)(operand);
+
+  } else if (isFloat(operand)) {
+    // Safe to cast because of the above check
+    Float *fOp = static_cast<Float *>(operand);
     rVal = new Float(fOp->getVal());
-  }
-  else {
-    throw new TypeMismatch(showOp(), operand->showType());
+
+  } else {
+    throw TypeMismatch(showOp(), operand->showType());
   }
 
   return rVal;
 }
 
+
 /******************************************************************************
  The unary '*' operator - indirect access
 ******************************************************************************/
@@ -707,6 +748,7 @@ OpIndirect::OpIndirect(Expression* expr)
 {
 }
 
+
 OpIndirect::~OpIndirect()
 {
 }
@@ -714,35 +756,41 @@ OpIndirect::~OpIndirect()
 
 Value* OpIndirect::applyOp(Value* operand)
 {
-  Value* rVal=0;
-  Register *pReg = 0;
+  Value* rVal = nullptr;
 
   if (isInteger(operand)) {
-    Integer* iOp = (Integer*)(operand);
+    Register *pReg = nullptr;
+    // Safe to cast because of the above check
+    Integer *iOp = static_cast<Integer *>(operand);
+
     // hmm ... what about ema? Need a different indirection operator?
-    if (get_active_cpu())
-        pReg = get_active_cpu()->rma.get_register(*iOp);
-    if(pReg) {
-      rVal = new Integer(pReg->get());
+    if (get_active_cpu()) {
+      pReg = get_active_cpu()->rma.get_register(*iOp);
     }
-    else {
+
+    if (pReg) {
+      rVal = new Integer(pReg->get());
+
+    } else {
       static char sFormat[] = "Value $%x is an invalid memory address";
       char sMsg[sizeof(sFormat) + 10];
-      sprintf(sMsg, sFormat, (int)iOp->getVal());
-      throw new Error(string(sMsg));
+      snprintf(sMsg, sizeof(sMsg), sFormat, (int)iOp->getVal());
+      throw Error(sMsg);
     }
-  }
-  else if (isFloat(operand) ) {
-    Float* fOp = (Float*)(operand);
+
+  } else if (isFloat(operand)) {
+    // Safe to cast because of the above check
+    Float *fOp = static_cast<Float *>(operand);
     rVal = new Float(fOp->getVal());
-  }
-  else {
-    throw new TypeMismatch(showOp(), operand->showType());
+
+  } else {
+    throw TypeMismatch(showOp(), operand->showType());
   }
 
   return rVal;
 }
 
+
 /******************************************************************************
  The unary '*' operator - indirect access
 ******************************************************************************/
@@ -751,29 +799,32 @@ OpAddressOf::OpAddressOf(Expression* expr)
 {
 }
 
+
 OpAddressOf::~OpAddressOf()
 {
 }
 
+
 Value* OpAddressOf::evaluate()
 {
   Value* tmp;
-
   // start evaluating our operand expression:
   LiteralSymbol *pSym = dynamic_cast<LiteralSymbol *>(expr);
+
   if (pSym) {
     tmp = applyOp(pSym->GetSymbol());
+
+  } else {
+    throw TypeMismatch(showOp(), expr->showType());
   }
-  else {
-    throw new TypeMismatch(showOp(), expr->showType());
-  }
+
   return tmp;
 }
 
+
 Value* OpAddressOf::applyOp(Value* operand)
 {
-  Value* rVal=0;
-
+  Value* rVal = nullptr;
   /*
   register_symbol *pReg =dynamic_cast<register_symbol*>(operand);
   if (pReg) {
@@ -790,10 +841,12 @@ Value* OpAddressOf::applyOp(Value* operand)
   }
   */
   Register *pReg = dynamic_cast<Register*>(operand);
-  rVal = pReg ? new Integer(pReg->getAddress()) : 0;
-  if(rVal==0) {
-    throw new TypeMismatch(showOp(), operand->showType());
+  rVal = pReg ? new Integer(pReg->getAddress()) : nullptr;
+
+  if (rVal == nullptr) {
+    throw TypeMismatch(showOp(), operand->showType());
   }
+
   return rVal;
 }
 
