@@ -19,12 +19,13 @@ License along with this library; if not, see
 */
 
 
-
 /* os_dependent.cc  -                   */
 /* version 0.1                          */
 
 #include <stdio.h>
 #include <stdlib.h>
+
+#include <algorithm>
 #include <string>
 
 #include "../config.h"
@@ -34,7 +35,7 @@ License along with this library; if not, see
 #ifdef _WIN32
 #define G_PLATFORM_WIN32
 #define G_OS_WIN32
-#include <glib/gmem.h>
+#include <glib.h>
 #include <glib/gwin32.h>
 #include <direct.h>
 #include <windows.h>
@@ -49,8 +50,6 @@ License along with this library; if not, see
 
 #endif	// _WIN32
 
-using namespace std;
-
 #ifdef _WIN32
 #define MODULE_EXT ".dll"
 #define FOLDERDELIMITER '\\'
@@ -81,158 +80,193 @@ using namespace std;
 //------------------------------------------------------------------------
 // Convert forward slashes and backslashes into the os-dependent
 // slash
-void translatePath(string &sPath)
+void translatePath(std::string &sPath)
 {
-  string::size_type nPos;
-  while ( (nPos = sPath.find(FOLDERDELIMITERALTERNATIVE)) != string::npos)
-    sPath[nPos] = FOLDERDELIMITER;
+  std::replace(sPath.begin(), sPath.end(), FOLDERDELIMITERALTERNATIVE, FOLDERDELIMITER);
 }
 
+
 //------------------------------------------------------------------------
 // EnsureTrailingFolderDelimiter -- append a directory delimeter (slash)
 // to the string if one is not present already.
 
-void EnsureTrailingFolderDelimiter(string &sPath)
+void EnsureTrailingFolderDelimiter(std::string &sPath)
 {
-  string::reference rLast = sPath.at(sPath.size() - 1);
-  if(rLast == FOLDERDELIMITERALTERNATIVE)
+  std::string::reference rLast = sPath.at(sPath.size() - 1);
+
+  if (rLast == FOLDERDELIMITERALTERNATIVE) {
     rLast = FOLDERDELIMITER;
-  else if(rLast != FOLDERDELIMITER)
+
+  } else if (rLast != FOLDERDELIMITER) {
     sPath.push_back(FOLDERDELIMITER);
+  }
 }
 
+
 //------------------------------------------------------------------------
 bool LIBGPSIM_EXPORT IsFileExtension(const char *pszFile, const char *pFileExt)
 {
-  string s(pszFile);
-
-  string::size_type i = s.rfind('.') ;
-
-  return (i != string::npos) && (s.substr(i+1)==pFileExt);
-
+  std::string s = pszFile;
+  std::string::size_type i = s.rfind('.');
+  return (i != std::string::npos) && (s.substr(i + 1) == pFileExt);
 }
 
+
 //------------------------------------------------------------------------
 /// SplitPathAndFile()
 /// Note this function does not verify whether the trailing
 /// is actually a file component.
-void SplitPathAndFile(string &sSource, string &sFolder, string &sFile) {
+void SplitPathAndFile(std::string &sSource, std::string &sFolder, std::string &sFile)
+{
   translatePath(sSource);
-  string::size_type LastDelimiter = sSource.find_last_of(FOLDERDELIMITER);
-  if (LastDelimiter == string::npos) {
+  std::string::size_type LastDelimiter = sSource.find_last_of(FOLDERDELIMITER);
+
+  if (LastDelimiter == std::string::npos) {
     // JRH - I'm not sure this is a good assumption.
     // It will do for the one place it is currently being used.
-    static char sCurrentFolder[] = { '.', FOLDERDELIMITER , '\0'};
+    static char sCurrentFolder[] = { '.', FOLDERDELIMITER, '\0'};
     sFolder.append(sCurrentFolder);
     sFile = sSource;
-  }
-  else {
+
+  } else {
     sFolder = sSource.substr(0, LastDelimiter + 1);
     sFile = sSource.substr(LastDelimiter + 1);
   }
 }
 
-const char * CFileSearchPath::Find(string &path) {
+
+const char * CFileSearchPath::Find(std::string &path)
+{
   const_iterator it = find(begin(), end(), path);
+
   if (it != end()) {
     return (*it).c_str();
   }
-  return NULL;
+
+  return nullptr;
 }
 
+
 static CFileSearchPath asDllSearchPath;
 #if defined(_DEBUG)
 static bool bAltPaths = false;
 #endif
-//void AddModulePathFromFilePath(string &sFolder) {
-void AddModulePathFromFilePath(char *arg) {
-  string sFile;
-  string sFolder = arg;
+
+void AddModulePathFromFilePath(char *arg)
+{
+  std::string sFile;
+  std::string sFolder = arg;
   asDllSearchPath.AddPathFromFilePath(sFolder, sFile);
-  char * pszGpsimModulePath;
-  if((pszGpsimModulePath = getenv("GPSIM_MODULE_PATH")) != NULL) {
+  char * pszGpsimModulePath = getenv("GPSIM_MODULE_PATH");
+
+  if (pszGpsimModulePath) {
     char * pLast = pszGpsimModulePath;
     char * pChar = strchr(pszGpsimModulePath, PATHDELIMITER[0]);
-    string sFolder;
-    while(true) {
-      if(pChar != NULL) {
+    std::string sFolder;
+
+    while (true) {
+      if (pChar) {
         *pChar = '\0';
       }
-      if(*pLast != '\0') {
+
+      if (*pLast != '\0') {
         // only add non empty folders
         sFolder = pLast;
         translatePath(sFolder);
-        if(sFolder[sFolder.size() - 1] != FOLDERDELIMITER) {
+
+        if (sFolder[sFolder.size() - 1] != FOLDERDELIMITER) {
           sFolder.push_back(FOLDERDELIMITER);
         }
+
         asDllSearchPath.push_back(sFolder);
       }
-      if(pChar == NULL) {
+
+      if (pChar == nullptr) {
         break;
       }
+
       pChar++;
       pLast = pChar;
       pChar = strchr(pChar, PATHDELIMITER[0]);
     }
   }
+
 #if defined(_DEBUG)
-  if(!bAltPaths) {
+
+  if (!bAltPaths) {
     bAltPaths = true;
-    string sPath;
+    std::string sPath;
     int iPos = sFolder.find_last_of(FOLDERDELIMITER);
-    if(iPos != string::npos) {
+
+    if (iPos != std::string::npos) {
       char szLine[1024];
       sPath = sFolder.substr(0, iPos + 1);
       sPath.append("altpaths.txt");
       FILE *pFile = fopen(sPath.c_str(), "r");
-      if(pFile) {
-        while(fgets(szLine, 1024, pFile) != NULL) {
+
+      if (pFile) {
+        while (fgets(szLine, sizeof(szLine), pFile) != nullptr) {
           char *pChar = &szLine[strlen(szLine) - 1];
-          while((*pChar == '\n') && pChar != szLine)
+
+          while ((*pChar == '\n') && pChar != szLine) {
             *pChar-- = 0;
-          if(*pChar != FOLDERDELIMITER) {
+          }
+
+          if (*pChar != FOLDERDELIMITER) {
             pChar++;
             *pChar = FOLDERDELIMITER;
             pChar++;
             *pChar = 0;
           }
-          asDllSearchPath.push_back(string(szLine));
+
+          asDllSearchPath.push_back(std::string(szLine));
         }
+
         fclose(pFile);
       }
     }
   }
+
 #endif
 }
 
-void CFileSearchPath::AddPathFromFilePath(string &sFolder, string &sFile) {
-  string::size_type LastDelimiter = sFolder.find_last_of(FOLDERDELIMITER);
-  if (LastDelimiter == string::npos) {
+
+void CFileSearchPath::AddPathFromFilePath(std::string &sFolder, std::string &sFile)
+{
+  std::string::size_type LastDelimiter = sFolder.find_last_of(FOLDERDELIMITER);
+
+  if (LastDelimiter == std::string::npos) {
     sFile = sFolder;
-  }
-  else {
-    string sNewFolder;
+
+  } else {
+    std::string sNewFolder;
     sNewFolder = sFolder.substr(0, LastDelimiter + 1);
     sFile = sFolder.substr(LastDelimiter + 1);
     iterator it = find(asDllSearchPath.begin(),
-      asDllSearchPath.end(), sNewFolder);
+                       asDllSearchPath.end(), sNewFolder);
+
     if (it == asDllSearchPath.end()) {
       asDllSearchPath.insert(asDllSearchPath.begin(), sNewFolder);
     }
   }
 }
+
+
 //------------------------------------------------------------------------
-bool bHasAbsolutePath(string &fname)
+bool bHasAbsolutePath(std::string &fname)
 {
   return fname[0] == FOLDERDELIMITER;
 }
+
+
 //---------------------------
 //OS agnostic library loader
 
 static void * sLoad(const char *library_name)
 {
-  if(!library_name)
-    return 0;
+  if (!library_name) {
+    return nullptr;
+  }
 
   void *handle;
 #ifdef _WIN32
@@ -242,37 +276,45 @@ static void * sLoad(const char *library_name)
   // be or'd with the second pararmeter of the function call. However,
   // under Linux at least, this apparently cause *all* symbols to
   // disappear.
-
-  handle = dlopen (library_name, RTLD_NOW); // | RTLD_GLOBAL);
+  handle = dlopen(library_name, RTLD_NOW);  // | RTLD_GLOBAL);
 #endif
   return handle;
 }
 
-void FixupLibraryName(string &sPath) {
+
+void FixupLibraryName(std::string &sPath)
+{
   translatePath(sPath);
 }
 
-void GetFileName(string &sPath, string &sName) {
-  string::size_type pos = sPath.find_last_of(FOLDERDELIMITER);
-  if(pos != string::npos) {
+
+void GetFileName(std::string &sPath, std::string &sName)
+{
+  std::string::size_type pos = sPath.find_last_of(FOLDERDELIMITER);
+
+  if (pos != std::string::npos) {
     sName = sPath.substr(pos + 1);
-  }
-  else if(&sName != &sPath) {
+
+  } else if (&sName != &sPath) {
     sName = sPath;
   }
 }
 
-void GetFileNameBase(string &sPath, string &sName) {
+
+void GetFileNameBase(std::string &sPath, std::string &sName)
+{
   GetFileName(sPath, sName);
-  string::size_type pos = sName.find_last_of('.');
-  if(pos != string::npos) {
+  std::string::size_type pos = sName.find_last_of('.');
+
+  if (pos != std::string::npos) {
     sName = sName.substr(0, sName.size() - pos + 1);
-  }
-  else {
+
+  } else {
     sName = sPath;
   }
 }
 
+
 const char * get_error_message()
 {
 #ifdef _WIN32
@@ -282,14 +324,18 @@ const char * get_error_message()
 #endif
 }
 
+
 void free_error_message(const char * pszError)
 {
+  (void)pszError;
 #ifdef _WIN32
   g_free((char *) pszError);
 #endif
 }
 
-unsigned long get_error(const char *err_str) {
+
+unsigned long get_error(const char *err_str)
+{
 #ifdef _WIN32
   return GetLastError();
 #else
@@ -299,30 +345,32 @@ unsigned long get_error(const char *err_str) {
   ** to try to determine if file was not found. RRR
   */
   unsigned long ret = errno;	// in Linux errno is 0
-  if (! ret && err_str && strstr(err_str, "No such file"))
-	ret = OS_E_FILENOTFOUND;
+
+  if (! ret && err_str && strstr(err_str, "No such file")) {
+    ret = OS_E_FILENOTFOUND;
+  }
+
   return ret;
 #endif
 }
 
+
 void * load_library(const char *library_name, const char **pszError)
 {
-  void *handle;
-
-  string sFile;
-  string sPath(library_name);
+  std::string sFile;
+  std::string sPath(library_name);
   FixupLibraryName(sPath);
   asDllSearchPath.AddPathFromFilePath(sPath, sFile);
 
-
   // loop twice: first time take the file name as is,
   // the second time append the os-dependent library extension.
-  for (int i=0; i<2; i++) {
-
+  for (int i = 0; i < 2; i++) {
+    void *handle;
     // First, see if we can load the library from where ever the
     // system thinks libraries are located.
-    if( (handle = sLoad(sPath.c_str())) != 0)
+    if ((handle = sLoad(sPath.c_str())) != 0) {
       return handle;
+    }
 
     *pszError = get_error_message();
     unsigned long uError = get_error(*pszError);
@@ -330,56 +378,58 @@ void * load_library(const char *library_name, const char **pszError)
     if (uError == OS_E_FILENOTFOUND) {
       // Failed to find the library in the system paths, so try to load
       // from one of our paths.
-
       free_error_message(*pszError);
+      CFileSearchPath::iterator itSearchPath = asDllSearchPath.begin();
 
-      CFileSearchPath::iterator itSearchPath;
-      for (itSearchPath = asDllSearchPath.begin();
-	   itSearchPath != asDllSearchPath.end();
-	   ++itSearchPath) {
-	sPath = *itSearchPath + sFile;
+      for ( ; itSearchPath != asDllSearchPath.end(); ++itSearchPath) {
+        sPath = *itSearchPath + sFile;
+        handle = sLoad(sPath.c_str());
 
-	handle = sLoad(sPath.c_str());
+        if (handle) {
+          return handle;
+        }
 
-	if (NULL != handle) {
-	  return handle;
-	}
-	*pszError = get_error_message();
+        *pszError = get_error_message();
       }
     }
+
     // Append the module extension and try again.
-    string::size_type nPos = sFile.find(MODULE_EXT,0);
-    if( nPos == string::npos)
-    {
-        sFile.append(MODULE_EXT);
+    std::string::size_type nPos = sFile.find(MODULE_EXT, 0);
+
+    if (nPos == std::string::npos) {
+      sFile.append(MODULE_EXT);
     }
+
 #ifndef _WIN32
-    else if( sFile.find(MODULE_VER, nPos) == string::npos)
-    {
-	i--;
-	sFile.append(MODULE_VER);
+
+    else if (sFile.find(MODULE_VER, nPos) == std::string::npos) {
+      i--;
+      sFile.append(MODULE_VER);
     }
+
 #endif
     sPath = sFile;
   }
 
   // Should there be a free?
   if (*pszError)
-      printf("Failed loading %s: %s\n",
-            sPath.c_str(), *pszError);
-  return NULL;
+    printf("Failed loading %s: %s\n", sPath.c_str(), *pszError);
+
+  return nullptr;
 }
 
+
 void free_library(void *handle)
 {
 #ifdef _WIN32
   FreeLibrary((HMODULE)handle);
 #else
-  dlclose (handle);
+  dlclose(handle);
 #endif
 }
 
-void * get_library_export(const char *name, void *library_handle, const char ** pszError)
+
+void * get_library_export(const char *name, void *library_handle, const char **pszError)
 {
   void * pExport;
 #ifdef _WIN32
@@ -388,8 +438,10 @@ void * get_library_export(const char *name, void *library_handle, const char **
   dlerror();	// Clear possible previous errors
   pExport = dlsym(library_handle, name);
 #endif
-  if (NULL == pExport && pszError != NULL) {
+
+  if (!pExport && pszError) {
     *pszError = get_error_message();
   }
+
   return pExport;
 }
