@@ -78,6 +78,11 @@ void PIR::setPeripheralInterrupt()
     intcon->peripheral_interrupt ( ipr && (value.get() & valid_bits & ipr->value.get() & pie->value.get()) );
 }
 
+/*
+   return 0 : no interrupt pending
+          1 : low priority interrupt pending
+	  2 : high priority unterrupt pending
+*/
 int PIR::interrupt_status()
 {
   assert(pie);
