@@ -1,40 +1,41 @@
 /*
    Copyright (C) 1998-2003 Scott Dattalo
 
-This file is part of gpsim.
+This file is part of the libgpsim library of gpsim
 
-gpsim is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
 
-gpsim is distributed in the hope that it will be useful,
+This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Lesser General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with gpsim; see the file COPYING.  If not, write to
-the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, see
+<http://www.gnu.org/licenses/lgpl-2.1.html>.
+*/
 
-#ifndef __REGISTERS_H__
-#define __REGISTERS_H__
+#ifndef SRC_REGISTERS_H_
+#define SRC_REGISTERS_H_
 
-#include <stdio.h>
-#include <iostream>
-#include <iomanip>
 #include <glib.h>
 
-class symbol;
-class XrefObject;
+class Expression;
 class Processor;
 class Module;
 
 #include "gpsim_classes.h"
+#include "gpsim_object.h"
 #include "value.h"
 #include "ValueCollections.h"
 
+#include <string>
+#include <vector>
+
+#define AN_INVALID_ADDRESS 0xffffffff
 
 //---------------------------------------------------------
 // RegisterValue class
@@ -44,26 +45,23 @@ class Module;
 // are valid.
 //
 
-class RegisterValue
-{
+class RegisterValue {
 public:
-
-  unsigned int data;  // The actual numeric value of the register.
-  unsigned int init;  // bit mask of initialized bits.
+  unsigned int data = 0;  // The actual numeric value of the register.
+  unsigned int init = 0xff;  // bit mask of initialized bits.
+                             // assume 8-bit wide, uninitialized registers
 
   RegisterValue()
   {
-    data = 0;
-    init = 0xff;  // assume 8-bit wide, uninitialized registers
   }
 
-  RegisterValue(unsigned int d, unsigned int i) : 
-    data(d), init(i)
+  RegisterValue(unsigned int d, unsigned int i)
+    : data(d), init(i)
   {
   }
 
-  RegisterValue(const RegisterValue &value) : 
-  data(value.data), init(value.init)
+  RegisterValue(const RegisterValue &value)
+    : data(value.data), init(value.init)
   {
   }
 
@@ -114,25 +112,27 @@ public:
     return (int)data;
   }
 
-  bool operator == (const RegisterValue &rv) const {
+  bool operator == (const RegisterValue &rv) const
+  {
     return data == rv.data && init == rv.init;
   }
 
-  bool operator != (const RegisterValue &rv) const {
+  bool operator != (const RegisterValue &rv) const
+  {
     return data != rv.data || init != rv.init;
   }
 
-  void operator >>= (unsigned int val) {
-      data >>= val;
-      init >>= val;
+  void operator >>= (unsigned int val)
+  {
+    data >>= val;
+    init >>= val;
   }
-  char * toString(char *str, int len, int regsize=2) const;
-  char * toBitStr(char *s, int len, unsigned int BitPos, 
-                  const char *ByteSeparator="_",
-                  const char *HiBitNames=0,
-                  const char *LoBitNames=0,
-                  const char *UndefBitNames=0) const;
-
+  char * toString(char *str, int len, int regsize = 2) const;
+  char * toBitStr(char *s, int len, unsigned int BitPos,
+                  const char *ByteSeparator = "_",
+                  const char *HiBitNames = nullptr,
+                  const char *LoBitNames = nullptr,
+                  const char *UndefBitNames = nullptr) const;
 };
 
 
@@ -140,38 +140,32 @@ public:
 /// Register - base class for gpsim registers.
 /// The Register class is used by processors and modules to
 /// to create memory maps and special function registers.
-/// 
+///
 
-class Register : public Value
-{
+class Register : public Value {
 public:
-
-  enum REGISTER_TYPES
-    {
-      INVALID_REGISTER,
-      GENERIC_REGISTER,
-      FILE_REGISTER,
-      SFR_REGISTER,
-      BP_REGISTER
-    };
+  enum REGISTER_TYPES {
+    INVALID_REGISTER,
+    GENERIC_REGISTER,
+    FILE_REGISTER,
+    SFR_REGISTER,
+    BP_REGISTER
+  };
 
   RegisterValue value;
-
-  unsigned int address;
+  unsigned int address = AN_INVALID_ADDRESS;
 
   // If non-zero, the alias_mask describes all address at which
   // this file register appears. The assumption (that is true so
   // far for all pic architectures) is that the aliased register
   // locations differ by one bit. For example, the status register
-  // appears at addresses 0x03 and 0x83 in the 14-bit core. 
+  // appears at addresses 0x03 and 0x83 in the 14-bit core.
   // Consequently, alias_mask = 0x80 and address (above) is equal
   // to 0x03.
 
-  unsigned int alias_mask;
-
+  unsigned int alias_mask = 0;
   RegisterValue por_value;  // power on reset value
-
-  unsigned int bit_mask;   // = 7 for 8-bit registers, = 15 for 16-bit registers.
+  unsigned int mValidBits = 0xFF;  // = 255 for 8-bit registers, = 65535 for 16-bit registers.
 
   // The read_trace and write_trace variables are used while
   // tracing register reads and writes. Essentially, these are
@@ -185,17 +179,18 @@ public:
 
   RegisterValue trace_state;
 
-
-  guint64 read_access_count;
-  guint64 write_access_count;
+  guint64 read_access_count = 0;
+  guint64 write_access_count = 0;
 
 
 public:
-  Register(Module *, const char *pName, const char *pDesc=0);
+  Register(Module *, const char *pName, const char *pDesc = nullptr);
   virtual ~Register();
 
 
-  virtual int set_break(ObjectBreakTypes bt=eBreakAny, ObjectActionTypes at=eActionHalt, Expression *expr=0);
+  virtual int set_break(ObjectBreakTypes bt = eBreakAny,
+                        ObjectActionTypes at = eActionHalt,
+                        Expression *expr = nullptr);
   virtual int clear_break();
 
   /// get - method for accessing the register's contents.
@@ -203,10 +198,10 @@ public:
   virtual unsigned int get();
 
   /// put - method for writing a new value to the register.
-  
+
   virtual void put(unsigned int new_value);
 
-  
+
   /// put_value - is the same as put(), but some extra stuff like
   /// interfacing to the gui is done. (It's more efficient than
   /// burdening the run time performance with (unnecessary) gui
@@ -217,12 +212,15 @@ public:
 
   /// get_value - same as get(), but no trace is performed
 
-  virtual unsigned int get_value() { return(value.get()); }
+  virtual unsigned int get_value()
+  {
+    return value.get();
+  }
 
   /// getRV - get the whole register value - including the info
   /// of the three-state bits.
 
-  virtual RegisterValue getRV() 
+  virtual RegisterValue getRV()
   {
     value.data = get();
     return value;
@@ -230,10 +228,10 @@ public:
 
   /// putRV - write a new value to the register.
   /// \deprecated {use SimPutAsRegisterValue()}
-  /// 
+  ///
 
   virtual void putRV(RegisterValue rv)
-  { 
+  {
     value.init = rv.init;
     put(rv.data);
   }
@@ -245,12 +243,12 @@ public:
   /// up the trace buffer
 
   virtual RegisterValue getRV_notrace()
-  { 
-    value.data = get_value();
+  {
+    value.data = value.get();
     return value;
   }
   virtual void putRV_notrace(RegisterValue rv)
-  { 
+  {
     value.init = rv.init;
     put_value(rv.data);
   }
@@ -281,7 +279,7 @@ public:
   }
 
   /// get3StateBit - returns the 3-state value of a bit
-  /// if a bit is known then a '1' or '0' is returned else, 
+  /// if a bit is known then a '1' or '0' is returned else,
   /// a '?' is returned. No check is performed to ensure
   /// that only a single bit is checked, thus it's possible
   /// to get the state of a group of bits using this method.
@@ -289,7 +287,7 @@ public:
   virtual char get3StateBit(unsigned int bitMask)
   {
     RegisterValue rv = getRV_notrace();
-    return (rv.init&bitMask) ? '?' : (rv.data&bitMask ? '1':'0');
+    return (rv.init & bitMask) ? '?' : ((rv.data & bitMask) ? '1' : '0');
   }
   /// In the Register class, the 'Register *get()' returns a
   /// pointer to itself. Derived classes may return something
@@ -300,36 +298,37 @@ public:
   {
     return this;
   }
-  
-  virtual REGISTER_TYPES isa() {return GENERIC_REGISTER;};
-  virtual void reset(RESET_TYPE r) { return; };
 
-   
+  virtual REGISTER_TYPES isa()
+  {
+    return GENERIC_REGISTER;
+  }
+  virtual void reset(RESET_TYPE )
+  {
+  }
+
   /// The setbit function is not really intended for general purpose
   /// registers. Instead, it is a place holder which is over-ridden
   /// by the IO ports.
-  
+
   virtual void setbit(unsigned int bit_number, bool new_value);
 
-  
   ///  like setbit, getbit is used mainly for breakpoints.
-  
+
   virtual bool get_bit(unsigned int bit_number);
   virtual double get_bit_voltage(unsigned int bit_number);
 
-
   ///  Breakpoint objects will overload this function and return true.
 
   virtual bool hasBreak()
-  { 
+  {
     return false;
   }
 
-
   ///  register_size returns the number of bytes required to store the register
   ///  (this is used primarily by the gui to determine how wide to make text fields)
 
-  virtual unsigned int register_size () const;
+  virtual unsigned int register_size() const;
 
   /*
     When the register is accessed, this action is recorded in the trace buffer.
@@ -351,8 +350,8 @@ public:
     convert value to a string:
    */
   virtual char * toString(char *str, int len);
-  virtual char * toBitStr(char *s, int len); 
-  virtual string &baseName()
+  virtual char * toBitStr(char *s, int len);
+  virtual std::string &baseName()
   {
     return name_str;
   }
@@ -365,17 +364,22 @@ public:
   {
     address = addr;
   }
-  Register *getReplaced() { return m_replaced; }
-  void setReplaced(Register *preg) { m_replaced = preg; }
+  Register *getReplaced()
+  {
+    return m_replaced;
+  }
+  void setReplaced(Register *preg)
+  {
+    m_replaced = preg;
+  }
 
-  virtual void new_name(string &);
+  virtual void new_name(std::string &);
   virtual void new_name(const char *);
 
 protected:
   // A pointer to the register that this register replaces.
-  // This is used primarily by the breakpoint code. 
-  Register *m_replaced;
-
+  // This is used primarily by the breakpoint code.
+  Register *m_replaced = nullptr;
 };
 
 
@@ -383,16 +387,20 @@ protected:
 // define a special 'invalid' register class. Accessess to
 // to this class' value get 0
 
-class InvalidRegister : public Register
-{
+class InvalidRegister : public Register {
 public:
-
-  InvalidRegister(Processor *, const char *pName, const char *pDesc=0);
+  InvalidRegister(Processor *, const char *pName, const char *pDesc = nullptr);
 
   void put(unsigned int new_value);
   unsigned int get();
-  virtual REGISTER_TYPES isa() {return INVALID_REGISTER;};
-  virtual Register *getReg()   {return 0; }
+  virtual REGISTER_TYPES isa() override
+  {
+    return INVALID_REGISTER;
+  }
+  virtual Register *getReg() override
+  {
+    return nullptr;
+  }
 };
 
 
@@ -400,25 +408,34 @@ public:
 // Base class for a special function register.
 class BitSink;
 
-class sfr_register : public Register
-{
+
+class sfr_register : public Register {
 public:
-  sfr_register(Module *, const char *pName, const char *pDesc=0);
+  sfr_register(Module *, const char *pName, const char *pDesc = nullptr);
 
   RegisterValue wdtr_value; // wdt or mclr reset value
 
-  virtual REGISTER_TYPES isa() {return SFR_REGISTER;};
-  virtual void initialize() {};
+  virtual REGISTER_TYPES isa() override
+  {
+    return SFR_REGISTER;
+  }
+  virtual void initialize() override {}
 
-  virtual void reset(RESET_TYPE r);
+  virtual void reset(RESET_TYPE r) override;
 
-  // The assign and release BitSink methods don't do anything 
+  // The assign and release BitSink methods don't do anything
   // unless derived classes redefine them. Their intent is to
   // provide an interface to the BitSink design - a design that
   // allows clients to be notified when bits change states.
 
-  virtual bool assignBitSink(unsigned int bitPosition, BitSink *) {return false;}
-  virtual bool releaseBitSink(unsigned int bitPosition, BitSink *) {return false;}
+  virtual bool assignBitSink(unsigned int /* bitPosition */ , BitSink *)
+  {
+    return false;
+  }
+  virtual bool releaseBitSink(unsigned int /* bitPosition */ , BitSink *)
+  {
+    return false;
+  }
 };
 
 
@@ -427,15 +444,13 @@ public:
 // Program Counter
 //
 class PCTraceType;
-class Program_Counter : public Value
-{
+class Program_Counter : public Value {
 public:
-  unsigned int value;              /* pc's current value */
-  unsigned int memory_size_mask; 
-  unsigned int pclath_mask;        /* pclath confines PC to banks */
+  unsigned int value;              // pc's current value
+  unsigned int memory_size;
+  unsigned int pclath_mask;        // pclath confines PC to banks
   unsigned int instruction_phase;
-  unsigned int trace_state;        /* used while reconstructing the trace history */
-
+  unsigned int trace_state;        // used while reconstructing the trace history
 
   // Trace commands
   unsigned int trace_increment;
@@ -445,6 +460,7 @@ public:
 
   Program_Counter(const char *name, const char *desc, Module *pM);
   ~Program_Counter();
+
   virtual void increment();
   virtual void start_skip();
   virtual void skip();
@@ -453,19 +469,29 @@ public:
   virtual void computed_goto(unsigned int new_value);
   virtual void new_address(unsigned int new_value);
   virtual void put_value(unsigned int new_value);
+  virtual void update_pcl();
+  virtual void get(char *buffer, int buf_size);
   virtual unsigned int get_value()
   {
     return value;
   }
-  virtual unsigned int get_PC() {
+  virtual unsigned int get_PC()
+  {
     return value;
   }
 
-  virtual void set_PC(unsigned int new_value) {
+  virtual void set_PC(unsigned int new_value)
+  {
     value = new_value;
     this->update();
   }
 
+  /// set --- cast another Value object type into a program counter register type
+  /// this is used primarily by expression and stimuli processing
+  /// (the put() methods are used by the processors).
+  /// FIXME -- consolidate the get, set, and put methods
+  virtual void set(Value *);
+
   // initialize the dynamically allocated trace type
   virtual void set_trace_command();
 
@@ -478,19 +504,19 @@ public:
   }
 
   virtual void set_phase(int phase)
-  { 
+  {
     instruction_phase = phase;
   }
-  virtual int get_phase() 
+  virtual int get_phase()
   {
-    return instruction_phase; 
+    return instruction_phase;
   }
-  
+
   void set_reset_address(unsigned int _reset_address)
   {
     reset_address = _reset_address;
   }
-  unsigned int get_reset_address() 
+  unsigned int get_reset_address()
   {
     return reset_address;
   }
@@ -507,27 +533,29 @@ public:
 protected:
   unsigned int reset_address;      /* Value pc gets at reset */
   PCTraceType *m_pPCTraceType;
-  
 };
 
+
 // Used in the command prompt interface
-class RegisterCollection : public IIndexedCollection 
-{
+class RegisterCollection : public IIndexedCollection {
 public:
-  RegisterCollection(Processor *pProcessor, 
+  RegisterCollection(Processor *pProcessor,
                      const char *collection_name,
                      Register   **ppRegisters,
                      unsigned int uiSize);
   ~RegisterCollection();
+
+  virtual void get(char *return_str, int len);
   virtual unsigned int GetSize();
-  virtual Value &GetAt(unsigned int uIndex, Value *pValue=0);
+  virtual Value &GetAt(unsigned int uIndex, Value *pValue = nullptr);
   virtual void SetAt(unsigned int uIndex, Value *pValue);
   virtual void ConsolidateValues(int &iColumnWidth,
-                                 vector<string> &aList,
-                                 vector<string> &aValue);
-//  virtual void SetAt(ExprList_t* pIndexers, Expression *pExpr);
+                                 std::vector<std::string> &aList,
+                                 std::vector<std::string> &aValue);
+  //  virtual void SetAt(ExprList_t* pIndexers, Expression *pExpr);
   virtual unsigned int GetLowerBound();
   virtual unsigned int GetUpperBound();
+
 private:
   Processor *   m_pProcessor;
   Register **   m_ppRegisters;
@@ -545,12 +573,11 @@ private:
 //
 // A client wishing to be notified whenever an SFR bit changes states
 // will create a BitSink object and pass its pointer to the SFR. The
-// client will also tell the SFR which bit this applies to. Now, when 
+// client will also tell the SFR which bit this applies to. Now, when
 // the bit changes states in the SFR, the SFR will call the setSink()
 // method.
 
-class BitSink
-{
+class BitSink {
 public:
   virtual ~BitSink()
   {
@@ -560,4 +587,4 @@ public:
 };
 
 
-#endif // __REGISTERS__
+#endif // SRC_REGISTERS_H_
