@@ -14,7 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
@@ -27,13 +27,11 @@ License along with this library; if not, see
 #endif
 #include <time.h>
 #include <iostream>
-#include <iomanip>
 #include <string>
-#include <map>
 
 #ifndef _WIN32
 #if !defined(_MAX_PATH)
-  #define _MAX_PATH 1024
+#define _MAX_PATH 1024
 #endif
 #include <unistd.h>
 #else
@@ -43,13 +41,17 @@ License along with this library; if not, see
 
 #include "../config.h"
 
-#include "errors.h"
 #include "fopen-path.h"
+#include "gpsim_interface.h"
+#include "gpsim_time.h"
+#include "modules.h"
+#include "processor.h"
 #include "program_files.h"
 #include "sim_context.h"
 #include "breakpoints.h"
 #include "trace.h"
 #include "symbol.h"
+#include "ui.h"
 
 //================================================================================
 // Global Declarations
@@ -62,36 +64,37 @@ License along with this library; if not, see
 //
 // pic_processor
 //
-// This file contains all (most?) of the code that simulates those features 
+// This file contains all (most?) of the code that simulates those features
 // common to all pic microcontrollers.
 //
 //
 
-CSimulationContext::CSimulationContext() 
+CSimulationContext::CSimulationContext()
   :  m_bEnableLoadSource(*new Boolean("EnableSourceLoad", true,
-                                      "Enables and disables loading of source code")) 
+                                      "Enables and disables loading of source code"))
 {
-  active_cpu_id = 0;
-  cpu_ids = 0;
-  m_pbUserCanceled = NULL;
   globalSymbolTable().addSymbol(&m_bEnableLoadSource);
 }
 
-CSimulationContext::~CSimulationContext() 
+
+CSimulationContext::~CSimulationContext()
 {
   globalSymbolTable().deleteSymbol("EnableSourceLoad");
 }
 
+
 void CSimulationContext::Initialize()
 {
 }
 
+
 //------------------------------------------------------------
 // The static pointer 's_SimulationContext' in CSimulationContext
-// is initialized to 0 here, but initialized to something valid 
+// is initialized to 0 here, but initialized to something valid
 // when GetContext is called.
 
-CSimulationContext *CSimulationContext::s_SimulationContext = 0;
+CSimulationContext *CSimulationContext::s_SimulationContext = nullptr;
+
 
 CSimulationContext *CSimulationContext::GetContext()
 {
@@ -103,200 +106,221 @@ CSimulationContext *CSimulationContext::GetContext()
   return s_SimulationContext;
 }
 
+
 bool CSimulationContext::SetDefaultProcessor(const char * processor_type,
-                                             const char * processor_new_name) 
+    const char * processor_new_name)
 {
   if (processor_type) {
     ProcessorConstructor *pc = ProcessorConstructorList::GetList()->findByType(processor_type);
 
     if (pc) {
-      m_DefProcessorName    = processor_type;
-      if(processor_new_name == NULL)
-	m_DefProcessorNameNew.clear();
-      else
-	m_DefProcessorNameNew = processor_new_name;
+      m_DefProcessorName = processor_type;
+
+      if (processor_new_name == nullptr) {
+        m_DefProcessorNameNew.clear();
+
+      } else {
+        m_DefProcessorNameNew = processor_new_name;
+      }
+
       return true;
     }
+
   } else {
-
     m_DefProcessorNameNew = processor_new_name;
-
   }
 
   return false;
 }
 
+
 //-------------------------------------------------------------------
 Processor * CSimulationContext::SetProcessorByType(const char * processor_type,
-                                                   const char * processor_new_name)
+    const char * processor_new_name)
 {
   Processor *p;
-  CProcessorList::iterator it = processor_list.findByType(string(processor_type));
+  CProcessorList::iterator it = processor_list.findByType(std::string(processor_type));
   GetBreakpoints().clear_all(GetActiveCPU());
-
-  cout << __FUNCTION__ << " FIXME \n";
+  std::cout << __FUNCTION__ << " FIXME \n";
   // GetSymbolTable().Reinitialize();
 
-  if(processor_list.end() == it) {
-    p = add_processor(processor_type,processor_new_name);
-  }
-  else {
+  if (processor_list.end() == it) {
+    p = add_processor(processor_type, processor_new_name);
+
+  } else {
     p = it->second;
     delete p;
-    p = add_processor(processor_type,processor_new_name);
-//    p->init
+    p = add_processor(processor_type, processor_new_name);
+    //    p->init
   }
+
   return p;
 }
 
+
 //-------------------------------------------------------------------
 Processor * CSimulationContext::add_processor(const char * processor_type,
-                                              const char * processor_new_name)
+    const char * processor_new_name)
 {
-  if(verbose)
-    cout << "Trying to add new processor '" << processor_type << "' named '" 
-	 << processor_new_name << "'\n";
+  if (verbose)
+    std::cout << "Trying to add new processor '" << processor_type << "' named '"
+         << processor_new_name << "'\n";
 
   ProcessorConstructor *pc = ProcessorConstructorList::GetList()->findByType(processor_type);
-  if(pc) {
-    return add_processor(pc,processor_new_name ? processor_new_name : m_DefProcessorNameNew.c_str());
+
+  if (pc) {
+    return add_processor(pc, processor_new_name ? processor_new_name : m_DefProcessorNameNew.c_str());
+
   } else
-    cout << processor_type << " is not a valid processor.\n"
-      "(try 'processor list' to see a list of valid processors.\n";
-  return 0;
+    std::cout << processor_type << " is not a valid processor.\n"
+         "(try 'processor list' to see a list of valid processors.\n";
+
+  return nullptr;
 }
 
+
 Processor * CSimulationContext::add_processor(ProcessorConstructor *pc,
-					      const char * processor_new_name)
+    const char * processor_new_name)
 {
-  Processor *  p = pc->ConstructProcessor(processor_new_name);
-  if(p) {
+  Processor *p = pc->ConstructProcessor(processor_new_name);
+
+  if (p) {
     add_processor(p);
     p->m_pConstructorObject = pc;
+
+  } else {
+    std::cout << " unable to add a processor (BUG?)\n";
   }
-  else
-    cout << " unable to add a processor (BUG?)\n";
+
   return p;
 }
 
+
 Processor * CSimulationContext::add_processor(Processor *p)
 {
-    processor_list.insert(CProcessorList::value_type(p->name(), p));
-    //p->initializeAttributes();
-    active_cpu = p;
-    //p->processor_id = 
-    active_cpu_id = ++cpu_ids;
-    if(verbose) {
-      cout << p->name() << '\n';
-      cout << "Program Memory size " <<  p->program_memory_size() << " words\n";
-      cout << "Register Memory size " <<  p->register_memory_size() << '\n';
-    }
+  processor_list.insert(CProcessorList::value_type(p->name(), p));
+  //p->initializeAttributes();
+  active_cpu = p;
+  //p->processor_id =
+  active_cpu_id = ++cpu_ids;
 
-    trace.switch_cpus(p);
-    // Tell the gui or any modules that are interfaced to gpsim
-    // that a new processor has been declared.
-    gi.new_processor(p);
+  if (verbose) {
+    std::cout << p->name() << '\n';
+    std::cout << "Program Memory size " <<  p->program_memory_size() << " words\n";
+    std::cout << "Register Memory size " <<  p->register_memory_size() << '\n';
+  }
 
-    return p;
-
-  return 0;
+  trace.switch_cpus(p);
+  // Tell the gui or any modules that are interfaced to gpsim
+  // that a new processor has been declared.
+  gi.new_processor(p);
+  return p;
 }
 
+
 int CSimulationContext::LoadProgram(const char *filename,
                                     const char *pProcessorType,
                                     Processor **ppProcessor,
-				    const char *pProcessorName)
+                                    const char *pProcessorName)
 {
   bool bReturn = false;
-
   Processor *pProcessor;
-  FILE * pFile = fopen_path (filename, "rb");
-  if(pFile == NULL) {
-    char cw[_MAX_PATH];
+  FILE *pFile = fopen_path(filename, "rb");
 
-    perror((string("failed to open program file ") + filename).c_str());
-    if (!getcwd(cw, sizeof(cw)))
-        perror("getcwd failed: ");
-    else
-    {
-        cerr << "current working directory is " << cw << endl;
+  if (pFile == nullptr) {
+    char cw[_MAX_PATH];
+    perror((std::string("failed to open program file ") + filename).c_str());
+
+    if (!getcwd(cw, sizeof(cw))) {
+      perror("getcwd failed: ");
+
+    } else {
+      std::cerr << "current working directory is " << cw << '\n';
     }
+
     return false;
   }
-  if(pProcessorType != NULL) {
-    pProcessor = SetProcessorByType(pProcessorType, NULL);
-    if(pProcessor != NULL) {
+
+  if (pProcessorType) {
+    pProcessor = SetProcessorByType(pProcessorType, nullptr);
+
+    if (pProcessor) {
       bReturn  = pProcessor->LoadProgramFile(filename, pFile, pProcessorName);
     }
-  }
-  else if(!m_DefProcessorName.empty()) {
-    pProcessor = SetProcessorByType(m_DefProcessorName.c_str(), NULL);
-    if(pProcessor != NULL) {
+
+  } else if (!m_DefProcessorName.empty()) {
+    pProcessor = SetProcessorByType(m_DefProcessorName.c_str(), nullptr);
+
+    if (pProcessor) {
       bReturn  = pProcessor->LoadProgramFile(filename, pFile, pProcessorName);
     }
-  }
-  else {
-    pProcessor = NULL;
-    if (!m_DefProcessorNameNew.empty())
+
+  } else {
+    pProcessor = nullptr;
+
+    if (!m_DefProcessorNameNew.empty()) {
       pProcessorName = m_DefProcessorNameNew.c_str();
+    }
+
     // use processor defined in program file
     bReturn  = ProgramFileTypeList::GetList().LoadProgramFile(
-			   &pProcessor, filename, pFile, pProcessorName);
-
+                 &pProcessor, filename, pFile, pProcessorName);
   }
 
   fclose(pFile);
-  if(bReturn) {
+
+  if (bReturn) {
     // Tell all of the interfaces that a new program exists.
     gi.new_program(pProcessor);
   }
-  if(ppProcessor != NULL) {
+
+  if (ppProcessor) {
     *ppProcessor = pProcessor;
   }
+
   return bReturn;
 }
 
+
 //------------------------------------------------------------------------
-// dump_processor_list - print out all of the processors a user is 
+// dump_processor_list - print out all of the processors a user is
 //                       simulating.
 
-void CSimulationContext::dump_processor_list(void)
+void CSimulationContext::dump_processor_list()
 {
+  std::cout << "Processor List\n";
+  bool have_processors = false;
+  CProcessorList::iterator processor_iterator = processor_list.begin();
 
-  cout << "Processor List\n";
-
-  bool have_processors = 0;
-  CProcessorList::iterator processor_iterator; 
-  for (processor_iterator = processor_list.begin();
-       processor_iterator != processor_list.end(); 
-       ++processor_iterator) {
-      CProcessorList::value_type vt = *processor_iterator;
-      Processor *p = vt.second;
-      cout << p->name() << '\n';
-      have_processors = 1;
-    }
-
-  if(!have_processors)
-    cout << "(empty)\n";
+  for ( ; processor_iterator != processor_list.end(); ++processor_iterator) {
+    CProcessorList::value_type vt = *processor_iterator;
+    Processor *p = vt.second;
+    std::cout << p->name() << '\n';
+    have_processors = true;
+  }
 
+  if (!have_processors) {
+    std::cout << "(empty)\n";
+  }
 }
 
-void CSimulationContext::Clear() 
-{
 
-  CProcessorList::iterator processor_iterator; 
-  for (processor_iterator = processor_list.begin();
-       processor_iterator != processor_list.end(); 
-       ++processor_iterator) {
+void CSimulationContext::Clear()
+{
+  CProcessorList::iterator processor_iterator = processor_list.begin();
+
+  for ( ; processor_iterator != processor_list.end(); ++processor_iterator) {
     CProcessorList::value_type vt = *processor_iterator;
     Processor *p = vt.second;
     GetBreakpoints().clear_all(p);
     delete p;
   }
+
   processor_list.clear();
 }
 
-void CSimulationContext::Reset(RESET_TYPE r)
+
+void CSimulationContext::Reset(RESET_TYPE )
 {
   /*
   Symbol_Table &ST = get_symbol_table();
@@ -309,59 +333,76 @@ void CSimulationContext::Reset(RESET_TYPE r)
       }
   }
   */
-  cout << __FUNCTION__ << " FIXME \n";
+  std::cout << __FUNCTION__ << " FIXME \n";
 }
 
-void CSimulationContext::NotifyUserCanceled() {
-  if(m_pbUserCanceled != NULL) {
+
+void CSimulationContext::NotifyUserCanceled()
+{
+  if (m_pbUserCanceled) {
     *m_pbUserCanceled = true;
-    m_pbUserCanceled = NULL;
+    m_pbUserCanceled = nullptr;
     return;
   }
-  if(CSimulationContext::GetContext()->GetActiveCPU() && 
+
+  if (CSimulationContext::GetContext()->GetActiveCPU() &&
       CSimulationContext::GetContext()->GetActiveCPU()->simulation_mode
-    == eSM_RUNNING) {
+      == eSM_RUNNING) {
     // If we get a CTRL->C while processing a command file
     // we should probably stop the command file processing.
     CSimulationContext::GetContext()->GetBreakpoints().halt();
   }
 }
 
-SymbolTable & CSimulationContext::GetSymbolTable() 
+
+SymbolTable & CSimulationContext::GetSymbolTable()
 {
   return gSymbolTable;
 }
 
-Breakpoints & CSimulationContext::GetBreakpoints() {
+
+Breakpoints & CSimulationContext::GetBreakpoints()
+{
   return get_bp();
 }
 
-Processor * CSimulationContext::GetActiveCPU() {
+
+Processor * CSimulationContext::GetActiveCPU()
+{
   return get_active_cpu();
 }
 
-Cycle_Counter * CSimulationContext::GetCycleCounter() {
+
+Cycle_Counter * CSimulationContext::GetCycleCounter()
+{
   return &cycles;
 }
 
+
 CSimulationContext::CProcessorList::iterator
-CSimulationContext::CProcessorList::findByType(const key_type& _Keyval) {
+CSimulationContext::CProcessorList::findByType(const key_type& _Keyval)
+{
   // First find a ProcessorConstructor that matches the
   // processor type we are looking for. This should handle
   // naming variations.
   ProcessorConstructorList * pcl = ProcessorConstructorList::GetList();
   ProcessorConstructor * pc = pcl->findByType(_Keyval.c_str());
-  if(pc == NULL)
+
+  if (pc == nullptr) {
     return end();
+  }
+
   // Now find the specific allocated processor that
-  // was created with the ProcessorConstructor object 
+  // was created with the ProcessorConstructor object
   // we found above.
   iterator it;
   iterator itEnd = end();
-  for(it = begin(); it != itEnd; ++it) {
-    if(it->second->m_pConstructorObject == pc) {
+
+  for (it = begin(); it != itEnd; ++it) {
+    if (it->second->m_pConstructorObject == pc) {
       return it;
     }
   }
+
   return itEnd;
 }
