@@ -14,7 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
@@ -27,20 +27,20 @@ License along with this library; if not, see
 //
 #include "symbol.h"
 
-#include <iostream>
-#include <iomanip>
-#include <sstream>
-
-#include <string>
-#include <vector>
 #include <algorithm>
+#include <iostream>
+#include <string>
 
-#include "value.h"
+#include "gpsim_object.h"
 #include "modules.h"
+#include "value.h"
+
+#define STR_HELPER(x) #x
+#define STR(x) STR_HELPER(x)
 
 SymbolTable   gSymbolTable;
 SymbolTable_t globalSymbols;
-static SymbolTable_t *currentSymbolTable=0;
+static SymbolTable_t *currentSymbolTable;
 
 #define DEBUG 0
 
@@ -54,7 +54,7 @@ SymbolTable &globalSymbolTable()
 
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
-int SymbolTable_t::addSymbol(gpsimObject *pSym, string *ps_AliasedName)
+int SymbolTable_t::addSymbol(gpsimObject *pSym, std::string *ps_AliasedName)
 {
   if (pSym) {
     ps_AliasedName = (ps_AliasedName && !ps_AliasedName->empty()) ? ps_AliasedName : &pSym->name();
@@ -65,18 +65,17 @@ int SymbolTable_t::addSymbol(gpsimObject *pSym, string *ps_AliasedName)
     }
     else if (pSym != sti->second)
     {
-      
-	cout << "SymbolTable_t::addSymbol " << *ps_AliasedName << " exists " << pSym << " " << sti->second << "\n";
-	return 0;
-    }
 
+      std::cout << "SymbolTable_t::addSymbol " << *ps_AliasedName << " exists " << pSym << ' ' << sti->second << '\n';
+      return 0;
+    }
   }
   return 0;
 }
 
 
-static gpsimObject *pSearchObject=0;
-static gpsimObject *pFoundObject=0;
+static gpsimObject *pSearchObject;
+static gpsimObject *pFoundObject;
 static bool spred(const SymbolEntry_t &se)
 {
   pFoundObject = se.second == pSearchObject ? pSearchObject : 0;
@@ -89,29 +88,29 @@ int SymbolTable_t::removeSymbol(gpsimObject *pSym)
 
     pSearchObject = pSym;
     pFoundObject = 0;
-    SymbolTable_t::iterator it = find_if (begin(), end(), spred);
+    SymbolTable_t::iterator it = find_if(begin(), end(), spred);
     if (it != end()) {
 
       if (DEBUG) {
-        cout << __FUNCTION__ <<':' << __LINE__ << " removing symbol ";
+        std:: cout << __FUNCTION__ << ":" STR(__LINE__) " removing symbol ";
 
-        if (pSym) 
-          cout << pSym->name() << endl;
+        if (pSym)
+          std::cout << pSym->name() << '\n';
       }
-      erase (it);
+      erase(it);
       return 1;
     }
   }
   return 0;
 }
 
-int SymbolTable_t::removeSymbol(const string &s)
+int SymbolTable_t::removeSymbol(const std::string &s)
 {
   SymbolTable_t::iterator sti = find(s);
   if (sti != end()) {
 
     if (DEBUG)
-      cout << __FUNCTION__ <<':' << __LINE__ << " Removing symbol " << s << endl;
+      std::cout << __FUNCTION__ << ":"  STR(__LINE__) " Removing symbol " << s << '\n';
 
     erase(sti);
     return 1;
@@ -120,13 +119,13 @@ int SymbolTable_t::removeSymbol(const string &s)
   return 0;
 }
 
-int SymbolTable_t::deleteSymbol(const string &s)
+int SymbolTable_t::deleteSymbol(const std::string &s)
 {
   SymbolTable_t::iterator sti = find(s);
   if (sti != end()) {
 
     if (DEBUG)
-      cout << __FUNCTION__ <<':' << __LINE__ << "  Deleting symbol " << s << endl;
+      std::cout << __FUNCTION__ << ":" STR(__LINE__) "  Deleting symbol " << s << '\n';
 
     delete sti->second;
     erase(sti);
@@ -137,10 +136,10 @@ int SymbolTable_t::deleteSymbol(const string &s)
 }
 
 
-gpsimObject *SymbolTable_t::findSymbol(const string &searchString)
+gpsimObject *SymbolTable_t::findSymbol(const std::string &searchString)
 {
   stiFound = find(searchString);
-  return stiFound != end() ? stiFound->second : 0;
+  return stiFound != end() ? stiFound->second : nullptr;
 }
 
 //-------------------------------------------------------------------
@@ -149,30 +148,30 @@ gpsimObject *SymbolTable_t::findSymbol(const string &searchString)
 
 SymbolTable::SymbolTable()
 {
-  MSymbolTables[string("__global__")] = &globalSymbols;
+  MSymbolTables[std::string("__global__")] = &globalSymbols;
   currentSymbolTable = &globalSymbols;
 }
 
 
 static void dumpOneSymbol(const SymbolEntry_t &sym)
 {
-  cout << "  " //<< sym.second->name()  // name may not be valid.
-       << " stored as " << sym.first 
+  std::cout << "  " //<< sym.second->name()  // name may not be valid.
+       << " stored as " << sym.first
        << " pointer:" << sym.second
        << "  Type:" << sym.second->showType()
-       << endl;
+       << '\n';
 }
 
 static void dumpSymbolTables(const SymbolTableEntry_t &st)
 {
-  cout << " Symbol Table: " << st.first << endl;
+  std::cout << " Symbol Table: " << st.first << '\n';
   (st.second)->ForEachSymbolTable(dumpOneSymbol);
 }
 
 SymbolTable::~SymbolTable()
 {
   if (DEBUG) {
-    cout << "Deleting the symbol table, here's what is still left in it:\n";
+    std::cout << "Deleting the symbol table, here's what is still left in it:\n";
     ForEachModule(dumpSymbolTables);
   }
 }
@@ -190,7 +189,7 @@ int SymbolTable::removeSymbol(gpsimObject *pSym)
 {
   /*
   cout << __FUNCTION__ <<':' << __LINE__ << "  Removing symbol ";
-  if (pSym) 
+  if (pSym)
     cout << " -- " << pSym->name() << " from the global symbol table\n";
   */
   return globalSymbols.removeSymbol(pSym);
@@ -231,25 +230,25 @@ public:
     cout << "searching " << st.first << endl;
     SymbolTable_t::iterator sti = st.second->find(searchString);
     pFound = sti != st.second->end() ? sti->second : 0;
-    
+
     return pFound != 0;
   }
 };
 */
 
 
-static  SymbolTable_t *searchTable=0;
-static  string searchString;
-static  gpsimObject *pFound=0;
+static  SymbolTable_t *searchTable;
+static  std::string searchString;
+static  gpsimObject *pFound;
 
-bool tpred(const pair<const string, SymbolTable_t *> &st)
+bool tpred(const std::pair<const std::string, SymbolTable_t *> &st)
 {
   //cout << "searching " << st.first << endl;
   pFound = st.second->findSymbol(searchString);
   return pFound != 0;
 }
 
-gpsimObject *SymbolTable::find(string s)
+gpsimObject *SymbolTable::find(std::string s)
 {
   // First check scoping
   //
@@ -258,18 +257,18 @@ gpsimObject *SymbolTable::find(string s)
   //                  |
   //                  +---  scoping operator
   //
-  // If the search string contains the scoping operator (i.e. '.') 
+  // If the search string contains the scoping operator (i.e. '.')
   // then the symbol table specified by the scope. In other words,
   // if the search string begins with a period, then search the
   // current symbol table.
   // If the search string contains a period, then search for the
   // symbol table named with the string to the left of the period
-  // and if that table is found search in it for the string to 
+  // and if that table is found search in it for the string to
   // the right of the period.
 
   const char scopeOperator = '.';
   size_t scopeOperatorPosition = s.find_first_of(scopeOperator);
-  if (scopeOperatorPosition != string::npos) {
+  if (scopeOperatorPosition != std::string::npos) {
     searchTable = &globalSymbols;
     if (scopeOperatorPosition == 0) {   // Select the current symbol table
       searchTable = currentSymbolTable;
@@ -277,14 +276,14 @@ gpsimObject *SymbolTable::find(string s)
     }
     else {
       // Find the symbol table with the scoped name:
-      string moduleName = s.substr(0, scopeOperatorPosition); //,string::npos);
+      std::string moduleName = s.substr(0, scopeOperatorPosition); //,string::npos);
       MSymbolTable_t::iterator mti = MSymbolTables.find(moduleName);
       if (mti != MSymbolTables.end()) {
         searchTable = mti->second;
         scopeOperatorPosition++;
       }
     }
-    SymbolTable_t::iterator sti = searchTable->find(s.substr(scopeOperatorPosition,string::npos));
+    SymbolTable_t::iterator sti = searchTable->find(s.substr(scopeOperatorPosition, std::string::npos));
     if (sti != searchTable->end())
       return sti->second;
   }
@@ -294,13 +293,12 @@ gpsimObject *SymbolTable::find(string s)
   MSymbolTable_t::iterator mti = find_if (MSymbolTables.begin(), MSymbolTables.end(), tpred);
   if (mti != MSymbolTables.end())
     searchTable = mti->second;
-  
+
   return pFound;
 }
 
-int SymbolTable::removeSymbol(const string &s)
+int SymbolTable::removeSymbol(const std::string &s)
 {
-
   gpsimObject *pObj = find(s);
   if (pObj && searchTable) {
     if (searchTable->stiFound != searchTable->end()) {
@@ -314,7 +312,8 @@ int SymbolTable::removeSymbol(const string &s)
 
   return 0;
 }
-int SymbolTable::deleteSymbol(const string &s)
+
+int SymbolTable::deleteSymbol(const std::string &s)
 {
   gpsimObject *pObj = find(s);
   if (pObj && searchTable) {
@@ -339,29 +338,28 @@ int SymbolTable::deleteSymbol(const string &s)
   }
   */
   return 0;
-
 }
 
 
 //------------------------------------------------------------------------
 // Convenience find functions
-// All these do is call SymbolTable::find and cast the found symbol into 
+// All these do is call SymbolTable::find and cast the found symbol into
 // another type
 
 gpsimObject *SymbolTable::findObject(gpsimObject *pObj)
 {
-  return pObj ? find(pObj->name()) : 0;
+  return pObj ? find(pObj->name()) : nullptr;
 }
 
-Integer *SymbolTable::findInteger(string s)
+Integer *SymbolTable::findInteger(std::string s)
 {
   return dynamic_cast<Integer *>(find(s));
 }
-Value *SymbolTable::findValue(string s)
+Value *SymbolTable::findValue(std::string s)
 {
   return dynamic_cast<Value *>(find(s));
 }
-Module *SymbolTable::findModule(string s)
+Module *SymbolTable::findModule(std::string s)
 {
   return dynamic_cast<Module *>(find(s));
 }
@@ -369,7 +367,7 @@ Module *SymbolTable::findModule(string s)
 
 static void dumpModules(const SymbolTableEntry_t &st)
 {
-  cout << " Module: " << st.first << endl;
+  std::cout << " Module: " << st.first << '\n';
 }
 
 void SymbolTable::listModules()
@@ -377,10 +375,8 @@ void SymbolTable::listModules()
   ForEachModule(dumpModules);
 }
 
-
 void SymbolTable::ForEachModule(PFN_ForEachModule forEach)
 {
-  
   for_each(MSymbolTables.begin(), MSymbolTables.end(),  forEach);
 }
 
