@@ -1,22 +1,22 @@
 /*
    Copyright (C) 1998 T. Scott Dattalo
 
-This file is part of gpsim.
+This file is part of the libgpsim library of gpsim
 
-gpsim is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
 
-gpsim is distributed in the hope that it will be useful,
+This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Lesser General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with gpsim; see the file COPYING.  If not, write to
-the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, see
+<http://www.gnu.org/licenses/lgpl-2.1.html>.
+*/
 
 //
 // symbol.h
@@ -36,7 +36,7 @@ Boston, MA 02111-1307, USA.  */
 // global symbols. Each one of these maps can be accessed via the
 // Module or via the Module name. The global symbols belong to no
 // Module, however the map holding them is named '__global__'.
-// 
+//
 // In addition, there is another map for holding all of the
 // Modules. This map together with all of the Module symbol tables
 // form a two-level hierarchical symbol table.
@@ -45,16 +45,16 @@ Boston, MA 02111-1307, USA.  */
 // to by:
 //
 //      ModuleName.ModuleSymbolName
-// 
+//
 // For example, p16f873.foo refers to the symbol 'foo' in the p16f873
 // module.
 //
 // A notion of a 'current module' exists. This feature is not fully
 // implemented, but currently the most recently loaded Processor is
 // designated as the current module. Symbols in the current module can
-// be referenced with just the '.' scoping operator. For example, if 
+// be referenced with just the '.' scoping operator. For example, if
 // p16f873 is the current module, then typing '.foo' will display
-// p16f873.foo. 
+// p16f873.foo.
 //
 // The symbol table avoids interpreting or operating on the data it
 // stores. For example, only the object's name is ever
@@ -64,15 +64,15 @@ Boston, MA 02111-1307, USA.  */
 // through all of the symbols.
 
 
-#ifndef __SYMBOL_H__
-#define __SYMBOL_H__
+#ifndef SRC_SYMBOL_H_
+#define SRC_SYMBOL_H_
 
 #include <algorithm>
 #include <string>
 #include <map>
-#include "exports.h"
+#include <utility>
 
-using namespace std;
+#include "exports.h"
 
 // Forward definitions
 class gpsimObject;
@@ -82,31 +82,31 @@ class Module;
 class SymbolTable_t;
 class SymbolTable;
 
-typedef  map<const char *, Module *> ModuleList_t;
-typedef  map<const string, SymbolTable_t *> MSymbolTable_t;
-typedef void (*PFN_ForEachModule)(const pair<string, SymbolTable_t *> &st);
-typedef void (*PFN_ForEachSymbol)(const pair<string, gpsimObject *> &sym);
-typedef pair<string, SymbolTable_t *> SymbolTableEntry_t;
-typedef pair<string, gpsimObject *> SymbolEntry_t;
+typedef std::map<const char *, Module *> ModuleList_t;
+typedef std::map<const std::string, SymbolTable_t *> MSymbolTable_t;
+typedef void (*PFN_ForEachModule)(const std::pair<std::string, SymbolTable_t *> &st);
+typedef void (*PFN_ForEachSymbol)(const std::pair<std::string, gpsimObject *> &sym);
+typedef std::pair<std::string, SymbolTable_t *> SymbolTableEntry_t;
+typedef std::pair<std::string, gpsimObject *> SymbolEntry_t;
 
 //************************************************************************
 // SymbolTable_t
-// 
+//
 // A gpsim symbol table is an STL map of gpsimObject pointers that are keyed with
 // by the object's name.
 //
 
-class SymbolTable_t : protected map<string, gpsimObject *>
+class SymbolTable_t : protected std::map<std::string, gpsimObject *>
 {
   // The SymbolTable class has access to all map<>'s methods.
   friend class SymbolTable;
 public:
 
-  int addSymbol(gpsimObject *, string *AliasedName=0);
+  int addSymbol(gpsimObject *, std::string *AliasedName=0);
   int removeSymbol(gpsimObject *);
-  int removeSymbol(const string &);
-  int deleteSymbol(const string &);
-  gpsimObject *findSymbol(const string &);
+  int removeSymbol(const std::string &);
+  int deleteSymbol(const std::string &);
+  gpsimObject *findSymbol(const std::string &);
 
   /// ForEachModuleSymbolTable -- thin wrapper around map<>'s for_each() algorithm.
   /// The pointer to the function passed must be declared like:
@@ -136,8 +136,8 @@ public:
   /// Globally scoped symbols are added and removed here
   int addSymbol(gpsimObject *);
   int removeSymbol(gpsimObject *);
-  int removeSymbol(const string &);
-  int deleteSymbol(const string &);
+  int removeSymbol(const std::string &);
+  int deleteSymbol(const std::string &);
 
   /// Each Module maintains its own symbol table. If the module wants
   /// its symbols to be accessed at the global scope, then the module
@@ -148,16 +148,16 @@ public:
   void listModules(); // ugh
 
   /// find - search for a particular symbol
-  gpsimObject *find(string);
+  gpsimObject *find(std::string);
   gpsimObject *findObject(gpsimObject *);
 
   ///
   void ForEachModule(PFN_ForEachModule forEach);
 
   /// Convenience functions for finding a symbol of a particular type:
-  Value         *findValue(string);
-  Integer       *findInteger(string);
-  Module        *findModule(string);
+  Value         *findValue(std::string);
+  Integer       *findInteger(std::string);
+  Module        *findModule(std::string);
 protected:
   MSymbolTable_t MSymbolTables;
 };
@@ -165,7 +165,7 @@ protected:
 
 
 #if defined(_WIN32)
-#if !defined(IN_MODULE) 
+#if !defined(IN_MODULE)
 extern SymbolTable  gSymbolTable;
 #endif
 // we are in Windows: don't access the symbol table object directly!
