@@ -20,7 +20,6 @@ License along with this library; if not, see
 
 
 #include "trigger.h"
-#include "../config.h"
 #include "value.h"
 #include "expr.h"
 #include "errors.h"
@@ -28,16 +27,14 @@ License along with this library; if not, see
 #include "ui.h"
 #include "trace.h"
 #include <iostream>
-#include <iomanip>
+
+#include <stdio.h>
+#include <string.h>
 
 extern Integer *verbosity;  // in ../src/init.cc
 
-using namespace std;
-
 static TriggerAction DefaultTrigger;
 
-
-
 //------------------------------------------------------------------------
 //
 class BreakTraceType : public TraceType
@@ -53,13 +50,13 @@ public:
   virtual int dump_raw(Trace *,unsigned tbi, char *buf, int bufsize);
 };
 
-TraceType *TriggerObject::m_brt=0;
+TraceType *TriggerObject::m_brt;
 
 //------------------------------------------------------------------------
 class BreakTraceObject : public TraceObject
 {
 public:
-  BreakTraceObject(unsigned int bpn);
+  explicit BreakTraceObject(unsigned int bpn);
   virtual void print(FILE *);
 private:
   unsigned int m_bpn;
@@ -76,7 +73,7 @@ void BreakTraceObject::print(FILE *fp)
 {
   fprintf(fp, "  BREAK: #");
   Breakpoints::BreakStatus *bs = bp.get(m_bpn);
-  TriggerObject *bpo = bs ? bs->bpo : 0;
+  TriggerObject *bpo = bs ? bs->bpo : nullptr;
   if (bpo)
     bpo->print();
   else
@@ -88,19 +85,19 @@ void BreakTraceObject::print(FILE *fp)
 //------------------------------------------------------------------------
 TraceObject *BreakTraceType::decode(unsigned int tbi)
 {
-  TraceObject *to;
   if (get_trace().type(tbi) == type())
   {
-      to = new BreakTraceObject(get_trace().get(tbi) );
+      TraceObject *to = new BreakTraceObject(get_trace().get(tbi));
       to->print(stdout);
       return to;
   }
   else
-    return 0;
+    return nullptr;
 }
-int BreakTraceType::dump_raw(Trace *pTrace,unsigned tbi, char *buf, int bufsize)
+
+int BreakTraceType::dump_raw(Trace *pTrace, unsigned tbi, char *buf, int bufsize)
 {
-  int n = TraceType::dump_raw(pTrace, tbi,buf,bufsize);
+  int n = TraceType::dump_raw(pTrace, tbi, buf, bufsize);
 
   buf += n;
   bufsize -= n;
@@ -108,10 +105,10 @@ int BreakTraceType::dump_raw(Trace *pTrace,unsigned tbi, char *buf, int bufsize)
   unsigned int bpn = trace.get(tbi) & 0xffffff;
   Breakpoints::BreakStatus *bs = bp.get(bpn);
 
-  TriggerObject *bpo = bs ? bs->bpo : 0;
+  TriggerObject *bpo = bs ? bs->bpo : nullptr;
   int m = snprintf(buf, bufsize, "  BREAK: #%u %s",
 	       bpn, (bpo ? bpo->bpName() : ""));
-  m = m>0 ? m : 0;
+  m = m > 0 ? m : 0;
   buf += m;
   bufsize -= m;
 
@@ -142,13 +139,11 @@ bool TriggerAction::getTriggerState()
 
 void TriggerAction::action()
 {
-  if(verbosity && verbosity->getVal())
-    cout << "Hit a Breakpoint!\n";
+  if (verbosity && verbosity->getVal())
+    std::cout << "Hit a Breakpoint!\n";
   bp.halt();
 }
 
-
-
 //------------------------------------------------------------------------
 // SimpleTriggerAction
 //
@@ -162,21 +157,20 @@ SimpleTriggerAction::SimpleTriggerAction(TriggerObject *_to)
 void SimpleTriggerAction::action()
 {
   TriggerAction::action();
-  if(to && verbosity && verbosity->getVal())
+  if (to && verbosity && verbosity->getVal())
     to->print();
 }
 
-
-
-
 //------------------------------------------------------------------------
 TriggerObject::TriggerObject()
+  : bpn(0), CallBackID(0)
 {
   m_PExpr = 0;
   set_action(&DefaultTrigger);
 }
 
 TriggerObject::TriggerObject(TriggerAction *ta)
+  : bpn(0), CallBackID(0)
 {
   // If a trace type has not been allocated yet, then allocate:
   if (!m_brt) {
@@ -186,7 +180,7 @@ TriggerObject::TriggerObject(TriggerAction *ta)
 
   m_PExpr = 0;
 
-  if(ta)
+  if (ta)
     set_action(ta);
   else
     set_action(&DefaultTrigger);
@@ -203,17 +197,16 @@ TriggerObject::~TriggerObject()
 
   if (m_action != &DefaultTrigger)
     delete m_action;
-
 }
 
 void TriggerObject::callback()
 {
-  cout << "generic callback\n";
+  std::cout << "generic callback\n";
 }
 
 void TriggerObject::callback_print()
 {
-  cout << " has callback, ID =  0x" << CallBackID << '\n';
+  std::cout << " has callback, ID =  0x" << CallBackID << '\n';
 }
 
 void  TriggerObject::clear_trigger()
@@ -234,42 +227,37 @@ int TriggerObject::find_free()
   }
 
   return bpn;
-
 }
 
 void TriggerObject::print()
 {
   char buf[256];
-  buf[0]=0;
+  buf[0] = '\0';
   printExpression(buf, sizeof(buf));
   if (buf[0]) {
     GetUserInterface().DisplayMessage("    Expr:%s\n", buf);
-
   }
-  if (message().size())
+  if (!message().empty())
     GetUserInterface().DisplayMessage("    Message:%s\n", message().c_str());
-
 }
 
 int TriggerObject::printExpression(char *pBuf, int szBuf)
 {
   if (!m_PExpr || !pBuf)
     return 0;
-  *pBuf = 0;
-  m_PExpr->toString(pBuf,szBuf);
+  *pBuf = '\0';
+  m_PExpr->toString(pBuf, szBuf);
   return strlen(pBuf);
 }
 
-int TriggerObject::printTraced(Trace *pTrace, unsigned int tbi,
-			       char *pBuf, int szBuf)
-
+int TriggerObject::printTraced(Trace *, unsigned int, char *, int )
 {
   return 0;
 }
 
 void TriggerObject::clear()
 {
-  cout << "clear Generic breakpoint " << bpn << endl;
+  std::cout << "clear Generic breakpoint " << bpn << '\n';
 }
 
 void TriggerObject::set_Expression(Expression *newExpression)
@@ -280,21 +268,19 @@ void TriggerObject::set_Expression(Expression *newExpression)
 
 bool TriggerObject::eval_Expression()
 {
-  if(m_PExpr) {
+  if (m_PExpr) {
     bool bRet = true;
 
     try {
       Value *v = m_PExpr->evaluate();
 
-      if(v) {
+      if (v) {
         v->get(bRet);
-	delete v;
+        delete v;
       }
     }
-    catch (Error *Perr) {
-      if(Perr)
-        cout << "ERROR:" << Perr->toString() << endl;
-      delete Perr;
+    catch (Error &Perr) {
+      std::cout << "ERROR:" << Perr.what() << '\n';
     }
 
     return bRet;
@@ -302,6 +288,7 @@ bool TriggerObject::eval_Expression()
 
   return true;
 }
+
 //------------------------------------------------------------------------
 void TriggerObject::invokeAction()
 {
@@ -312,11 +299,11 @@ void TriggerObject::invokeAction()
 //-------------------------------------------------------------------
 void TriggerObject::new_message(const char *s)
 {
-  m_sMessage = string(s);
+  m_sMessage = s;
 }
 
 
-void TriggerObject::new_message(string &new_message)
+void TriggerObject::new_message(std::string &new_message)
 {
   m_sMessage = new_message;
 }
