@@ -18,37 +18,40 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
+#include "value.h"
 
+#include <ctype.h>
 #include <stdio.h>
 #include <iostream>
-#include <iomanip>
-#include <cstdio>
-
-#include "processor.h"
-
-#include "value.h"
-#include "errors.h"
-#include "operator.h"
-
-#include "protocol.h"
-#include "../config.h"
-#include "cmd_gpsim.h"
-
+#include <string>
 #include <typeinfo>
 
-char * TrimWhiteSpaceFromString(char * pBuffer) {
+#include "../config.h"
+#include "breakpoints.h"
+#include "errors.h"
+#include "expr.h"
+#include "modules.h"
+#include "operator.h"
+#include "processor.h"
+#include "protocol.h"
+#include "ui.h"
+#include "xref.h"
+class Register;
+
+char * TrimWhiteSpaceFromString(char * pBuffer)
+{
   size_t iPos = 0;
   char * pChar = pBuffer;
-  while(*pChar != 0 && ::isspace(*pChar)) {
+  while (*pChar != 0 && ::isspace(*pChar)) {
     pChar++;
   }
-  if(pBuffer != pChar) {
+  if (pBuffer != pChar) {
     memmove(pBuffer, pChar, strlen(pBuffer) - iPos);
   }
   iPos = strlen(pBuffer);
-  if(iPos > 0) {
+  if (iPos > 0) {
     pChar = pBuffer + iPos - 1;
-    while(pBuffer != pChar && ::isspace(*pChar)) {
+    while (pBuffer != pChar && ::isspace(*pChar)) {
       *pChar = 0;
       pChar--;
     }
@@ -56,20 +59,21 @@ char * TrimWhiteSpaceFromString(char * pBuffer) {
   return pBuffer;
 }
 
-char * UnquoteString(char * pBuffer) {
+char * UnquoteString(char * pBuffer)
+{
   char cQuote;
-  if(*pBuffer == '\'') {
+  if (*pBuffer == '\'') {
     cQuote = '\'';
   }
-  else if(*pBuffer == '"') {
+  else if (*pBuffer == '"') {
     cQuote = '"';
   }
   else {
     return pBuffer;
   }
   int iLen = strlen(pBuffer);
-  if(iLen > 1) {
-    if(pBuffer[iLen - 1] == cQuote) {
+  if (iLen > 1) {
+    if (pBuffer[iLen - 1] == cQuote) {
       memmove(&pBuffer[0], &pBuffer[1], iLen - 2);
       pBuffer[iLen - 2] = 0;
     }
@@ -77,11 +81,13 @@ char * UnquoteString(char * pBuffer) {
   return pBuffer;
 }
 
-string &toupper(string & sStr) {
-  string::iterator it;
-  string::iterator itEnd = sStr.end();
-  for(it = sStr.begin(); it != itEnd; ++it) {
-    if(isalpha(*it)) {
+std::string &toupper(std::string & sStr)
+{
+  std::string::iterator it = sStr.begin();
+  std::string::iterator itEnd = sStr.end();
+
+  for ( ; it != itEnd; ++it) {
+    if (isalpha(*it)) {
       *it = toupper((int)*it);
     }
   }
@@ -90,12 +96,12 @@ string &toupper(string & sStr) {
 
 //------------------------------------------------------------------------
 Value::Value()
-  : _xref(0), cpu(0), m_aka(0)
+  : _xref(nullptr), cpu(nullptr)
 {
 }
 
 Value::Value(const char *_name, const char *desc, Module *pMod)
-  : gpsimObject(_name,desc), _xref(0), cpu(pMod),m_aka(0)
+  : gpsimObject(_name, desc), _xref(nullptr), cpu(pMod)
 {
 }
 
@@ -103,32 +109,17 @@ Value::~Value()
 {
   // Remove references of this Value from the symbol table:
   if (cpu) {
-
     //cout << "Deleting value named:" << name_str <<  " addr "<< this << endl;
     cpu->removeSymbol(name_str);
 
-    if (m_aka) {
-      //cout << "m_aka ==" << m_aka << endl;
-
-      list <string>::iterator it;
-      it = m_aka->begin();
-      while(it != m_aka->end()) {
-        string s(*it);
-        //cout << " Value label " << s << endl;
-        cpu->removeSymbol(s);
-        ++it;
-      }
-      m_aka->clear();
-      delete m_aka;
+    //cout << "m_aka ==" << m_aka << endl;
+    for (const auto &it : m_aka) {
+      cpu->removeSymbol(it);
     }
-    if(_xref)
-    {
-	delete _xref;
-	_xref = 0;
-    }
-
   }
+  delete _xref;
 }
+
 void Value::update()
 {
   if (_xref)
@@ -147,21 +138,24 @@ void Value::remove_xref(void *an_xref)
   _xref->clear(an_xref);
 }
 
-void Value::set(const char *cP,int i)
+void Value::set(const char *, int )
 {
-  throw new Error(" cannot assign string to a " + showType());
+  throw Error(" cannot assign string to a " + showType());
 }
-void Value::set(double d)
+
+void Value::set(double)
 {
-  throw new Error(" cannot assign a double to a " + showType());
+  throw Error(" cannot assign a double to a " + showType());
 }
-void Value::set(gint64 i)
+
+void Value::set(gint64)
 {
-  throw new Error(" cannot assign an integer to a " + showType());
+  throw Error(" cannot assign an integer to a " + showType());
 }
-void Value::set(bool v)
+
+void Value::set(bool)
 {
-  throw new Error(" cannot assign a boolean to a " + showType());
+  throw Error(" cannot assign a boolean to a " + showType());
 }
 
 void Value::set(int i)
@@ -170,46 +164,41 @@ void Value::set(int i)
   set(i64);
 }
 
-void Value::set(Value *v)
+void Value::set(Value *)
 {
-  throw new Error(" cannot assign a Value to a " + showType());
+  throw Error(" cannot assign a Value to a " + showType());
 }
 
 void Value::set(Expression *expr)
 {
   try {
-    Value *v=0;
+    Value *v = nullptr;
 
-    if(!expr)
-      throw new Error(" null expression ");
+    if (!expr)
+      throw Error(" null expression ");
     if (verbose)
-      cout << toString() << " is being assigned expression " << expr->toString() << endl;
+      std::cout << toString() << " is being assigned expression " << expr->toString() << '\n';
     v = expr->evaluate();
-    if(!v)
-      throw new Error(" cannot evaluate expression ");
+    if (!v)
+      throw Error(" cannot evaluate expression ");
 
     set(v);
     delete v;
   }
 
-
-  catch (Error *err) {
-    if(err)
-      cout << "ERROR:" << err->toString() << endl;
-    delete err;
+  catch (Error &err) {
+    std::cout << "ERROR:" << err.what() << '\n';
   }
-
 }
 
-void Value::set(Packet &pb)
+void Value::set(Packet &)
 {
-  cout << "Value,"<<name()<<" is ignoring packet buffer for set()\n";
+  std::cout << "Value," << name() << " is ignoring packet buffer for set()\n";
 }
 
-void Value::get(gint64 &i)
+void Value::get(gint64 &)
 {
-  throw new Error(showType() +
-                  " cannot be converted to an integer ");
+  throw Error(showType() + " cannot be converted to an integer ");
 }
 
 void Value::get(int &i)
@@ -227,16 +216,14 @@ void Value::get(guint64 &i)
   i = (gint64) i64;
 }
 
-void Value::get(bool &b)
+void Value::get(bool &)
 {
-  throw new Error(showType() +
-                  " cannot be converted to a boolean");
+  throw Error(showType() + " cannot be converted to a boolean");
 }
 
-void Value::get(double &d)
+void Value::get(double &)
 {
-  throw new Error(showType() +
-                  " cannot be converted to a double ");
+  throw Error(showType() + " cannot be converted to a double ");
 }
 
 // get as a string - no error is thrown if the derived class
@@ -245,25 +232,25 @@ void Value::get(double &d)
 
 void Value::get(char *buffer, int buf_size)
 {
-  if(buffer)
-    strncpy(buffer,"INVALID",buf_size);
+  if (buffer && buf_size > 0) {
+    snprintf(buffer, buf_size, "INVALID");
+  }
 }
 
-void Value::get(Packet &pb)
+void Value::get(Packet &)
 {
-  cout << "Value,"<<name()<<" is ignoring packet buffer for get()\n";
+  std::cout << "Value," << name() << " is ignoring packet buffer for get()\n";
 }
 
-bool Value::compare(ComparisonOperator *compOp, Value *rvalue)
+bool Value::compare(ComparisonOperator *compOp, Value *)
 {
-  throw new Error(compOp->showOp() +
+  throw Error(compOp->showOp() +
                   " comparison is not defined for " + showType());
 }
 
 Value *Value::copy()
 {
-  throw new Error(" cannot copy " + showType());
-
+  throw Error(" cannot copy " + showType());
 }
 
 /*
@@ -287,22 +274,20 @@ void Value::set_cpu(Processor *new_cpu)
 {
   cpu = new_cpu;
 }
+
 void Value::set_module(Module *new_cpu)
 {
   cpu = new_cpu;
 }
+
 Module *Value::get_module()
 {
   return cpu;
 }
 
-void Value::addName(string &r_sAliasedName)
+void Value::addName(std::string &r_sAliasedName)
 {
-  if (!m_aka)
-    m_aka = new list<string>();
-
-  //cout << "Adding name " << r_sAliasedName << " to "<< name() << endl;
-  m_aka->push_back(r_sAliasedName);
+  m_aka.push_back(r_sAliasedName);
 }
 
 //------------------------------------------------------------------------
@@ -310,85 +295,106 @@ ValueWrapper::ValueWrapper(Value *pCopy)
   : m_pVal(pCopy)
 {
 }
+
 ValueWrapper::~ValueWrapper()
 {
 }
+
 unsigned int ValueWrapper::get_leftVal()
 {
   return m_pVal->get_leftVal();
 }
+
 unsigned int ValueWrapper::get_rightVal()
 {
   return m_pVal->get_rightVal();
 }
-void ValueWrapper::set(const char *cP,int len)
+
+void ValueWrapper::set(const char *cP, int len)
 {
   m_pVal->set(cP,len);
 }
+
 void ValueWrapper::set(double d)
 {
   m_pVal->set(d);
 }
+
 void ValueWrapper::set(gint64 i)
 {
   m_pVal->set(i);
 }
+
 void ValueWrapper::set(int i)
 {
   m_pVal->set(i);
 }
+
 void ValueWrapper::set(bool b)
 {
   m_pVal->set(b);
 }
+
 void ValueWrapper::set(Value *v)
 {
   m_pVal->set(v);
 }
+
 void ValueWrapper::set(Expression *e)
 {
   m_pVal->set(e);
 }
+
 void ValueWrapper::set(Packet &p)
 {
   m_pVal->set(p);
 }
+
 void ValueWrapper::get(bool &b)
 {
   m_pVal->get(b);
 }
+
 void ValueWrapper::get(int &i)
 {
   m_pVal->get(i);
 }
+
 void ValueWrapper::get(guint64 &i)
 {
   m_pVal->get(i);
 }
+
 void ValueWrapper::get(gint64 &i)
 {
   m_pVal->get(i);
 }
+
 void ValueWrapper::get(double &d)
 {
   m_pVal->get(d);
 }
+
 void ValueWrapper::get(char *pC, int len)
 {
-  m_pVal->get(pC,len);
+  m_pVal->get(pC, len);
 }
+
 void ValueWrapper::get(Packet &p)
 {
   m_pVal->get(p);
 }
+
 Value *ValueWrapper::copy()
 {
   return m_pVal->copy();
 }
+
 void ValueWrapper::update()
 {
   m_pVal->update();
 }
+
 Value *ValueWrapper::evaluate()
 {
   return m_pVal->evaluate();
@@ -396,7 +402,7 @@ Value *ValueWrapper::evaluate()
 
 bool ValueWrapper::compare(ComparisonOperator *compOp, Value *rvalue)
 {
-  if(!compOp || !rvalue)
+  if (!compOp || !rvalue)
     return false;
 
   gint64 i,r;
@@ -404,10 +410,10 @@ bool ValueWrapper::compare(ComparisonOperator *compOp, Value *rvalue)
   m_pVal->get(i);
   rvalue->get(r);
 
-  if(i < r)
+  if (i < r)
     return compOp->less();
 
-  if(i > r)
+  if (i > r)
     return compOp->greater();
 
   return compOp->equal();
@@ -417,38 +423,34 @@ bool ValueWrapper::compare(ComparisonOperator *compOp, Value *rvalue)
  * The AbstractRange class.
  */
 AbstractRange::AbstractRange(unsigned int newLeft, unsigned int newRight)
+  : left(newLeft), right(newRight)
 {
-  left = newLeft;
-  right = newRight;
 }
 
-
 AbstractRange::~AbstractRange()
 {
 }
 
-
-string AbstractRange::toString()
+std::string AbstractRange::toString()
 {
   char buff[256];
 
   snprintf(buff, sizeof(buff), "%u:%u", left, right);
 
-  return (string(buff));
+  return buff;
 }
 
-string AbstractRange::toString(const char* format)
+std::string AbstractRange::toString(const char* format)
 {
   char cvtBuf[1024];
 
   snprintf(cvtBuf, sizeof(cvtBuf), format, left, right);
-  return (string(&cvtBuf[0]));
+  return cvtBuf;
 }
 
 char *AbstractRange::toString(char *return_str, int len)
 {
-  if(return_str) {
-
+  if (return_str) {
     snprintf(return_str, len, "%u:%u", left, right);
   }
 
@@ -457,36 +459,37 @@ char *AbstractRange::toString(char *return_str, int len)
 
 unsigned int AbstractRange::get_leftVal()
 {
-  return(left);
+  return left;
 }
 
 unsigned int AbstractRange::get_rightVal()
 {
-  return(right);
+  return right;
 }
 
-AbstractRange* AbstractRange::typeCheck(Value* val, string valDesc)
+AbstractRange* AbstractRange::typeCheck(Value* val, std::string valDesc)
 {
   if (typeid(*val) != typeid(AbstractRange)) {
-    throw new TypeMismatch(valDesc, "AbstractRange", val->showType());
+    throw TypeMismatch(valDesc, "AbstractRange", val->showType());
   }
   // This static cast is totally safe in light of our typecheck, above.
-  return((AbstractRange*)(val));
+  return static_cast<AbstractRange *>(val);
 }
-bool AbstractRange::compare(ComparisonOperator *compOp, Value *rvalue)
+
+bool AbstractRange::compare(ComparisonOperator *compOp, Value *)
 {
-  throw new Error(compOp->showOp() +
+  throw Error(compOp->showOp() +
                   " comparison is not defined for " + showType());
 }
 
 Value *AbstractRange::copy()
 {
-  return new AbstractRange(get_leftVal(),get_rightVal());
+  return new AbstractRange(get_leftVal(), get_rightVal());
 }
 
 void AbstractRange::set(Value *v)
 {
-  AbstractRange *ar=typeCheck(v, string(""));
+  AbstractRange *ar = typeCheck(v, "");
   left = ar->get_leftVal();
   right = ar->get_rightVal();
 }
@@ -503,100 +506,100 @@ bool AbstractRange::operator<(Value *rv)
  * The Boolean class.
  */
 Boolean::Boolean(bool newValue)
+  : value(newValue)
 {
-  value = newValue;
 }
 
-Boolean::Boolean(const char *_name, bool newValue,const char *_desc)
-  : Value(_name,_desc)
+Boolean::Boolean(const char *_name, bool newValue, const char *_desc)
+  : Value(_name, _desc), value(newValue)
 {
-  value = newValue;
-
 }
 
-bool Boolean::Parse(const char *pValue, bool &bValue) {
-  if(strncmp("true", pValue, sizeof("true")-1) == 0) {
+bool Boolean::Parse(const char *pValue, bool &bValue)
+{
+  if (strncmp("true", pValue, sizeof("true") - 1) == 0) {
     bValue = true;
     return true;
   }
-  else if(strncmp("false", pValue, sizeof("false")-1) == 0) {
-        bValue = false;
+  else if (strncmp("false", pValue, sizeof("false") - 1) == 0) {
+    bValue = false;
     return true;
   }
   return false;
 }
 
-Boolean * Boolean::NewObject(const char *_name, const char *pValue, const char *desc) {
+Boolean * Boolean::NewObject(const char *_name, const char *pValue, const char *)
+{
   bool bValue;
-  if(Parse(pValue, bValue)) {
+  if (Parse(pValue, bValue)) {
     return new Boolean(_name, bValue);
   }
-  return NULL;
+  return nullptr;
 }
 
 Boolean::~Boolean()
 {
 }
 
-string Boolean::toString()
+std::string Boolean::toString()
 {
   bool b;
   get(b);
-  return (string(b ? "true" : "false"));
+  return b ? "true" : "false";
 }
 
-string Boolean::toString(bool value)
+std::string Boolean::toString(bool value)
 {
-  return (string(value ? "true" : "false"));
+  return value ? "true" : "false";
 }
 
 char *Boolean::toString(char *return_str, int len)
 {
-  if(return_str) {
+  if (return_str) {
     bool b;
     get(b);
-    snprintf(return_str,len,"%s",(b ? "true" : "false"));
+    snprintf(return_str, len, "%s", (b ? "true" : "false"));
   }
 
   return return_str;
 }
+
 char *Boolean::toBitStr(char *return_str, int len)
 {
-  if(return_str) {
+  if (return_str) {
     bool b;
     get(b);
-    snprintf(return_str,len,"%d",(b ? 1 : 0));
+    snprintf(return_str, len, "%d", (b ? 1 : 0));
   }
 
   return return_str;
 }
 
-string Boolean::toString(const char* format)
+std::string Boolean::toString(const char* format)
 {
   char cvtBuf[1024];
   bool b;
   get(b);
 
-  sprintf(cvtBuf, format, b);
-  return (string(&cvtBuf[0]));
+  snprintf(cvtBuf, sizeof(cvtBuf), format, b);
+  return cvtBuf;
 }
 
-Boolean* Boolean::typeCheck(Value* val, string valDesc)
+Boolean* Boolean::typeCheck(Value* val, std::string valDesc)
 {
   if (typeid(*val) != typeid(Boolean)) {
-    throw new TypeMismatch(valDesc, "Boolean", val->showType());
+    throw TypeMismatch(valDesc, "Boolean", val->showType());
   }
 
   // This static cast is totally safe in light of our typecheck, above.
-  return((Boolean*)(val));
+  return static_cast<Boolean *>(val);
 }
 
 bool Boolean::compare(ComparisonOperator *compOp, Value *rvalue)
 {
+  Boolean *rv = typeCheck(rvalue, "");
 
-  Boolean *rv = typeCheck(rvalue,"");
-
-  switch(compOp->isa()) {
+  switch (compOp->isa()) {
   case ComparisonOperator::eOpEq:
     return value == rv->value;
   case ComparisonOperator::eOpNe:
@@ -608,7 +611,6 @@ bool Boolean::compare(ComparisonOperator *compOp, Value *rvalue)
   return false; // keep the compiler happy.
 }
 
-
 Value *Boolean::copy()
 {
   bool b;
@@ -632,6 +634,7 @@ void Boolean::get(int &i)
   get(b);
   i = b ? 1 : 0;
 }
+
 /*
 void Boolean::get(double &d)
 {
@@ -642,17 +645,13 @@ void Boolean::get(double &d)
 */
 void Boolean::get(char *buffer, int buf_size)
 {
-  if(buffer) {
-
+  if (buffer) {
     bool b;
     get(b);
-    if(b)
-      strncpy(buffer,"true",buf_size);
-    else
-      strncpy(buffer,"false",buf_size);
+    snprintf(buffer, buf_size, (b ? "true" : "false"));
   }
-
 }
+
 void Boolean::get(Packet &pb)
 {
   bool b;
@@ -662,7 +661,7 @@ void Boolean::get(Packet &pb)
 
 void Boolean::set(Value *v)
 {
-  Boolean *bv = typeCheck(v,string("set "));
+  Boolean *bv = typeCheck(v, "set ");
   bool b = bv->getVal();
   set(b);
 }
@@ -674,11 +673,11 @@ void Boolean::set(bool v)
   //  get_xref()->set(v);
 }
 
-void Boolean::set(const char *buffer, int buf_size)
+void Boolean::set(const char *buffer, int )
 {
-  if(buffer) {
+  if (buffer) {
     bool bValue;
-    if(Parse(buffer, bValue)) {
+    if (Parse(buffer, bValue)) {
       set(bValue);
     }
   }
@@ -687,7 +686,7 @@ void Boolean::set(const char *buffer, int buf_size)
 void Boolean::set(Packet &p)
 {
   bool b;
-  if(p.DecodeBool(b))
+  if (p.DecodeBool(b))
     set(b);
 }
 
@@ -720,23 +719,21 @@ bool Boolean::operator!=(Value *rv)
 /*****************************************************************
  * The Integer class.
  */
-Integer::Integer(const Integer &new_value) {
+Integer::Integer(const Integer &new_value)
+{
   Integer & nv = (Integer&)new_value;
   nv.get(value);
   bitmask = new_value.bitmask;
 }
 
 Integer::Integer(gint64 newValue)
+  : value(newValue), bitmask(def_bitmask)
 {
-  value = newValue;
-  bitmask = def_bitmask;
 }
 
-Integer::Integer(const char *_name, gint64 newValue,const char *_desc)
-  : Value(_name,_desc)
+Integer::Integer(const char *_name, gint64 newValue, const char *_desc)
+  : Value(_name, _desc), value(newValue), bitmask(def_bitmask)
 {
-  value = newValue;
-  bitmask = def_bitmask;
 }
 
 gint64 Integer::def_bitmask = 0xffffffff;
@@ -745,7 +742,8 @@ Integer::~Integer()
 {
 }
 
-void Integer::setDefaultBitmask(gint64 bitmask) {
+void Integer::setDefaultBitmask(gint64 bitmask)
+{
   def_bitmask = bitmask;
 }
 
@@ -768,11 +766,13 @@ void Integer::set(gint64 i)
   //if(get_xref())
   //  get_xref()->set(i);
 }
+
 void Integer::set(int i)
 {
   gint64 ii = i;
   set(ii);
 }
+
 void Integer::set(Value *v)
 {
   gint64 iv = 0;
@@ -785,58 +785,59 @@ void Integer::set(Value *v)
 void Integer::set(Packet &p)
 {
   unsigned int i;
-  if(p.DecodeUInt32(i)) {
+  if (p.DecodeUInt32(i)) {
 
     set((int)i);
     return;
   }
 
   guint64 i64;
-  if(p.DecodeUInt64(i64)) {
+  if (p.DecodeUInt64(i64)) {
 
     set((gint64)i64);
     return;
   }
 }
 
-void Integer::set(const char *buffer, int buf_size)
+void Integer::set(const char *buffer, int )
 {
-  if(buffer) {
+  if (buffer) {
     gint64 i;
-    if(Parse(buffer, i)) {
+    if (Parse(buffer, i)) {
       set(i);
     }
   }
 }
 
-bool Integer::Parse(const char *pValue, gint64 &iValue) {
-    if(::isdigit(*pValue)) {
-      if(strchr(pValue, '.')) {
-        return false;
-      }
-      else {
-        // decimal or 0x integer
-        return sscanf(pValue, "%" PRINTF_GINT64_MODIFIER "i", &iValue) == 1;
-      }
+bool Integer::Parse(const char *pValue, gint64 &iValue)
+{
+  if (::isdigit(*pValue)) {
+    if (strchr(pValue, '.')) {
+      return false;
     }
-    else if(*pValue == '$' && ::isxdigit(*(pValue+1))) {
-      // hexidecimal integer
-      char szHex[10] = "0x";
-      strcat(&szHex[0], pValue + 1);
-      return sscanf(szHex, "%"  PRINTF_GINT64_MODIFIER "i" , &iValue) == 1;
+    else {
+      // decimal or 0x integer
+      return sscanf(pValue, "%" PRINTF_GINT64_MODIFIER "i", &iValue) == 1;
     }
-    return false;
+  }
+  else if (*pValue == '$' && ::isxdigit(*(pValue + 1))) {
+    // hexidecimal integer
+    char szHex[10] = "0x";
+    strcat(szHex, pValue + 1);
+    return sscanf(szHex, "%"  PRINTF_GINT64_MODIFIER "i" , &iValue) == 1;
+  }
+  return false;
 }
 
-Integer * Integer::NewObject(const char *_name, const char *pValue, const char *desc) {
+Integer * Integer::NewObject(const char *_name, const char *pValue, const char *desc)
+{
   gint64 iValue;
-  if(Parse(pValue, iValue)) {
+  if (Parse(pValue, iValue)) {
     return new Integer(_name, iValue, desc);
   }
-  return NULL;
+  return nullptr;
 }
 
-
 void Integer::get(gint64 &i)
 {
   i = value;
@@ -851,21 +852,21 @@ void Integer::get(double &d)
 
 void Integer::get(char *buffer, int buf_size)
 {
-  if(buffer) {
+  if (buffer) {
 
     gint64 i;
     get(i);
     long long int j = i;
-    snprintf(buffer,buf_size,"%" PRINTF_INT64_MODIFIER "d",j);
+    snprintf(buffer, buf_size, "%" PRINTF_INT64_MODIFIER "d", j);
   }
-
 }
+
 void Integer::get(Packet &pb)
 {
   gint64 i;
   get(i);
 
-  unsigned int j = (unsigned int) (i &0xffffffff);
+  unsigned int j = (unsigned int) (i & 0xffffffff);
   pb.EncodeUInt32(j);
 }
 
@@ -892,46 +893,44 @@ int Integer::set_break(ObjectBreakTypes bt, ObjectActionTypes at, Expression *ex
   return -1;
 }
 
-string Integer::toString()
+std::string Integer::toString()
 {
   gint64 i;
   get(i);
   IUserInterface & TheUI = GetUserInterface();
-  return string(TheUI.FormatValue(i, (unsigned int)bitmask));
+  return std::string(TheUI.FormatValue(i, (unsigned int)bitmask));
 }
 
-
-string Integer::toString(const char* format)
+std::string Integer::toString(const char* format)
 {
   char cvtBuf[1024];
 
   gint64 i;
   get(i);
 
-  snprintf(cvtBuf,sizeof(cvtBuf), format, i);
-  return (string(&cvtBuf[0]));
+  snprintf(cvtBuf, sizeof(cvtBuf), format, i);
+  return cvtBuf;
 }
 
-
-string Integer::toString(const char* format, gint64 value)
+std::string Integer::toString(const char* format, gint64 value)
 {
   char cvtBuf[1024];
 
-  snprintf(cvtBuf,sizeof(cvtBuf), format, value);
-  return (string(&cvtBuf[0]));
+  snprintf(cvtBuf, sizeof(cvtBuf), format, value);
+  return cvtBuf;
 }
 
-string Integer::toString(gint64 value)
+std::string Integer::toString(gint64 value)
 {
   char cvtBuf[1024];
-  long long int v=value;
-  snprintf(cvtBuf,sizeof(cvtBuf), "%" PRINTF_INT64_MODIFIER "d", v);
-  return (string(&cvtBuf[0]));
+  long long int v = value;
+  snprintf(cvtBuf, sizeof(cvtBuf), "%" PRINTF_INT64_MODIFIER "d", v);
+  return cvtBuf;
 }
 
 char *Integer::toString(char *return_str, int len)
 {
-  if(return_str) {
+  if (return_str) {
     gint64 i;
     get(i);
     IUserInterface & TheUI = GetUserInterface();
@@ -941,35 +940,36 @@ char *Integer::toString(char *return_str, int len)
 
   return return_str;
 }
+
 char *Integer::toBitStr(char *return_str, int len)
 {
-  if(return_str) {
+  if (return_str) {
     gint64 i;
     get(i);
-    int j=0;
-    int mask=1<<31;
-    for( ; mask ; mask>>=1, j++)
-      if(j<len)
-        return_str[j] = ( (i & mask) ? 1 : 0);
+    int j = 0;
+    int mask = 1 << 31;
+    for ( ; mask ; mask >>= 1, j++)
+      if (j < len)
+        return_str[j] = ((i & mask) ? 1 : 0);
 
-    if(j<len)
-      return_str[j]=0;
+    if (j < len)
+      return_str[j] = 0;
   }
 
   return return_str;
 }
 
-Integer* Integer::typeCheck(Value* val, string valDesc)
+Integer* Integer::typeCheck(Value* val, std::string valDesc)
 {
   if (typeid(*val) != typeid(Integer)) {
-    throw new TypeMismatch(valDesc, "Integer", val->showType());
+    throw TypeMismatch(valDesc, "Integer", val->showType());
   }
 
   // This static cast is totally safe in light of our typecheck, above.
-  return((Integer*)(val));
+  return static_cast<Integer *>(val);
 }
 
-Integer* Integer::assertValid(Value* val, string valDesc, gint64 valMin)
+Integer* Integer::assertValid(Value* val, std::string valDesc, gint64 valMin)
 {
   Integer* iVal;
   gint64 i;
@@ -978,7 +978,7 @@ Integer* Integer::assertValid(Value* val, string valDesc, gint64 valMin)
   iVal->get(i);
 
   if (i < valMin) {
-    throw new Error(valDesc +
+    throw Error(valDesc +
                     " must be greater than " + Integer::toString(valMin) +
                     ", saw " + Integer::toString(i)
                     );
@@ -987,7 +987,7 @@ Integer* Integer::assertValid(Value* val, string valDesc, gint64 valMin)
   return(iVal);
 }
 
-Integer* Integer::assertValid(Value* val, string valDesc, gint64 valMin, gint64 valMax)
+Integer* Integer::assertValid(Value* val, std::string valDesc, gint64 valMin, gint64 valMax)
 {
   Integer* iVal;
   gint64 i;
@@ -997,29 +997,28 @@ Integer* Integer::assertValid(Value* val, string valDesc, gint64 valMin, gint64
   iVal->get(i);
 
   if ((i < valMin) || (i>valMax)) {
-    throw new Error(valDesc +
+    throw Error(valDesc +
                     " must be be in the range [" + Integer::toString(valMin) + ".." +
                     Integer::toString(valMax) + "], saw " + Integer::toString(i)
                     );
   }
 
-  return(iVal);
+  return iVal;
 }
 
 bool Integer::compare(ComparisonOperator *compOp, Value *rvalue)
 {
-
   Integer *rv = typeCheck(rvalue,"");
 
-  gint64 i,r;
+  gint64 i, r;
 
   get(i);
   rv->get(r);
 
-  if(i < r)
+  if (i < r)
     return compOp->less();
 
-  if(i > r)
+  if (i > r)
     return compOp->greater();
 
   return compOp->equal();
@@ -1055,27 +1054,27 @@ bool Integer::operator>(Value *rv)
  * The Float class.
  */
 Float::Float(double newValue)
+  : value(newValue)
 {
-  value = newValue;
 }
 
-Float::Float(const char *_name, double newValue,const char *_desc)
-  : Value(_name,_desc)
+Float::Float(const char *_name, double newValue, const char *_desc)
+  : Value(_name, _desc), value(newValue)
 {
-  value = newValue;
 }
 
 bool Float::Parse(const char *pValue, double &fValue)
 {
-  return pValue ? sscanf(pValue,"%lg",&fValue) == 1 : false;
+  return pValue ? sscanf(pValue, "%lg", &fValue) == 1 : false;
 }
 
-Float * Float::NewObject(const char *_name, const char *pValue, const char *desc) {
+Float * Float::NewObject(const char *_name, const char *pValue, const char *)
+{
   double fValue;
-  if(Parse(pValue, fValue)) {
+  if (Parse(pValue, fValue)) {
     return new Float(_name, fValue);
   }
-  return NULL;
+  return nullptr;
 }
 
 Float::~Float()
@@ -1107,18 +1106,17 @@ void Float::set(Value *v)
   if (typeid(*v) != typeid(Float) &&
       typeid(*v) != typeid(Integer))
   {
-    throw new TypeMismatch(string("set "), "Float", v->showType());
+    throw TypeMismatch("set ", "Float", v->showType());
   }
-   v->get(d);
-   set(d);
+  v->get(d);
+  set(d);
 }
 
-void Float::set(const char *buffer, int buf_size)
+void Float::set(const char *buffer, int )
 {
-  if(buffer) {
-
+  if (buffer) {
     double d;
-    if(Parse(buffer, d)) {
+    if (Parse(buffer, d)) {
       set(d);
     }
   }
@@ -1127,11 +1125,9 @@ void Float::set(const char *buffer, int buf_size)
 void Float::set(Packet &p)
 {
   double d;
-  if(p.DecodeFloat(d)) {
-
+  if (p.DecodeFloat(d)) {
     set(d);
   }
-
 }
 
 void Float::get(gint64 &i)
@@ -1140,6 +1136,7 @@ void Float::get(gint64 &i)
   get(d);
   i = (gint64)d;
 }
+
 void Float::get(double &d)
 {
   d = value;
@@ -1147,15 +1144,15 @@ void Float::get(double &d)
 
 void Float::get(char *buffer, int buf_size)
 {
-  if(buffer) {
+  if (buffer) {
 
     double d;;
     get(d);
 
-    snprintf(buffer,buf_size,"%g",d);
+    snprintf(buffer, buf_size, "%g", d);
   }
-
 }
+
 void Float::get(Packet &pb)
 {
   double d;
@@ -1164,64 +1161,63 @@ void Float::get(Packet &pb)
   pb.EncodeFloat(d);
 }
 
-Value *Float::copy() {
+Value *Float::copy()
+{
   double d;
   get(d);
   return new Float(d);
 }
 
-string Float::toString()
+std::string Float::toString()
 {
   return toString("%#-16.16g");
 }
 
-
-string Float::toString(const char* format)
+std::string Float::toString(const char* format)
 {
   char cvtBuf[1024];
 
   double d;
   get(d);
 
-  sprintf(cvtBuf, format, d);
-  return (string(&cvtBuf[0]));
+  snprintf(cvtBuf, sizeof(cvtBuf), format, d);
+  return cvtBuf;
 }
 
 char *Float::toString(char *return_str, int len)
 {
-  if(return_str) {
+  if (return_str) {
 
     double d;
     get(d);
-    snprintf(return_str,len,"%g",d);
+    snprintf(return_str, len, "%g", d);
   }
 
   return return_str;
 }
 
-Float* Float::typeCheck(Value* val, string valDesc)
+Float* Float::typeCheck(Value* val, std::string valDesc)
 {
   if (typeid(*val) != typeid(Float)) {
-    throw new TypeMismatch(valDesc, "Float", val->showType());
+    throw TypeMismatch(valDesc, "Float", val->showType());
   }
 
   // This static cast is totally safe in light of our typecheck, above.
-  return((Float*)(val));
+  return static_cast<Float *>(val);
 }
 
 bool Float::compare(ComparisonOperator *compOp, Value *rvalue)
 {
-
   Float *rv = typeCheck(rvalue,"");
 
   double d,r;
   get(d);
   rv->get(r);
 
-  if(d < r)
+  if (d < r)
     return compOp->less();
 
-  if(d > r)
+  if (d > r)
     return compOp->greater();
 
   return compOp->equal();
@@ -1283,13 +1279,13 @@ void String::set(Value *v)
 }
 
 // TODO: is this meant to do something
-void String::set(Packet &p)
+void String::set(Packet &)
 {
-  cout << " fixme String::set(Packet &) is not implemented\n";
+  std::cout << " fixme String::set(Packet &) is not implemented\n";
 }
 
 // TODO: was len meant to do anything
-void String::set(const char *s, int len)
+void String::set(const char *s, int )
 {
   if (s)
     value = s;
@@ -1325,25 +1321,25 @@ namespace gpsim {
 
   Function::~Function()
   {
-    cout << "Function destructor\n";
+    std::cout << "Function destructor\n";
   }
 
-  string Function::description()
+  std::string Function::description()
   {
-    if(cpDescription)
-      return string(cpDescription);
+    if (cpDescription)
+      return cpDescription;
     else
-      return string("no description");
+      return "no description";
   }
 
-  string Function::toString()
+  std::string Function::toString()
   {
     return name();
   }
 
-  void Function::call(ExprList_t *vargs)
+  void Function::call(ExprList_t *)
   {
-    cout << "calling " << name() << endl;
+    std::cout << "calling " << name() << '\n';
   }
 
 }
